/*************************************************************************
*
*    Used with ICCARM and AARM.
*
*    (c) Copyright IAR Systems 2008
*
*    File name   : main.c
*    Description : Main module
*
*    History :
*    1. Date        : 4, August 2008
*       Author      : Stanimir Bonev
*       Description : Create
*
*  This example project shows how to use the IAR Embedded Workbench for ARM
* to develop code for the IAR LPC-2468 board. It shows basic use of the I/O,
* the timer and the interrupt controllers.
*  It starts by blinking USB Link LED.
*
* Jumpers:
*  EXT/JLINK  - depending of power source
*  ISP_E      - unfilled
*  RST_E      - unfilled
*  BDS_E      - unfilled
*  C/SC       - SC
*
* Note:
*  After power-up the controller get clock from internal RC oscillator that
* is unstable and may fail with J-Link auto detect, therefore adaptive clocking
* should always be used. The adaptive clock can be select from menu:
*  Project->Options..., section Debugger->J-Link/J-Trace  JTAG Speed - Adaptive.
*
*    $Revision: 30870 $
**************************************************************************/
#include "iolpc2470_gcc.h"
#include "board.h"
#include "sdram.h"
#include "sys.h"
#include "sdram_64M_32bit_drv.h"
#include "drv_glcd.h"
#include "logo.h"
#include "Cursor.h"
#include "smb380_drv.h"
#include "touchscreen.h"
#include "drv_touch_scr.h"

#include "init.h"
#include "print.h"

#define TIMER0_TICK_PER_SEC   5

#define LCD_VRAM_BASE_ADDR ((Int32U)SDRAM_BASE_ADDR)

unsigned char Smb380Id, Smb380Ver;

void InitializeTimer0(void(*timerHandler)(void), int ticksPerSecond);
void AccelerometerDemo(void);
void TouchScreenDemo(void);
void TouchScreenDemo2(void);

void TouchScrInit(void);

/*************************************************************************
* Function Name: Timer0IntrHandler
* Parameters: none
*
* Return: none
*
* Description: Timer 0 interrupt handler
*
*************************************************************************/
void Timer0IntrHandler (void)
{
	// Toggle USB Link LED
	USB_D_LINK_LED_FIO ^= USB_D_LINK_LED_MASK;

	// Clear interrupt flag for match channel 0.
	T0IR_bit.MR0INT = 1;

	// Acknowledge the interrupt has been handled
	VICADDRESS = 0;
}

/*************************************************************************
* Function Name: main
* Parameters: none
*
* Return: none
*
* Description: main
*
*************************************************************************/
int main(void)
{
	typedef Int32U ram_unit;
	int cursor_x = (C_GLCD_H_SIZE - CURSOR_H_SIZE)/2;
	int cursor_y = (C_GLCD_V_SIZE - CURSOR_V_SIZE)/2;

	InitHardware();
	printString("InitHardware\n");

//	// Init GPIO
//	GpioInit();
//	// Init VIC
//	VIC_Init();
//	// Init clock
//	InitClock();

#ifndef SDRAM_DEBUG
	// MAM init
	MAMCR_bit.MODECTRL = 0;
	MAMTIM_bit.CYCLES  = 5;   // FCLK > 40 MHz
	MAMCR_bit.MODECTRL = 2;   // MAM functions fully enabled
	// SDRAM Init
	 SDRAM_Init();
#endif // SDRAM_DEBUG

	printString("GLCD init\n");

	// GLCD init
	GLCD_Ctrl(FALSE);
	GLCD_Init(logoPic.pPicStream, NULL);
	GLCD_Cursor_Dis(0);
	GLCD_Copy_Cursor((Int32U *)Cursor, 0, sizeof(Cursor)/sizeof(Int32U));
	GLCD_Cursor_Cfg(CRSR_FRAME_SYNC | CRSR_PIX_64);
	GLCD_Move_Cursor(cursor_x, cursor_y);
	GLCD_Cursor_En(0);
	GLCD_Ctrl(TRUE);

	// Init USB Link LED
	USB_D_LINK_LED_FDIR = USB_D_LINK_LED_MASK;
	USB_D_LINK_LED_FSET = USB_D_LINK_LED_MASK;

	InitializeTimer0(Timer0IntrHandler, TIMER0_TICK_PER_SEC);

	// SDRAM_Test();

	//TouchScreenDemo();
	//TouchScreenDemo2();

	AccelerometerDemo();
}


void TouchScreenDemo2(void)
{
	Int32U cursor_x = (C_GLCD_H_SIZE - CURSOR_H_SIZE)/2;
	Int32U cursor_y = (C_GLCD_V_SIZE - CURSOR_V_SIZE)/2;

	ToushRes_t XY_Touch;
	Boolean TouchFlag = FALSE;

	// Init touch screen
	TouchScrInit();

	while (1)
	{
		if (TouchGet(&XY_Touch))
		{
			cursor_x = XY_Touch.X;
			cursor_y = XY_Touch.Y;
			GLCD_Move_Cursor(cursor_x, cursor_y);
			if (FALSE == TouchFlag)
			{
				TouchFlag = TRUE;
				USB_H_LINK_LED_FCLR = USB_H_LINK_LED_MASK;
			}
		}
		else if (TouchFlag)
		{
			USB_H_LINK_LED_FSET = USB_H_LINK_LED_MASK;
			TouchFlag  = FALSE;
		}
	}
}


// Touch Demo - does not work
void TouchScreenDemo(void)
{
#define	TS_MIN_X	200
#define	TS_MAX_X	910
#define	TS_MIN_Y	150
#define	TS_MAX_Y	800

	//char ch;

	touchscreen_data ts_data;
	ts_data.xvalue = 0;
	ts_data.yvalue = 0;
	ts_data.pvalue = 0;

	int cursor_x = (C_GLCD_H_SIZE)/2;
	int cursor_y = (C_GLCD_V_SIZE)/2;

	AD0CR_bit.PDN = 0;

	InitADC(ADC_CH_7);
	InitTS(ts_data);

	GLCD_Move_Cursor(cursor_x, cursor_y);

	while (1)
	{
		for (int i =0; i<100000; i++);

//		if (TRUE == UARTIsDataReady(UART_CH_0))
//		{
//			ch = UARTReceive(UART_CH_0);
//			return;
//		}

		ts_data = GetTS();

		if (ts_data.pvalue > 512)
		{
			cursor_x = (C_GLCD_H_SIZE * (ts_data.xvalue - TS_MIN_X)) /(TS_MAX_X - TS_MIN_X);
			cursor_y = (C_GLCD_V_SIZE * (ts_data.yvalue - TS_MIN_Y)) /(TS_MAX_Y - TS_MIN_Y);

			cursor_x = cursor_x - CURSOR_H_SIZE/2;
			cursor_y = cursor_y - CURSOR_V_SIZE/2;

			if (cursor_x < -28) cursor_x = -28;
			if (cursor_y < -28) cursor_y = -28;

			if ((cursor_x + CURSOR_H_SIZE) > (C_GLCD_H_SIZE+28)) cursor_x = (C_GLCD_H_SIZE - CURSOR_H_SIZE + 28);
			if ((cursor_y + CURSOR_V_SIZE) > (C_GLCD_V_SIZE+28)) cursor_y = (C_GLCD_V_SIZE - CURSOR_V_SIZE + 28);

			GLCD_Move_Cursor(cursor_x, cursor_y);
			//printf("\r\nx=%d, x_cursor=%d, y=%d, y_cursor=%d", ts_data.xvalue, cursor_x, ts_data.yvalue, cursor_y);
			printString("Loop\n");
		}
	}
}

void AccelerometerDemo(void)
{
	int cursor_x = (C_GLCD_H_SIZE - CURSOR_H_SIZE)/2;
	int cursor_y = (C_GLCD_V_SIZE - CURSOR_V_SIZE)/2;

	// Inititalize acceleration sensor
	SMB380_Init();
	SMB380_GetID(&Smb380Id, &Smb380Ver);
	SMB380_Data_t XYZT;

	while(1)
	{
		printString("Loop\n");

		for(int i = 0; i < 100000;  i++);

		SMB380_GetData (&XYZT);

		cursor_x += XYZT.AccX/512;
		cursor_y += XYZT.AccY/512;

		if((C_GLCD_H_SIZE - CURSOR_H_SIZE/2) < cursor_x)
		{
			cursor_x = C_GLCD_H_SIZE - CURSOR_H_SIZE/2;
		}

		if(-(CURSOR_H_SIZE/2) > cursor_x)
		{
			cursor_x = -(CURSOR_H_SIZE/2);
		}

		if((C_GLCD_V_SIZE - CURSOR_V_SIZE/2) < cursor_y)
		{
			cursor_y = (C_GLCD_V_SIZE - CURSOR_V_SIZE/2);
		}

		if(-(CURSOR_V_SIZE/2) > cursor_y)
		{
			cursor_y = -(CURSOR_V_SIZE/2);
		}

		GLCD_Move_Cursor(cursor_x, cursor_y);

		print_uint32(cursor_x);
		printString(" - ");
		print_uint32(cursor_y);
		printString("\n");
	}
}


//
// Stripe the background with a color bands
//
void ColorStripeBackground(void)
{
	pInt32U pDst = (pInt32U)LCD_VRAM_BASE_ADDR;
	for(Int32U k = 0; k < C_GLCD_V_SIZE; k++)
	{
		for(Int32U i = 0 ; 8 > i; i++)
		{
			for(Int32U j = 0; 40 > j; j++)
			{
				switch(i)
				{
				case 0:
					*pDst++ = 0;
					break;
				case 1:
					*pDst++ = 0xFF;
					break;
				case 2:
					*pDst++ = 0xFF00;
					break;
				case 3:
					*pDst++ = 0xFFFF;
					break;
				case 4:
					*pDst++ = 0xFF0000;
					break;
				case 5:
					*pDst++ = 0xFF00FF;
					break;
				case 6:
					*pDst++ = 0xFFFF00;
					break;
				case 7:
					*pDst++ = 0xFFFFFF;
					break;
				}
			}
		}
	}
}
