/***************************************************************************
 **
 **    This file defines the Special Function Registers for
 **    NXP LPC2378
 **
 **    Used with ARM IAR C/C++ Compiler and Assembler.
 **
 **    (c) Copyright IAR Systems 2006
 **
 **    $Revision: 1.1.2.3 $
 **
 **    Note: Only little endian addressing of 8 bit registers.
 ***************************************************************************/

#ifndef __IOLPC2378_H
#define __IOLPC2378_H

//#if (((__TID__ >> 8) & 0x7F) != 0x4F)     /* 0x4F = 79 dec */
//#error This file should only be compiled by ARM IAR compiler and assembler
//#endif

#include "io_macros.h"


#define BIT(a)  (1<<a)

#define VOLATILE32(addr) (*(volatile uint32_t *)(addr))
#define VOLATILE16(addr) (*(volatile uint16_t *)(addr))
#define VOLATILE8(addr)  (*(volatile uint8_t *)(addr))

//#define VOLATILE_TYPE(addr, type_name) (*(volatile type_name *)(addr))


/***************************************************************************
 ***************************************************************************
 **
 **    LPC2378 SPECIAL FUNCTION REGISTERS
 **
 ***************************************************************************
 ***************************************************************************
 ***************************************************************************/

/* C-compiler specific declarations  ***************************************/
#ifdef __GNUC__

//#ifndef _SYSTEM_BUILD
//#pragma system_include
//#endif


/* Memory mapping control register */
typedef struct{
__REG32 MAP         : 2;
__REG32             :30;
} __memmap_bits;

/* Reset Source Identification Register */
typedef struct{
__REG32 POR         : 1;
__REG32 EXTR        : 1;
__REG32 WDTR        : 1;
__REG32 BODR        : 1;
__REG32             :28;
} __rsir_bits;

/* External interrupt register */
typedef struct{
__REG32 EINT0       : 1;
__REG32 EINT1       : 1;
__REG32 EINT2       : 1;
__REG32 EINT3       : 1;
__REG32             :28;
} __extint_bits;

/* External Interrupt Mode Register */
typedef struct{
__REG32 EXTMODE0    : 1;
__REG32 EXTMODE1    : 1;
__REG32 EXTMODE2    : 1;
__REG32 EXTMODE3    : 1;
__REG32             :28;
} __extmode_bits;

/* External Interrupt Polarity Register */
typedef struct{
__REG32 EXTPOLAR0   : 1;
__REG32 EXTPOLAR1   : 1;
__REG32 EXTPOLAR2   : 1;
__REG32 EXTPOLAR3   : 1;
__REG32             :28;
} __extpolar_bits;

/* System Controls and Status register */
typedef struct{
__REG32 GPIOM       : 1;
__REG32 EMCRD       : 1;
__REG32             : 1;
__REG32 MCIPWR      : 1;
__REG32 OSCRANGE    : 1;
__REG32 OSCEN       : 1;
__REG32 OSCSTAT     : 1;
__REG32             :25;
} __scs_bits;

/* AHB Arbiter Configuration Register*/
typedef struct{
__REG32 SHDL        : 1;
__REG32 BB          : 2;
__REG32 QT          : 1;
__REG32 QS          : 4;
__REG32 DM          : 4;
__REG32 EP1         : 4;
__REG32 EP2         : 4;
__REG32 EP3         : 4;
__REG32 EP4         : 4;
__REG32 EP5         : 4;    // HACK
} __ahbcfg1_bits;

typedef struct{
__REG32 SHDL        : 1;
__REG32 BB          : 2;
__REG32 QT          : 1;
__REG32 QS          : 4;
__REG32 DM          : 4;
__REG32 EP1         : 4;
__REG32 EP2         : 4;
__REG32             :12;
} __ahbcfg2_bits;

/* Clock Soucre Select register */
typedef struct{
__REG32 CLKSRC      : 2;
__REG32             :30;
} __clksrcsel_bits;

/* IRC Trim Register (IRCTRIM - 0xE01FC1A4) */
typedef struct{
__REG32 IRCTRIM     : 8;
__REG32             :24;
} __irctrim_bits;

/* APB Divider Register */
typedef struct{
__REG32 APBDIV  : 2;
__REG32         :30;
} __apbdiv_bits;

/* CPU Clock Configuration register */
typedef struct{
__REG32 CCLKSEL     : 8;
__REG32             :24;
} __cclkcfg_bits;

/* USB Clock Configuration register */
typedef struct{
__REG32 USBSEL      : 4;
__REG32             :28;
} __usbclkcfg_bits;

/* Peripheral Clock Selection registers 0 */

typedef struct{
__REG32 PCLK_WDT    : 2;
__REG32 PCLK_TIMER0 : 2;
__REG32 PCLK_TIMER1 : 2;
__REG32 PCLK_UART0  : 2;
__REG32 PCLK_UART1  : 2;
__REG32 PCLK_PWM0   : 2;
__REG32 PCLK_PWM1   : 2;
__REG32 PCLK_I2C0   : 2;
__REG32 PCLK_SPI    : 2;
__REG32 PCLK_RTC    : 2;
__REG32 PCLK_SSP1   : 2;
__REG32 PCLK_DAC    : 2;
__REG32 PCLK_ADC    : 2;
__REG32 PCLK_CAN1   : 2;
__REG32 PCLK_CAN2   : 2;
__REG32 PCLK_ACF    : 2;
} __pclksel0_bits;

/* Peripheral Clock Selection registers 1 */
typedef struct{
__REG32 PCLK_BAT_RAM: 2;
__REG32 PCLK_GPIO   : 2;
__REG32 PCLK_PCB    : 2;
__REG32 PCLK_I2C1   : 2;
__REG32             : 2;
__REG32 PCLK_SSP0   : 2;
__REG32 PCLK_TIMER2 : 2;
__REG32 PCLK_TIMER3 : 2;
__REG32 PCLK_UART2  : 2;
__REG32 PCLK_UART3  : 2;
__REG32 PCLK_I2C2   : 2;
__REG32 PCLK_I2S    : 2;
__REG32 PCLK_MCI    : 2;
__REG32             : 2;
__REG32 PCLK_SYSCON : 2;
__REG32             : 2;
} __pclksel1_bits;

/* PLL control register */
typedef struct{
__REG32 PLLE        : 1;
__REG32 PLLC        : 1;
__REG32             :30;
} __pllcon_bits;

/* PLL config register */
typedef struct{
__REG32 MSEL        :15;
__REG32             : 1;
__REG32 NSEL        : 8;
__REG32             : 8;
} __pllcfg_bits;

/* PLL status register */
typedef struct{
__REG32 MSEL        :15;
__REG32             : 1;
__REG32 NSEL        : 8;
__REG32 PLLE        : 1;
__REG32 PLLC        : 1;
__REG32 PLOCK       : 1;
__REG32             : 5;
} __pllstat_bits;

/* PLL feed register */
typedef struct{
__REG32 FEED        : 8;
__REG32             :24;
} __pllfeed_bits;

/* Power control register */
typedef struct{
__REG32 IDL         : 1;
__REG32 PD          : 1;
__REG32 BODPDM      : 1;
__REG32 BOGD        : 1;
__REG32 BORD        : 1;
__REG32             : 2;
__REG32 PM2         : 1;
__REG32             :24;
}__pcon_bits;

/* Interrupt Wakeup Register */
typedef struct{
__REG32 EXTWAKE0    : 1;
__REG32 EXTWAKE1    : 1;
__REG32 EXTWAKE2    : 1;
__REG32 EXTWAKE3    : 1;
__REG32 ETHWAK      : 1;
__REG32 USBWAKE     : 1;
__REG32 CANWAKE     : 1;
__REG32 GPIOWAKE    : 1;
__REG32             : 6;
__REG32 BODWAKE     : 1;
__REG32 RTCWAKE     : 1;
__REG32             :16;
}__intwake_bits;

/* Power control for peripherals register */
typedef struct{
__REG32             : 1;
__REG32 PCTIM0      : 1;
__REG32 PCTIM1      : 1;
__REG32 PCUART0     : 1;
__REG32 PCUART1     : 1;
__REG32 PCPWM0      : 1;
__REG32 PCPWM1      : 1;
__REG32 PCI2C0      : 1;
__REG32 PCSPI       : 1;
__REG32 PCRTC       : 1;
__REG32 PCSSP1      : 1;
__REG32 PCEMC       : 1;
__REG32 PCAD        : 1;
__REG32 PCAN1       : 1;
__REG32 PCAN2       : 1;
__REG32             : 4;
__REG32 PCI2C1      : 1;
__REG32             : 1;
__REG32 PCSSP0      : 1;
__REG32 PCTIM2      : 1;
__REG32 PCTIM3      : 1;
__REG32 PCUART2     : 1;
__REG32 PCUART3     : 1;
__REG32 PCI2C2      : 1;
__REG32 PCI2S       : 1;
__REG32 PCSDC       : 1;
__REG32 PCGPDMA     : 1;
__REG32 PCENET      : 1;
__REG32 PCUSB       : 1;
} __pconp_bits;

/* Memory accelerator module control register */
typedef struct {
  __REG32 MODECTRL  : 2;
  __REG32           :30;
} __mamcr_bits;

/* Memory accelerator module timing register */
typedef struct {
  __REG32 CYCLES    : 3;
  __REG32           :29;
} __mamtim_bits;

/* EMC Control Register */
typedef struct {
  __REG32 E         : 1;
  __REG32 M         : 1;
  __REG32 L         : 1;
  __REG32           :29;
} __emc_ctrl_bits;

/* EMC Status Register */
typedef struct {
  __REG32 B         : 1;
  __REG32 S         : 1;
  __REG32 SA        : 1;
  __REG32           :29;
} __emc_st_bits;

/* EMC Configuration Register */
typedef struct {
  __REG32 ENDIAN    : 1;
  __REG32           :31;
} __emc_cfg_bits;

/* Static Memory Configuration Registers */
typedef struct {
  __REG32 MW        : 2;
  __REG32           : 1;
  __REG32 PM        : 1;
  __REG32           : 2;
  __REG32 PC        : 1;
  __REG32           : 1;
  __REG32 EW        : 1;
  __REG32           :10;
  __REG32 B         : 1;
  __REG32 P         : 1;
  __REG32           :11;
} __emc_s_config_bits;

/* Static Memory Write Enable Delay Registers */
typedef struct {
  __REG32 WAITWEN   : 4;
  __REG32           :28;
} __emc_s_wait_wen_bits;

/* Static Memory Output Enable Delay Registers */
typedef struct {
  __REG32 WAITOEN   : 4;
  __REG32           :28;
} __emc_s_wait_oen_bits;

/* Static Memory Read Delay Registers */
typedef struct {
  __REG32 WAITRD    : 5;
  __REG32           :27;
} __emc_s_wait_rd_bits;

/* Static Memory Page Mode Read Delay Registers */
typedef struct {
  __REG32 WAITPAGE  : 5;
  __REG32           :27;
} __emc_s_wait_pg_bits;

/* Static Memory Write Delay Registers */
typedef struct {
  __REG32 WAITWR    : 5;
  __REG32           :27;
} __emc_s_wait_wr_bits;

/* Static Memory Extended Wait Register */
typedef struct {
  __REG32 EXTENDEDWAIT  :10;
  __REG32               :22;
} __emc_s_ext_wait_bits;

/* Static Memory Turn Round Delay Registers */
typedef struct {
  __REG32 WAITTURN  : 4;
  __REG32           :28;
} __emc_s_wait_turn_bits;

/* VIC Interrupt registers */
typedef struct{
__REG32 WDT       : 1;
__REG32           : 1;
__REG32 ARMCORE0  : 1;
__REG32 ARMCORE1  : 1;
__REG32 TIMER0    : 1;
__REG32 TIMER1    : 1;
__REG32 UART0     : 1;
__REG32 UART1     : 1;
__REG32 PWM1      : 1;
__REG32 I2C0      : 1;
__REG32 SPI       : 1;
__REG32 SSP1      : 1;
__REG32 PLL       : 1;
__REG32 RTC       : 1;
__REG32 EINT0     : 1;
__REG32 EINT1     : 1;
__REG32 EINT2     : 1;
__REG32 EINT3     : 1;
__REG32 AD0       : 1;
__REG32 I2C1      : 1;
__REG32 BOD       : 1;
__REG32 ETHERNET  : 1;
__REG32 USB       : 1;
__REG32 CAN12     : 1;
__REG32 SDMMC     : 1;
__REG32 GPDMA     : 1;
__REG32 TIMER2    : 1;
__REG32 TIMER3    : 1;
__REG32 UART2     : 1;
__REG32 UART3     : 1;
__REG32 I2C2      : 1;
__REG32 I2S       : 1;
} __vicint_bits;

/* VIC Vector control registers */
typedef struct{
__REG32 PRIORITY : 4;
__REG32          :28;
} __vicvectpr_bits;

/* VIC Software Priority register */
typedef struct{
__REG32 SWPRIORITY:16;
__REG32           :16;
} __vicswprmask_bits;

/* VIC protection enable register */
typedef struct{
__REG32 PROTECT  : 1;
__REG32          :31;
} __vicprotection_bits;

/* Pin function select register 0 */
typedef struct{
__REG32 P0_0   : 2;
__REG32 P0_1   : 2;
__REG32 P0_2   : 2;
__REG32 P0_3   : 2;
__REG32 P0_4   : 2;
__REG32 P0_5   : 2;
__REG32 P0_6   : 2;
__REG32 P0_7   : 2;
__REG32 P0_8   : 2;
__REG32 P0_9   : 2;
__REG32 P0_10  : 2;
__REG32 P0_11  : 2;
__REG32 P0_12  : 2;
__REG32 P0_13  : 2;
__REG32 P0_14  : 2;
__REG32 P0_15  : 2;
} __pinsel0_bits;

/* Pin function select register 1 */
typedef struct{
__REG32 P0_16  : 2;
__REG32 P0_17  : 2;
__REG32 P0_18  : 2;
__REG32 P0_19  : 2;
__REG32 P0_20  : 2;
__REG32 P0_21  : 2;
__REG32 P0_22  : 2;
__REG32 P0_23  : 2;
__REG32 P0_24  : 2;
__REG32 P0_25  : 2;
__REG32 P0_26  : 2;
__REG32 P0_27  : 2;
__REG32 P0_28  : 2;
__REG32 P0_29  : 2;
__REG32 P0_30  : 2;
__REG32 P0_31  : 2;
} __pinsel1_bits;

/* Pin function select register 2 */
typedef struct{
__REG32 P1_0   : 2;
__REG32 P1_1   : 2;
__REG32 P1_2   : 2;
__REG32 P1_3   : 2;
__REG32 P1_4   : 2;
__REG32 P1_5   : 2;
__REG32 P1_6   : 2;
__REG32 P1_7   : 2;
__REG32 P1_8   : 2;
__REG32 P1_9   : 2;
__REG32 P1_10  : 2;
__REG32 P1_11  : 2;
__REG32 P1_12  : 2;
__REG32 P1_13  : 2;
__REG32 P1_14  : 2;
__REG32 P1_15  : 2;
} __pinsel2_bits;

/* Pin function select register 3 */
typedef struct{
__REG32 P1_16  : 2;
__REG32 P1_17  : 2;
__REG32 P1_18  : 2;
__REG32 P1_19  : 2;
__REG32 P1_20  : 2;
__REG32 P1_21  : 2;
__REG32 P1_22  : 2;
__REG32 P1_23  : 2;
__REG32 P1_24  : 2;
__REG32 P1_25  : 2;
__REG32 P1_26  : 2;
__REG32 P1_27  : 2;
__REG32 P1_28  : 2;
__REG32 P1_29  : 2;
__REG32 P1_30  : 2;
__REG32 P1_31  : 2;
} __pinsel3_bits;

/* Pin function select register 4 */
typedef struct{
__REG32 P2_0   : 2;
__REG32 P2_1   : 2;
__REG32 P2_2   : 2;
__REG32 P2_3   : 2;
__REG32 P2_4   : 2;
__REG32 P2_5   : 2;
__REG32 P2_6   : 2;
__REG32 P2_7   : 2;
__REG32 P2_8   : 2;
__REG32 P2_9   : 2;
__REG32 P2_10  : 2;
__REG32 P2_11  : 2;
__REG32 P2_12  : 2;
__REG32 P2_13  : 2;
__REG32 P2_14  : 2;
__REG32 P2_15  : 2;
} __pinsel4_bits;

/* Pin function select register 5 */
typedef struct{
__REG32 P2_16  : 2;
__REG32 P2_17  : 2;
__REG32 P2_18  : 2;
__REG32 P2_19  : 2;
__REG32 P2_20  : 2;
__REG32 P2_21  : 2;
__REG32 P2_22  : 2;
__REG32 P2_23  : 2;
__REG32 P2_24  : 2;
__REG32 P2_25  : 2;
__REG32 P2_26  : 2;
__REG32 P2_27  : 2;
__REG32 P2_28  : 2;
__REG32 P2_29  : 2;
__REG32 P2_30  : 2;
__REG32 P2_31  : 2;
} __pinsel5_bits;

/* Pin function select register 6 */
typedef struct{
__REG32 P3_0   : 2;
__REG32 P3_1   : 2;
__REG32 P3_2   : 2;
__REG32 P3_3   : 2;
__REG32 P3_4   : 2;
__REG32 P3_5   : 2;
__REG32 P3_6   : 2;
__REG32 P3_7   : 2;
__REG32 P3_8   : 2;
__REG32 P3_9   : 2;
__REG32 P3_10  : 2;
__REG32 P3_11  : 2;
__REG32 P3_12  : 2;
__REG32 P3_13  : 2;
__REG32 P3_14  : 2;
__REG32 P3_15  : 2;
} __pinsel6_bits;

/* Pin function select register 7 */
typedef struct{
__REG32 P3_16  : 2;
__REG32 P3_17  : 2;
__REG32 P3_18  : 2;
__REG32 P3_19  : 2;
__REG32 P3_20  : 2;
__REG32 P3_21  : 2;
__REG32 P3_22  : 2;
__REG32 P3_23  : 2;
__REG32 P3_24  : 2;
__REG32 P3_25  : 2;
__REG32 P3_26  : 2;
__REG32 P3_27  : 2;
__REG32 P3_28  : 2;
__REG32 P3_29  : 2;
__REG32 P3_30  : 2;
__REG32 P3_31  : 2;
} __pinsel7_bits;

/* Pin function select register 8 */
typedef struct{
__REG32 P4_0   : 2;
__REG32 P4_1   : 2;
__REG32 P4_2   : 2;
__REG32 P4_3   : 2;
__REG32 P4_4   : 2;
__REG32 P4_5   : 2;
__REG32 P4_6   : 2;
__REG32 P4_7   : 2;
__REG32 P4_8   : 2;
__REG32 P4_9   : 2;
__REG32 P4_10  : 2;
__REG32 P4_11  : 2;
__REG32 P4_12  : 2;
__REG32 P4_13  : 2;
__REG32 P4_14  : 2;
__REG32 P4_15  : 2;
} __pinsel8_bits;

/* Pin function select register 9 */
typedef struct{
__REG32 P4_16  : 2;
__REG32 P4_17  : 2;
__REG32 P4_18  : 2;
__REG32 P4_19  : 2;
__REG32 P4_20  : 2;
__REG32 P4_21  : 2;
__REG32 P4_22  : 2;
__REG32 P4_23  : 2;
__REG32 P4_24  : 2;
__REG32 P4_25  : 2;
__REG32 P4_26  : 2;
__REG32 P4_27  : 2;
__REG32 P4_28  : 2;
__REG32 P4_29  : 2;
__REG32 P4_30  : 2;
__REG32 P4_31  : 2;
} __pinsel9_bits;

/* Pin function select register 10 */
typedef struct{
__REG32             : 3;
__REG32 GPIO_TRACE  : 1;
__REG32             :28;
} __pinsel10_bits;

/* GPIO 0 Registers */
typedef struct {
__REG32 P0_0   : 1;
__REG32 P0_1   : 1;
__REG32 P0_2   : 1;
__REG32 P0_3   : 1;
__REG32 P0_4   : 1;
__REG32 P0_5   : 1;
__REG32 P0_6   : 1;
__REG32 P0_7   : 1;
__REG32 P0_8   : 1;
__REG32 P0_9   : 1;
__REG32 P0_10  : 1;
__REG32 P0_11  : 1;
__REG32 P0_12  : 1;
__REG32 P0_13  : 1;
__REG32 P0_14  : 1;
__REG32 P0_15  : 1;
__REG32 P0_16  : 1;
__REG32 P0_17  : 1;
__REG32 P0_18  : 1;
__REG32 P0_19  : 1;
__REG32 P0_20  : 1;
__REG32 P0_21  : 1;
__REG32 P0_22  : 1;
__REG32 P0_23  : 1;
__REG32 P0_24  : 1;
__REG32 P0_25  : 1;
__REG32 P0_26  : 1;
__REG32 P0_27  : 1;
__REG32 P0_28  : 1;
__REG32 P0_29  : 1;
__REG32 P0_30  : 1;
__REG32 P0_31  : 1;
} __gpio0_bits;

/* FGPIO 0 Registers*/
typedef union{
  struct {
    __REG32 P0_0   : 1;
    __REG32 P0_1   : 1;
    __REG32 P0_2   : 1;
    __REG32 P0_3   : 1;
    __REG32 P0_4   : 1;
    __REG32 P0_5   : 1;
    __REG32 P0_6   : 1;
    __REG32 P0_7   : 1;
    __REG32 P0_8   : 1;
    __REG32 P0_9   : 1;
    __REG32 P0_10  : 1;
    __REG32 P0_11  : 1;
    __REG32 P0_12  : 1;
    __REG32 P0_13  : 1;
    __REG32 P0_14  : 1;
    __REG32 P0_15  : 1;
    __REG32 P0_16  : 1;
    __REG32 P0_17  : 1;
    __REG32 P0_18  : 1;
    __REG32 P0_19  : 1;
    __REG32 P0_20  : 1;
    __REG32 P0_21  : 1;
    __REG32 P0_22  : 1;
    __REG32 P0_23  : 1;
    __REG32 P0_24  : 1;
    __REG32 P0_25  : 1;
    __REG32 P0_26  : 1;
    __REG32 P0_27  : 1;
    __REG32 P0_28  : 1;
    __REG32 P0_29  : 1;
    __REG32 P0_30  : 1;
    __REG32 P0_31  : 1;
  };

  struct
  {
    union
    {
      struct{
        __REG8  P0_0   : 1;
        __REG8  P0_1   : 1;
        __REG8  P0_2   : 1;
        __REG8  P0_3   : 1;
        __REG8  P0_4   : 1;
        __REG8  P0_5   : 1;
        __REG8  P0_6   : 1;
        __REG8  P0_7   : 1;
      } __byte0_bit;
      __REG8 __byte0;
    };
    union
    {
      struct{
        __REG8  P0_0   : 1;
        __REG8  P0_1   : 1;
        __REG8  P0_2   : 1;
        __REG8  P0_3   : 1;
        __REG8  P0_4   : 1;
        __REG8  P0_5   : 1;
        __REG8  P0_6   : 1;
        __REG8  P0_7   : 1;
      } __byte1_bit;
      __REG8 __byte1;
    };
    union
    {
      struct{
        __REG8  P0_0   : 1;
        __REG8  P0_1   : 1;
        __REG8  P0_2   : 1;
        __REG8  P0_3   : 1;
        __REG8  P0_4   : 1;
        __REG8  P0_5   : 1;
        __REG8  P0_6   : 1;
        __REG8  P0_7   : 1;
      } __byte2_bit;
      __REG8 __byte2;
    };
    union
    {
      struct{
        __REG8  P0_0   : 1;
        __REG8  P0_1   : 1;
        __REG8  P0_2   : 1;
        __REG8  P0_3   : 1;
        __REG8  P0_4   : 1;
        __REG8  P0_5   : 1;
        __REG8  P0_6   : 1;
        __REG8  P0_7   : 1;
      } __byte3_bit;
      __REG8 __byte3;
    };
  };

  struct
  {
    union
    {
      struct{
        __REG16 P0_0   : 1;
        __REG16 P0_1   : 1;
        __REG16 P0_2   : 1;
        __REG16 P0_3   : 1;
        __REG16 P0_4   : 1;
        __REG16 P0_5   : 1;
        __REG16 P0_6   : 1;
        __REG16 P0_7   : 1;
        __REG16 P0_8   : 1;
        __REG16 P0_9   : 1;
        __REG16 P0_10  : 1;
        __REG16 P0_11  : 1;
        __REG16 P0_12  : 1;
        __REG16 P0_13  : 1;
        __REG16 P0_14  : 1;
        __REG16 P0_15  : 1;
      } __shortl_bit;
      __REG16 __shortl;
    };
    union
    {
      struct{
        __REG16 P0_0   : 1;
        __REG16 P0_1   : 1;
        __REG16 P0_2   : 1;
        __REG16 P0_3   : 1;
        __REG16 P0_4   : 1;
        __REG16 P0_5   : 1;
        __REG16 P0_6   : 1;
        __REG16 P0_7   : 1;
        __REG16 P0_8   : 1;
        __REG16 P0_9   : 1;
        __REG16 P0_10  : 1;
        __REG16 P0_11  : 1;
        __REG16 P0_12  : 1;
        __REG16 P0_13  : 1;
        __REG16 P0_14  : 1;
        __REG16 P0_15  : 1;
      } __shortu_bit;
      __REG16 __shortu;
    };
  };
} __fgpio0_bits;

/* GPIO 1 Registers */
typedef struct {
__REG32 P1_0   : 1;
__REG32 P1_1   : 1;
__REG32 P1_2   : 1;
__REG32 P1_3   : 1;
__REG32 P1_4   : 1;
__REG32 P1_5   : 1;
__REG32 P1_6   : 1;
__REG32 P1_7   : 1;
__REG32 P1_8   : 1;
__REG32 P1_9   : 1;
__REG32 P1_10  : 1;
__REG32 P1_11  : 1;
__REG32 P1_12  : 1;
__REG32 P1_13  : 1;
__REG32 P1_14  : 1;
__REG32 P1_15  : 1;
__REG32 P1_16  : 1;
__REG32 P1_17  : 1;
__REG32 P1_18  : 1;
__REG32 P1_19  : 1;
__REG32 P1_20  : 1;
__REG32 P1_21  : 1;
__REG32 P1_22  : 1;
__REG32 P1_23  : 1;
__REG32 P1_24  : 1;
__REG32 P1_25  : 1;
__REG32 P1_26  : 1;
__REG32 P1_27  : 1;
__REG32 P1_28  : 1;
__REG32 P1_29  : 1;
__REG32 P1_30  : 1;
__REG32 P1_31  : 1;
} __gpio1_bits;

/* FGPIO 1 Registers*/
typedef union{
  struct {
    __REG32 P1_0   : 1;
    __REG32 P1_1   : 1;
    __REG32 P1_2   : 1;
    __REG32 P1_3   : 1;
    __REG32 P1_4   : 1;
    __REG32 P1_5   : 1;
    __REG32 P1_6   : 1;
    __REG32 P1_7   : 1;
    __REG32 P1_8   : 1;
    __REG32 P1_9   : 1;
    __REG32 P1_10  : 1;
    __REG32 P1_11  : 1;
    __REG32 P1_12  : 1;
    __REG32 P1_13  : 1;
    __REG32 P1_14  : 1;
    __REG32 P1_15  : 1;
    __REG32 P1_16  : 1;
    __REG32 P1_17  : 1;
    __REG32 P1_18  : 1;
    __REG32 P1_19  : 1;
    __REG32 P1_20  : 1;
    __REG32 P1_21  : 1;
    __REG32 P1_22  : 1;
    __REG32 P1_23  : 1;
    __REG32 P1_24  : 1;
    __REG32 P1_25  : 1;
    __REG32 P1_26  : 1;
    __REG32 P1_27  : 1;
    __REG32 P1_28  : 1;
    __REG32 P1_29  : 1;
    __REG32 P1_30  : 1;
    __REG32 P1_31  : 1;
  };

  struct
  {
    union
    {
      struct{
        __REG8  P1_0   : 1;
        __REG8  P1_1   : 1;
        __REG8  P1_2   : 1;
        __REG8  P1_3   : 1;
        __REG8  P1_4   : 1;
        __REG8  P1_5   : 1;
        __REG8  P1_6   : 1;
        __REG8  P1_7   : 1;
      } __byte0_bit;
      __REG8 __byte0;
    };
    union
    {
      struct{
        __REG8  P1_0   : 1;
        __REG8  P1_1   : 1;
        __REG8  P1_2   : 1;
        __REG8  P1_3   : 1;
        __REG8  P1_4   : 1;
        __REG8  P1_5   : 1;
        __REG8  P1_6   : 1;
        __REG8  P1_7   : 1;
      } __byte1_bit;
      __REG8 __byte1;
    };
    union
    {
      struct{
        __REG8  P1_0   : 1;
        __REG8  P1_1   : 1;
        __REG8  P1_2   : 1;
        __REG8  P1_3   : 1;
        __REG8  P1_4   : 1;
        __REG8  P1_5   : 1;
        __REG8  P1_6   : 1;
        __REG8  P1_7   : 1;
      } __byte2_bit;
      __REG8 __byte2;
    };
    union
    {
      struct{
        __REG8  P1_0   : 1;
        __REG8  P1_1   : 1;
        __REG8  P1_2   : 1;
        __REG8  P1_3   : 1;
        __REG8  P1_4   : 1;
        __REG8  P1_5   : 1;
        __REG8  P1_6   : 1;
        __REG8  P1_7   : 1;
      } __byte3_bit;
      __REG8 __byte3;
    };
  };

  struct
  {
    union
    {
      struct{
        __REG16 P1_0   : 1;
        __REG16 P1_1   : 1;
        __REG16 P1_2   : 1;
        __REG16 P1_3   : 1;
        __REG16 P1_4   : 1;
        __REG16 P1_5   : 1;
        __REG16 P1_6   : 1;
        __REG16 P1_7   : 1;
        __REG16 P1_8   : 1;
        __REG16 P1_9   : 1;
        __REG16 P1_10  : 1;
        __REG16 P1_11  : 1;
        __REG16 P1_12  : 1;
        __REG16 P1_13  : 1;
        __REG16 P1_14  : 1;
        __REG16 P1_15  : 1;
      } __shortl_bit;
      __REG16 __shortl;
    };
    union
    {
      struct{
        __REG16 P1_0   : 1;
        __REG16 P1_1   : 1;
        __REG16 P1_2   : 1;
        __REG16 P1_3   : 1;
        __REG16 P1_4   : 1;
        __REG16 P1_5   : 1;
        __REG16 P1_6   : 1;
        __REG16 P1_7   : 1;
        __REG16 P1_8   : 1;
        __REG16 P1_9   : 1;
        __REG16 P1_10  : 1;
        __REG16 P1_11  : 1;
        __REG16 P1_12  : 1;
        __REG16 P1_13  : 1;
        __REG16 P1_14  : 1;
        __REG16 P1_15  : 1;
      } __shortu_bit;
      __REG16 __shortu;
    };
  };
} __fgpio1_bits;

/* FGPIO 2 Registers*/
typedef union{
  struct {
    __REG32 P2_0   : 1;
    __REG32 P2_1   : 1;
    __REG32 P2_2   : 1;
    __REG32 P2_3   : 1;
    __REG32 P2_4   : 1;
    __REG32 P2_5   : 1;
    __REG32 P2_6   : 1;
    __REG32 P2_7   : 1;
    __REG32 P2_8   : 1;
    __REG32 P2_9   : 1;
    __REG32 P2_10  : 1;
    __REG32 P2_11  : 1;
    __REG32 P2_12  : 1;
    __REG32 P2_13  : 1;
    __REG32 P2_14  : 1;
    __REG32 P2_15  : 1;
    __REG32 P2_16  : 1;
    __REG32 P2_17  : 1;
    __REG32 P2_18  : 1;
    __REG32 P2_19  : 1;
    __REG32 P2_20  : 1;
    __REG32 P2_21  : 1;
    __REG32 P2_22  : 1;
    __REG32 P2_23  : 1;
    __REG32 P2_24  : 1;
    __REG32 P2_25  : 1;
    __REG32 P2_26  : 1;
    __REG32 P2_27  : 1;
    __REG32 P2_28  : 1;
    __REG32 P2_29  : 1;
    __REG32 P2_30  : 1;
    __REG32 P2_31  : 1;
  };

  struct
  {
    union
    {
      struct{
        __REG8  P2_0   : 1;
        __REG8  P2_1   : 1;
        __REG8  P2_2   : 1;
        __REG8  P2_3   : 1;
        __REG8  P2_4   : 1;
        __REG8  P2_5   : 1;
        __REG8  P2_6   : 1;
        __REG8  P2_7   : 1;
      } __byte0_bit;
      __REG8 __byte0;
    };
    union
    {
      struct{
        __REG8  P2_0   : 1;
        __REG8  P2_1   : 1;
        __REG8  P2_2   : 1;
        __REG8  P2_3   : 1;
        __REG8  P2_4   : 1;
        __REG8  P2_5   : 1;
        __REG8  P2_6   : 1;
        __REG8  P2_7   : 1;
      } __byte1_bit;
      __REG8 __byte1;
    };
    union
    {
      struct{
        __REG8  P2_0   : 1;
        __REG8  P2_1   : 1;
        __REG8  P2_2   : 1;
        __REG8  P2_3   : 1;
        __REG8  P2_4   : 1;
        __REG8  P2_5   : 1;
        __REG8  P2_6   : 1;
        __REG8  P2_7   : 1;
      } __byte2_bit;
      __REG8 __byte2;
    };
    union
    {
      struct{
        __REG8  P2_0   : 1;
        __REG8  P2_1   : 1;
        __REG8  P2_2   : 1;
        __REG8  P2_3   : 1;
        __REG8  P2_4   : 1;
        __REG8  P2_5   : 1;
        __REG8  P2_6   : 1;
        __REG8  P2_7   : 1;
      } __byte3_bit;
      __REG8 __byte3;
    };
  };

  struct
  {
    union
    {
      struct{
        __REG16 P2_0   : 1;
        __REG16 P2_1   : 1;
        __REG16 P2_2   : 1;
        __REG16 P2_3   : 1;
        __REG16 P2_4   : 1;
        __REG16 P2_5   : 1;
        __REG16 P2_6   : 1;
        __REG16 P2_7   : 1;
        __REG16 P2_8   : 1;
        __REG16 P2_9   : 1;
        __REG16 P2_10  : 1;
        __REG16 P2_11  : 1;
        __REG16 P2_12  : 1;
        __REG16 P2_13  : 1;
        __REG16 P2_14  : 1;
        __REG16 P2_15  : 1;
      } __shortl_bit;
      __REG16 __shortl;
    };
    union
    {
      struct{
        __REG16 P2_0   : 1;
        __REG16 P2_1   : 1;
        __REG16 P2_2   : 1;
        __REG16 P2_3   : 1;
        __REG16 P2_4   : 1;
        __REG16 P2_5   : 1;
        __REG16 P2_6   : 1;
        __REG16 P2_7   : 1;
        __REG16 P2_8   : 1;
        __REG16 P2_9   : 1;
        __REG16 P2_10  : 1;
        __REG16 P2_11  : 1;
        __REG16 P2_12  : 1;
        __REG16 P2_13  : 1;
        __REG16 P2_14  : 1;
        __REG16 P2_15  : 1;
      } __shortu_bit;
      __REG16 __shortu;
    };
  };
} __fgpio2_bits;

/* FGPIO 3 Registers*/
typedef union{
  struct {
    __REG32 P3_0   : 1;
    __REG32 P3_1   : 1;
    __REG32 P3_2   : 1;
    __REG32 P3_3   : 1;
    __REG32 P3_4   : 1;
    __REG32 P3_5   : 1;
    __REG32 P3_6   : 1;
    __REG32 P3_7   : 1;
    __REG32 P3_8   : 1;
    __REG32 P3_9   : 1;
    __REG32 P3_10  : 1;
    __REG32 P3_11  : 1;
    __REG32 P3_12  : 1;
    __REG32 P3_13  : 1;
    __REG32 P3_14  : 1;
    __REG32 P3_15  : 1;
    __REG32 P3_16  : 1;
    __REG32 P3_17  : 1;
    __REG32 P3_18  : 1;
    __REG32 P3_19  : 1;
    __REG32 P3_20  : 1;
    __REG32 P3_21  : 1;
    __REG32 P3_22  : 1;
    __REG32 P3_23  : 1;
    __REG32 P3_24  : 1;
    __REG32 P3_25  : 1;
    __REG32 P3_26  : 1;
    __REG32 P3_27  : 1;
    __REG32 P3_28  : 1;
    __REG32 P3_29  : 1;
    __REG32 P3_30  : 1;
    __REG32 P3_31  : 1;
  };

  struct
  {
    union
    {
      struct{
        __REG8  P3_0   : 1;
        __REG8  P3_1   : 1;
        __REG8  P3_2   : 1;
        __REG8  P3_3   : 1;
        __REG8  P3_4   : 1;
        __REG8  P3_5   : 1;
        __REG8  P3_6   : 1;
        __REG8  P3_7   : 1;
      } __byte0_bit;
      __REG8 __byte0;
    };
    union
    {
      struct{
        __REG8  P3_0   : 1;
        __REG8  P3_1   : 1;
        __REG8  P3_2   : 1;
        __REG8  P3_3   : 1;
        __REG8  P3_4   : 1;
        __REG8  P3_5   : 1;
        __REG8  P3_6   : 1;
        __REG8  P3_7   : 1;
      } __byte1_bit;
      __REG8 __byte1;
    };
    union
    {
      struct{
        __REG8  P3_0   : 1;
        __REG8  P3_1   : 1;
        __REG8  P3_2   : 1;
        __REG8  P3_3   : 1;
        __REG8  P3_4   : 1;
        __REG8  P3_5   : 1;
        __REG8  P3_6   : 1;
        __REG8  P3_7   : 1;
      } __byte2_bit;
      __REG8 __byte2;
    };
    union
    {
      struct{
        __REG8  P3_0   : 1;
        __REG8  P3_1   : 1;
        __REG8  P3_2   : 1;
        __REG8  P3_3   : 1;
        __REG8  P3_4   : 1;
        __REG8  P3_5   : 1;
        __REG8  P3_6   : 1;
        __REG8  P3_7   : 1;
      } __byte3_bit;
      __REG8 __byte3;
    };
  };

  struct
  {
    union
    {
      struct{
        __REG16 P3_0   : 1;
        __REG16 P3_1   : 1;
        __REG16 P3_2   : 1;
        __REG16 P3_3   : 1;
        __REG16 P3_4   : 1;
        __REG16 P3_5   : 1;
        __REG16 P3_6   : 1;
        __REG16 P3_7   : 1;
        __REG16 P3_8   : 1;
        __REG16 P3_9   : 1;
        __REG16 P3_10  : 1;
        __REG16 P3_11  : 1;
        __REG16 P3_12  : 1;
        __REG16 P3_13  : 1;
        __REG16 P3_14  : 1;
        __REG16 P3_15  : 1;
      } __shortl_bit;
      __REG16 __shortl;
    };
    union
    {
      struct{
        __REG16 P3_0   : 1;
        __REG16 P3_1   : 1;
        __REG16 P3_2   : 1;
        __REG16 P3_3   : 1;
        __REG16 P3_4   : 1;
        __REG16 P3_5   : 1;
        __REG16 P3_6   : 1;
        __REG16 P3_7   : 1;
        __REG16 P3_8   : 1;
        __REG16 P3_9   : 1;
        __REG16 P3_10  : 1;
        __REG16 P3_11  : 1;
        __REG16 P3_12  : 1;
        __REG16 P3_13  : 1;
        __REG16 P3_14  : 1;
        __REG16 P3_15  : 1;
      } __shortu_bit;
      __REG16 __shortu;
    };
  };
} __fgpio3_bits;

/* FGPIO 4 Registers*/
typedef union{
  struct {
    __REG32 P4_0   : 1;
    __REG32 P4_1   : 1;
    __REG32 P4_2   : 1;
    __REG32 P4_3   : 1;
    __REG32 P4_4   : 1;
    __REG32 P4_5   : 1;
    __REG32 P4_6   : 1;
    __REG32 P4_7   : 1;
    __REG32 P4_8   : 1;
    __REG32 P4_9   : 1;
    __REG32 P4_10  : 1;
    __REG32 P4_11  : 1;
    __REG32 P4_12  : 1;
    __REG32 P4_13  : 1;
    __REG32 P4_14  : 1;
    __REG32 P4_15  : 1;
    __REG32 P4_16  : 1;
    __REG32 P4_17  : 1;
    __REG32 P4_18  : 1;
    __REG32 P4_19  : 1;
    __REG32 P4_20  : 1;
    __REG32 P4_21  : 1;
    __REG32 P4_22  : 1;
    __REG32 P4_23  : 1;
    __REG32 P4_24  : 1;
    __REG32 P4_25  : 1;
    __REG32 P4_26  : 1;
    __REG32 P4_27  : 1;
    __REG32 P4_28  : 1;
    __REG32 P4_29  : 1;
    __REG32 P4_30  : 1;
    __REG32 P4_31  : 1;
  };

  struct
  {
    union
    {
      struct{
        __REG8  P4_0   : 1;
        __REG8  P4_1   : 1;
        __REG8  P4_2   : 1;
        __REG8  P4_3   : 1;
        __REG8  P4_4   : 1;
        __REG8  P4_5   : 1;
        __REG8  P4_6   : 1;
        __REG8  P4_7   : 1;
      } __byte0_bit;
      __REG8 __byte0;
    };
    union
    {
      struct{
        __REG8  P4_0   : 1;
        __REG8  P4_1   : 1;
        __REG8  P4_2   : 1;
        __REG8  P4_3   : 1;
        __REG8  P4_4   : 1;
        __REG8  P4_5   : 1;
        __REG8  P4_6   : 1;
        __REG8  P4_7   : 1;
      } __byte1_bit;
      __REG8 __byte1;
    };
    union
    {
      struct{
        __REG8  P4_0   : 1;
        __REG8  P4_1   : 1;
        __REG8  P4_2   : 1;
        __REG8  P4_3   : 1;
        __REG8  P4_4   : 1;
        __REG8  P4_5   : 1;
        __REG8  P4_6   : 1;
        __REG8  P4_7   : 1;
      } __byte2_bit;
      __REG8 __byte2;
    };
    union
    {
      struct{
        __REG8  P4_0   : 1;
        __REG8  P4_1   : 1;
        __REG8  P4_2   : 1;
        __REG8  P4_3   : 1;
        __REG8  P4_4   : 1;
        __REG8  P4_5   : 1;
        __REG8  P4_6   : 1;
        __REG8  P4_7   : 1;
      } __byte3_bit;
      __REG8 __byte3;
    };
  };

  struct
  {
    union
    {
      struct{
        __REG16 P4_0   : 1;
        __REG16 P4_1   : 1;
        __REG16 P4_2   : 1;
        __REG16 P4_3   : 1;
        __REG16 P4_4   : 1;
        __REG16 P4_5   : 1;
        __REG16 P4_6   : 1;
        __REG16 P4_7   : 1;
        __REG16 P4_8   : 1;
        __REG16 P4_9   : 1;
        __REG16 P4_10  : 1;
        __REG16 P4_11  : 1;
        __REG16 P4_12  : 1;
        __REG16 P4_13  : 1;
        __REG16 P4_14  : 1;
        __REG16 P4_15  : 1;
      } __shortl_bit;
      __REG16 __shortl;
    };
    union
    {
      struct{
        __REG16 P4_0   : 1;
        __REG16 P4_1   : 1;
        __REG16 P4_2   : 1;
        __REG16 P4_3   : 1;
        __REG16 P4_4   : 1;
        __REG16 P4_5   : 1;
        __REG16 P4_6   : 1;
        __REG16 P4_7   : 1;
        __REG16 P4_8   : 1;
        __REG16 P4_9   : 1;
        __REG16 P4_10  : 1;
        __REG16 P4_11  : 1;
        __REG16 P4_12  : 1;
        __REG16 P4_13  : 1;
        __REG16 P4_14  : 1;
        __REG16 P4_15  : 1;
      } __shortu_bit;
      __REG16 __shortu;
    };
  };
} __fgpio4_bits;

/* GPIO overall Interrupt Status register */
typedef struct{
__REG32 P0INT  : 1;
__REG32        : 1;
__REG32 P1INT  : 1;
__REG32        :29;
}__iointst_bits;

/* MAC Configuration Register 1 */
typedef struct{
__REG32 RE        : 1;
__REG32 PARF      : 1;
__REG32 RXFC      : 1;
__REG32 TXFC      : 1;
__REG32 LB        : 1;
__REG32           : 3;
__REG32 RSTTX     : 1;
__REG32 RSTMCSTX  : 1;
__REG32 RSTRX     : 1;
__REG32 RSTMCSRX  : 1;
__REG32           : 2;
__REG32 SRST      : 1;
__REG32 SOFTRST   : 1;
__REG32           :16;
}__mac1_bits;

/* MAC Configuration Register 2 */
typedef struct{
__REG32 FD        : 1;
__REG32 FLC       : 1;
__REG32 HFE       : 1;
__REG32 DLYCRC    : 1;
__REG32 CRCEN     : 1;
__REG32 PADCRCEN  : 1;
__REG32 VLANCRCEN : 1;
__REG32 ADPE      : 1;
__REG32 PPE       : 1;
__REG32 LPE       : 1;
__REG32           : 2;
__REG32 NOBACKOFF : 1;
__REG32 BP        : 1;
__REG32 ED        : 1;
__REG32           :17;
}__mac2_bits;

/* Back-to-Back Inter-Packet-Gap Register */
typedef struct{
__REG32 IPG       : 7;
__REG32           :25;
}__ipgt_bits;

/* Non Back-to-Back Inter-Packet-Gap Register */
typedef struct{
__REG32 IPGR2     : 7;
__REG32           : 1;
__REG32 IPGR1     : 7;
__REG32           :17;
}__ipgr_bits;

/*Collision Window / Retry Register */
typedef struct{
__REG32 RM        : 4;
__REG32           : 4;
__REG32 CW        : 6;
__REG32           :18;
}__clrt_bits;

/* Maximum Frame Register */
typedef struct{
__REG32 MAXF      :16;
__REG32           :16;
}__maxf_bits;

/* PHY Support Register */
typedef struct{
__REG32             : 8;
__REG32 SPEED       : 1;
__REG32             :23;
}__supp_bits;

/* Test Register */
typedef struct{
__REG32 SPQ         : 1;
__REG32 TP          : 1;
__REG32 TB          : 1;
__REG32             :29;
}__test_bits;

/* MII Mgmt Configuration Register */
typedef struct{
__REG32 SI          : 1;
__REG32 SP          : 1;
__REG32 CS          : 3;
__REG32             :10;
__REG32 RSTMIIMGMT  : 1;
__REG32             :16;
}__mcfg_bits;

/* MII Mgmt Command Register */
typedef struct{
__REG32 READ        : 1;
__REG32 SCAN        : 1;
__REG32             :30;
}__mcmd_bits;

/* MII Mgmt Address Register */
typedef struct{
__REG32 REGADDR     : 5;
__REG32             : 3;
__REG32 PHY_ADDR    : 5;
__REG32             :19;
}__madr_bits;

/* MII Mgmt Write Data Register */
typedef struct{
__REG32 WRITEDATA   :16;
__REG32             :16;
}__mwtd_bits;

/* MII Mgmt Read Data Register */
typedef struct{
__REG32 READDATA    :16;
__REG32             :16;
}__mrdd_bits;

/* MII Mgmt Indicators Register */
typedef struct{
__REG32 BUSY          : 1;
__REG32 SCANNING      : 1;
__REG32 NOT_VALID     : 1;
__REG32 MII_LINC_FAIL : 1;
__REG32               :28;
}__mind_bits;

/* Station Address 0 Register */
typedef struct{
__REG32 STATION_ADDR_2  : 8;
__REG32 STATION_ADDR_1  : 8;
__REG32                 :16;
}__sa0_bits;

/* Station Address 1 Register */
typedef struct{
__REG32 STATION_ADDR_4  : 8;
__REG32 STATION_ADDR_3  : 8;
__REG32                 :16;
}__sa1_bits;

/* Station Address 2 Register */
typedef struct{
__REG32 STATION_ADDR_6  : 8;
__REG32 STATION_ADDR_5  : 8;
__REG32                 :16;
}__sa2_bits;

/* Command Register */
typedef struct{
__REG32 RXENABLE        : 1;
__REG32 TXENABLE        : 1;
__REG32                 : 1;
__REG32 REGRESET        : 1;
__REG32 TXRESET         : 1;
__REG32 RXRESET         : 1;
__REG32 PASSRUNTFRAME   : 1;
__REG32 PASSRXFILTER    : 1;
__REG32 TXFLOWCONTROL   : 1;
__REG32 RMII            : 1;
__REG32 FULLDUPLEX      : 1;
__REG32                 :21;
}__command_bits;

/* Status Register */
typedef struct{
__REG32 RXSTATUS        : 1;
__REG32 TXSTATUS        : 1;
__REG32                 :30;
}__status_bits;

/* Receive Number of Descriptors Register */
typedef struct{
__REG32 RXDESCRIPTORNUMBER  :16;
__REG32                     :16;
}__rxdescrn_bits;

/* Receive Produce Index Register */
typedef struct{
__REG32 RXPRODUCDINDEX  :16;
__REG32                 :16;
}__rxprodind_bits;

/* Receive Consume Index Register */
typedef struct{
__REG32 RXCONSUMEINDEX  :16;
__REG32                 :16;
}__rxcomind_bits;

/* Transmit Number of Descriptors Register */
typedef struct{
__REG32 TXDESCRIPTORNUMBER  :16;
__REG32                     :16;
}__txdescrn_bits;

/* Transmit Produce Index Register */
typedef struct{
__REG32 TXPRODUCDINDEX  :16;
__REG32                 :16;
}__txprodind_bits;

/* Transmit Consume Index Register */
typedef struct{
__REG32 TXCONSUMEINDEX  :16;
__REG32                 :16;
}__txcomind_bits;

/* Transmit Status Vector 0 Register */
typedef struct{
__REG32 CCR_ERR         : 1;
__REG32 LCERR           : 1;
__REG32 LOOR            : 1;
__REG32 DONE            : 1;
__REG32 MULTICAST       : 1;
__REG32 BROADCAST       : 1;
__REG32 PD              : 1;
__REG32 ED              : 1;
__REG32 EC              : 1;
__REG32 LC              : 1;
__REG32 GIANT           : 1;
__REG32 UNDERRUN        : 1;
__REG32 TB              :16;
__REG32 CF              : 1;
__REG32 PAUSE           : 1;
__REG32 BACKPRESSURE    : 1;
__REG32 VLAN            : 1;
}__tsv0_bits;

/* Transmit Status Vector 1 Register */
typedef struct{
__REG32 TBC             :16;
__REG32 TCC             : 4;
__REG32                 :12;
}__tsv1_bits;

/* Receive Status Vector Register */
typedef struct{
__REG32 RBC             :16;
__REG32 PPI             : 1;
__REG32 RXDVEPS         : 1;
__REG32 CEPS            : 1;
__REG32 RCV             : 1;
__REG32 CRC_ERR         : 1;
__REG32 LCE             : 1;
__REG32 LOOR            : 1;
__REG32 R_OK            : 1;
__REG32 MULTICAST       : 1;
__REG32 BROADCAST       : 1;
__REG32 DN              : 1;
__REG32 CF              : 1;
__REG32 PAUSE           : 1;
__REG32 UO              : 1;
__REG32 VLAN            : 1;
__REG32                 : 1;
}__rsv_bits;

/* Flow Control Counter Register */
typedef struct{
__REG32 MC              :16;
__REG32 PT              :16;
}__fwctrlcnt_bits;

/* Flow Control Status Register */
typedef struct{
__REG32 MCC             :16;
__REG32                 :16;
}__fwctrlstat_bits;

/* Receive Filter Control Register */
typedef struct{
__REG32 AUE             : 1;
__REG32 ABE             : 1;
__REG32 AME             : 1;
__REG32 AUHE            : 1;
__REG32 AMHE            : 1;
__REG32 APE             : 1;
__REG32                 : 6;
__REG32 MPEWOL          : 1;
__REG32 RXFEWOL         : 1;
__REG32                 :18;
}__rxflctrl_bits;

/* Receive Filter WoL Status Register */
typedef struct{
__REG32 AUWOL           : 1;
__REG32 ABWOL           : 1;
__REG32 AMWOL           : 1;
__REG32 AUHWOL          : 1;
__REG32 AMHWOL          : 1;
__REG32 APWOL           : 1;
__REG32                 : 1;
__REG32 RXFWOL          : 1;
__REG32 MPWOL           : 1;
__REG32                 :23;
}__rxflwolstat_bits;

/* Receive Filter WoL Clear Register */
typedef struct{
__REG32 AUWOLC          : 1;
__REG32 ABWOLC          : 1;
__REG32 AMWOLC          : 1;
__REG32 AUHWOLC         : 1;
__REG32 AMHWOLC         : 1;
__REG32 APWOLC          : 1;
__REG32                 : 1;
__REG32 RXFWOLC         : 1;
__REG32 MPWOLC          : 1;
__REG32                 :23;
}__rxflwolclr_bits;

/* Interrupt Status Register */
typedef struct{
__REG32 RXOVERRUNINT    : 1;
__REG32 RXERRORINT      : 1;
__REG32 RXFINISHEDINT   : 1;
__REG32 RXDONEINT       : 1;
__REG32 TXUNDERRUNINT   : 1;
__REG32 TXERRORINT      : 1;
__REG32 TXFINISHEDINT   : 1;
__REG32 TXDONEINT       : 1;
__REG32                 : 4;
__REG32 SOFTINT         : 1;
__REG32 WAKEUPINT       : 1;
__REG32                 :18;
}__intstat_bits;

/* Interrupt Enable Register */
typedef struct{
__REG32 RXOVERRUNINTEN  : 1;
__REG32 RXERRORINTEN    : 1;
__REG32 RXFINISHEDINTEN : 1;
__REG32 RXDONEINTEN     : 1;
__REG32 TXUNDERRUNINTEN : 1;
__REG32 TXERRORINTEN    : 1;
__REG32 TXFINISHEDINTEN : 1;
__REG32 TXDONEINTEN     : 1;
__REG32                 : 4;
__REG32 SOFTINTEN       : 1;
__REG32 WAKEUPINTEN     : 1;
__REG32                 :18;
}__intena_bits;

/* Interrupt Clear Register */
typedef struct{
__REG32 RXOVERRUNINTCLR : 1;
__REG32 RXERRORINTCLR   : 1;
__REG32 RXFINISHEDINTCLR: 1;
__REG32 RXDONEINTCLR    : 1;
__REG32 TXUNDERRUNINTCLR: 1;
__REG32 TXERRORINTCLR   : 1;
__REG32 TXFINISHEDINTCLR: 1;
__REG32 TXDONEINTCLR    : 1;
__REG32                 : 4;
__REG32 SOFTINTCLR      : 1;
__REG32 WAKEUPINTCLR    : 1;
__REG32                 :18;
}__intclr_bits;

/* Interrupt Set Register */
typedef struct{
__REG32 RXOVERRUNINTSET : 1;
__REG32 RXERRORINTSET   : 1;
__REG32 RXFINISHEDINTSET: 1;
__REG32 RXDONEINTSET    : 1;
__REG32 TXUNDERRUNINTSET: 1;
__REG32 TXERRORINTSET   : 1;
__REG32 TXFINISHEDINTSET: 1;
__REG32 TXDONEINTSET    : 1;
__REG32                 : 4;
__REG32 SOFTINTSET      : 1;
__REG32 WAKEUPINTSET    : 1;
__REG32                 :18;
}__intset_bits;

/* Power Down Register */
typedef struct{
__REG32                 :31;
__REG32 POWERDOWN       : 1;
}__pwrdn_bits;


/* USB - Device Interrupt Status Register */
typedef struct {
  __REG32 PORTSEL           : 2;
  __REG32                   :30;
} __usbportsel_bits;

/* USB Clock Control register (USBClkCtrl - 0xFFE0 CFF4) 
   USB Clock Status register (USBClkSt - 0xFFE0 CFF8) */
typedef struct{
__REG32                 : 1;
__REG32 DEV_CLK_EN      : 1;
__REG32                 : 1;
__REG32 PORTSEL_CLK_EN  : 1;
__REG32 AHB_CLK_EN      : 1;
__REG32                 :27;
} __usbclkctrl_bits;

/* USB - Device Interrupt Status Register */
typedef struct {
  __REG32 USB_INT_REQ_LP    : 1;
  __REG32 USB_INT_REQ_HP    : 1;
  __REG32 USB_INT_REQ_DMA   : 1;
  __REG32                   : 5;
  __REG32 USB_NEED_CLOCK    : 1;
  __REG32                   :22;
  __REG32 EN_USB_INTS       : 1;
} __usbints_bits;

/* USB - Device Interrupt Status Register */
/* USB - Device Interrupt Enable Register */
/* USB - Device Interrupt Clear Register */
/* USB - Device Interrupt Set Register */
typedef struct {
  __REG32 FRAME             : 1;
  __REG32 EP_FAST           : 1;
  __REG32 EP_SLOW           : 1;
  __REG32 DEV_STAT          : 1;
  __REG32 CCEMTY            : 1;
  __REG32 CDFULL            : 1;
  __REG32 RXENDPKT          : 1;
  __REG32 TXENDPKT          : 1;
  __REG32 EP_RLZED          : 1;
  __REG32 ERR_INT           : 1;
  __REG32                   :22;
} __usbdevintst_bits;

/* USB - Device Interrupt Priority Register */
typedef struct {
  __REG8  FRAME             : 1;
  __REG8  EP_FAST           : 1;
  __REG8                    : 6;
} __usbdevintpri_bits;

/* USB - Endpoint Interrupt Status Register */
/* USB - Endpoint Interrupt Enable Register */
/* USB - Endpoint Interrupt Clear Register */
/* USB - Endpoint Interrupt Set Register */
/* USB - Endpoint Interrupt Priority Register */
typedef struct {
  __REG32 EP_0RX            : 1;
  __REG32 EP_0TX            : 1;
  __REG32 EP_1RX            : 1;
  __REG32 EP_1TX            : 1;
  __REG32 EP_2RX            : 1;
  __REG32 EP_2TX            : 1;
  __REG32 EP_3RX            : 1;
  __REG32 EP_3TX            : 1;
  __REG32 EP_4RX            : 1;
  __REG32 EP_4TX            : 1;
  __REG32 EP_5RX            : 1;
  __REG32 EP_5TX            : 1;
  __REG32 EP_6RX            : 1;
  __REG32 EP_6TX            : 1;
  __REG32 EP_7RX            : 1;
  __REG32 EP_7TX            : 1;
  __REG32 EP_8RX            : 1;
  __REG32 EP_8TX            : 1;
  __REG32 EP_9RX            : 1;
  __REG32 EP_9TX            : 1;
  __REG32 EP_10RX           : 1;
  __REG32 EP_10TX           : 1;
  __REG32 EP_11RX           : 1;
  __REG32 EP_11TX           : 1;
  __REG32 EP_12RX           : 1;
  __REG32 EP_12TX           : 1;
  __REG32 EP_13RX           : 1;
  __REG32 EP_13TX           : 1;
  __REG32 EP_14RX           : 1;
  __REG32 EP_14TX           : 1;
  __REG32 EP_15RX           : 1;
  __REG32 EP_15TX           : 1;
} __usbepintst_bits;

/* USB - Realize Enpoint Register */
/* USB - DMA Request Status Register */
/* USB - DMA Request Clear Register */
/* USB - DMA Request Set Regiser */
/* USB - EP DMA Status Register */
/* USB - EP DMA Enable Register */
/* USB - EP DMA Disable Register */
/* USB - New DD Request Interrupt Status Register */
/* USB - New DD Request Interrupt Clear Register */
/* USB - New DD Request Interrupt Set Register */
/* USB - End Of Transfer Interrupt Status Register */
/* USB - End Of Transfer Interrupt Clear Register */
/* USB - End Of Transfer Interrupt Set Register */
/* USB - System Error Interrupt Status Register */
/* USB - System Error Interrupt Clear Register */
/* USB - System Error Interrupt Set Register */
typedef struct {
  __REG32 EP0               : 1;
  __REG32 EP1               : 1;
  __REG32 EP2               : 1;
  __REG32 EP3               : 1;
  __REG32 EP4               : 1;
  __REG32 EP5               : 1;
  __REG32 EP6               : 1;
  __REG32 EP7               : 1;
  __REG32 EP8               : 1;
  __REG32 EP9               : 1;
  __REG32 EP10              : 1;
  __REG32 EP11              : 1;
  __REG32 EP12              : 1;
  __REG32 EP13              : 1;
  __REG32 EP14              : 1;
  __REG32 EP15              : 1;
  __REG32 EP16              : 1;
  __REG32 EP17              : 1;
  __REG32 EP18              : 1;
  __REG32 EP19              : 1;
  __REG32 EP20              : 1;
  __REG32 EP21              : 1;
  __REG32 EP22              : 1;
  __REG32 EP23              : 1;
  __REG32 EP24              : 1;
  __REG32 EP25              : 1;
  __REG32 EP26              : 1;
  __REG32 EP27              : 1;
  __REG32 EP28              : 1;
  __REG32 EP29              : 1;
  __REG32 EP30              : 1;
  __REG32 EP31              : 1;
} __usbreep_bits;

/* USB - Endpoint Index Register */
typedef struct {
  __REG32 PHY_ENDP          : 5;
  __REG32                   :27;
} __usbepin_bits;

/* USB - MaxPacketSize Register */
typedef struct {
  __REG32 MPS               :10;
  __REG32                   :22;
} __usbmaxpsize_bits;

/* USB - Receive Packet Length Register */
typedef struct {
  __REG32 PKT_LNGTH         :10;
  __REG32 DV                : 1;
  __REG32 PKT_RDY           : 1;
  __REG32                   :20;
} __usbrxplen_bits;

/* USB - Transmit Packet Length Register */
typedef struct {
  __REG32 PKT_LNGHT         :10;
  __REG32                   :22;
} __usbtxplen_bits;

/* USB - Control Register */
typedef struct {
  __REG32 RD_EN             : 1;
  __REG32 WR_EN             : 1;
  __REG32 LOG_ENDPOINT      : 4;
  __REG32                   :26;
} __usbctrl_bits;

/* USB - Command Code Register */
typedef struct {
  __REG32                   : 8;
  __REG32 CMD_PHASE         : 8;
  __REG32 CMD_CODE          : 8;
  __REG32                   : 8;
} __usbcmdcode_bits;

/* USB - Command Data Register */
typedef struct {
  __REG32 CMD_DATA          : 8;
  __REG32                   :24;
} __usbcmddata_bits;

/* USB - DMA Interrupt Status Register */
/* USB - DMA Interrupt Enable Register */
typedef struct {
  __REG32 EOT       : 1;
  __REG32 NDDR      : 1;
  __REG32 ERR       : 1;
  __REG32           :29;
} __usbdmaintst_bits;

/* CAN acceptance filter mode register */
typedef struct {
  __REG32 ACCOFF          :1;
  __REG32 ACCBP           :1;
  __REG32 EFCAN           :1;
  __REG32                 :29;
} __afmr_bits;

/* Global FullCANInterrupt Enable register */
typedef struct {
  __REG32 FCANIE          :1;
  __REG32                 :31;
} __fcanie_bits;

/* FullCAN Interrupt and Capture registers 0 */
typedef struct {
  __REG32 INTPND0         :1;
  __REG32 INTPND1         :1;
  __REG32 INTPND2         :1;
  __REG32 INTPND3         :1;
  __REG32 INTPND4         :1;
  __REG32 INTPND5         :1;
  __REG32 INTPND6         :1;
  __REG32 INTPND7         :1;
  __REG32 INTPND8         :1;
  __REG32 INTPND9         :1;
  __REG32 INTPND10        :1;
  __REG32 INTPND11        :1;
  __REG32 INTPND12        :1;
  __REG32 INTPND13        :1;
  __REG32 INTPND14        :1;
  __REG32 INTPND15        :1;
  __REG32 INTPND16        :1;
  __REG32 INTPND17        :1;
  __REG32 INTPND18        :1;
  __REG32 INTPND19        :1;
  __REG32 INTPND20        :1;
  __REG32 INTPND21        :1;
  __REG32 INTPND22        :1;
  __REG32 INTPND23        :1;
  __REG32 INTPND24        :1;
  __REG32 INTPND25        :1;
  __REG32 INTPND26        :1;
  __REG32 INTPND27        :1;
  __REG32 INTPND28        :1;
  __REG32 INTPND29        :1;
  __REG32 INTPND30        :1;
  __REG32 INTPND31        :1;
} __fcanic0_bits;

/* FullCAN Interrupt and Capture registers 1 */
typedef struct {
  __REG32 INTPND32        :1;
  __REG32 INTPND33        :1;
  __REG32 INTPND34        :1;
  __REG32 INTPND35        :1;
  __REG32 INTPND36        :1;
  __REG32 INTPND37        :1;
  __REG32 INTPND38        :1;
  __REG32 INTPND39        :1;
  __REG32 INTPND40        :1;
  __REG32 INTPND41        :1;
  __REG32 INTPND42        :1;
  __REG32 INTPND43        :1;
  __REG32 INTPND44        :1;
  __REG32 INTPND45        :1;
  __REG32 INTPND46        :1;
  __REG32 INTPND47        :1;
  __REG32 INTPND48        :1;
  __REG32 INTPND49        :1;
  __REG32 INTPND50        :1;
  __REG32 INTPND51        :1;
  __REG32 INTPND52        :1;
  __REG32 INTPND53        :1;
  __REG32 INTPND54        :1;
  __REG32 INTPND55        :1;
  __REG32 INTPND56        :1;
  __REG32 INTPND57        :1;
  __REG32 INTPND58        :1;
  __REG32 INTPND59        :1;
  __REG32 INTPND60        :1;
  __REG32 INTPND61        :1;
  __REG32 INTPND62        :1;
  __REG32 INTPND63        :1;
} __fcanic1_bits;

/* CAN central transmit status register */
typedef struct {
  __REG32 TS1             : 1;
  __REG32 TS2             : 1;
  __REG32                 : 6;
  __REG32 TBS1            : 1;
  __REG32 TBS2            : 1;
  __REG32                 : 6;
  __REG32 TCS1            : 1;
  __REG32 TCS2            : 1;
  __REG32                 :14;
} __cantxsr_bits;

/* CAN central receive status register */
typedef struct {
  __REG32 RS1             : 1;
  __REG32 RS2             : 1;
  __REG32                 : 6;
  __REG32 RBS1            : 1;
  __REG32 RBS2            : 1;
  __REG32                 : 6;
  __REG32 DOS1            : 1;
  __REG32 DOS2            : 1;
  __REG32                 :14;
} __canrxsr_bits;

/* CAN miscellaneous status register */
typedef struct {
  __REG32 ES1             : 1;
  __REG32 ES2             : 1;
  __REG32                 : 6;
  __REG32 BS1             : 1;
  __REG32 BS2             : 1;
  __REG32                 :22;
} __canmsr_bits;

/* CAN mode register */
typedef struct {
  __REG32 RM              :1;
  __REG32 LOM             :1;
  __REG32 STM             :1;
  __REG32 TPM             :1;
  __REG32 SM              :1;
  __REG32 RPM             :1;
  __REG32                 :1;
  __REG32 TM              :1;
  __REG32                 :24;
} __canmod_bits;

/* CAN command register */
typedef struct {
  __REG32 TR              :1;
  __REG32 AT              :1;
  __REG32 RRB             :1;
  __REG32 CDO             :1;
  __REG32 SRR             :1;
  __REG32 STB1            :1;
  __REG32 STB2            :1;
  __REG32 STB3            :1;
  __REG32                 :24;
} __cancmr_bits;

/* CAN global status register */
typedef struct {
  __REG32 RBS              :1;
  __REG32 DOS              :1;
  __REG32 TBS              :1;
  __REG32 TCS              :1;
  __REG32 RS               :1;
  __REG32 TS               :1;
  __REG32 ES               :1;
  __REG32 BS               :1;
  __REG32                  :8;
  __REG32 RXERR            :8;
  __REG32 TXERR            :8;
} __cangsr_bits;

/* CAN interrupt capture register */
typedef struct {
  __REG32 RI               :1;
  __REG32 TI1              :1;
  __REG32 EI               :1;
  __REG32 DOI              :1;
  __REG32 WUI              :1;
  __REG32 EPI              :1;
  __REG32 ALI              :1;
  __REG32 BEI              :1;
  __REG32 IDI              :1;
  __REG32 TI2              :1;
  __REG32 TI3              :1;
  __REG32                  :5;
  __REG32 ERRBIT           :5;
  __REG32 ERRDIR           :1;
  __REG32 ERRC             :2;
  __REG32 ALCBIT           :8;
} __canicr_bits;

/* CAN interrupt enable register */
typedef struct {
  __REG32 RIE               :1;
  __REG32 TIE1              :1;
  __REG32 EIE               :1;
  __REG32 DOIE              :1;
  __REG32 WUIE              :1;
  __REG32 EPIE              :1;
  __REG32 ALIE              :1;
  __REG32 BEIE              :1;
  __REG32 IDIE              :1;
  __REG32 TIE2              :1;
  __REG32 TIE3              :1;
  __REG32                   :21;
} __canier_bits;

/* CAN bus timing register */
typedef struct {
  __REG32 BRP                :10;
  __REG32                    :4;
  __REG32 SJW                :2;
  __REG32 TSEG1              :4;
  __REG32 TSEG2              :3;
  __REG32 SAM                :1;
  __REG32                    :8;
} __canbtr_bits;

/* CAN error warning limit register */
typedef struct {
  __REG32 EWL                :8;
  __REG32                    :24;
} __canewl_bits;

/* CAN status register */
typedef struct {
  __REG32 RBS                :1;
  __REG32 DOS                :1;
  __REG32 TBS1               :1;
  __REG32 TCS1               :1;
  __REG32 RS                 :1;
  __REG32 TS1                :1;
  __REG32 ES                 :1;
  __REG32 BS                 :1;
  __REG32 /*RBS*/            :1;
  __REG32 /*DOS*/            :1;
  __REG32 TBS2               :1;
  __REG32 TCS2               :1;
  __REG32 /*RS*/             :1;
  __REG32 TS2                :1;
  __REG32 /*ES*/             :1;
  __REG32 /*BS*/             :1;
  __REG32 /*RBS*/            :1;
  __REG32 /*DOS*/            :1;
  __REG32 TBS3               :1;
  __REG32 TCS3               :1;
  __REG32 /*RS*/             :1;
  __REG32 TS3                :1;
  __REG32 /*ES*/             :1;
  __REG32 /*BS*/             :1;
  __REG32                    :8;
} __cansr_bits;

/* CAN rx frame status register */
typedef struct {
  __REG32 IDINDEX            :10;
  __REG32 BP                 :1;
  __REG32                    :5;
  __REG32 DLC                :4;
  __REG32                    :10;
  __REG32 RTR                :1;
  __REG32 FF                 :1;
} __canrfs_bits;

/* CAN rx identifier register */
typedef union {
  //CANxRID
  struct {
   __REG32 ID10_0             :11;
   __REG32                    :21;
  };
  //CANxRID
  struct {
   __REG32 ID29_18            :11;
   __REG32                    :21;
  };
  //)   //RID
  struct {
   __REG32 ID29_0             :29;
   __REG32                    :3;
  };
} __canrid_bits;

/* CAN rx data register A */
typedef struct {
  __REG32 DATA1               :8;
  __REG32 DATA2               :8;
  __REG32 DATA3               :8;
  __REG32 DATA4               :8;
} __canrda_bits;

/* CAN rx data register B */
typedef struct {
  __REG32 DATA5               :8;
  __REG32 DATA6               :8;
  __REG32 DATA7               :8;
  __REG32 DATA8               :8;
} __canrdb_bits;

/* CAN tx frame information register */
typedef struct {
  __REG32 PRIO              :8;
  __REG32                   :8;
  __REG32 DLC               :4;
  __REG32                   :10;
  __REG32 RTR               :1;
  __REG32 FF                :1;
} __cantfi_bits;

/* CAN tx identifier register */
typedef union {
  //CANxTIDy
  struct {
   __REG32 ID10_0             :11;
   __REG32                    :21;
  };
  //CANxTIDy
  struct {
   __REG32 ID29_18            :11;
   __REG32                    :21;
  };
  //CANxTIDy
  struct {
   __REG32 ID29_0             :29;
   __REG32                    :3;
  };
} __cantid_bits;

/* CAN tx data register A */
typedef struct {
  __REG32 DATA1               :8;
  __REG32 DATA2               :8;
  __REG32 DATA3               :8;
  __REG32 DATA4               :8;
} __cantda_bits;

/* CAN tx data register B */
typedef struct {
  __REG32 DATA5               :8;
  __REG32 DATA6               :8;
  __REG32 DATA7               :8;
  __REG32 DATA8               :8;
} __cantdb_bits;

/* UART interrupt enable register */
typedef struct{
__REG32 RDAIE     : 1;
__REG32 THREIE    : 1;
__REG32 RXLSIE    : 1;
__REG32           : 5;
__REG32 ABTOINTEN : 1;
__REG32 ABEOINTEN : 1;
__REG32           :22;
} __uartier0_bits;

/* UART1 interrupt enable register */
typedef struct{
__REG32 RDAIE     : 1;
__REG32 THREIE    : 1;
__REG32 RXLSIE    : 1;
__REG32 RXMSIE    : 1;
__REG32           : 3;
__REG32 CTSIE     : 1;
__REG32 ABTOINTEN : 1;
__REG32 ABEOINTEN : 1;
__REG32           :22;
} __uartier1_bits;

/* UART Transmit Enable Register */
typedef struct{
__REG8        : 7;
__REG8  TXEN  : 1;
} __uartter_bits;

/* UART line status register */
typedef struct{
__REG8  DR    : 1;
__REG8  OE    : 1;
__REG8  PE    : 1;
__REG8  FE    : 1;
__REG8  BI    : 1;
__REG8  THRE  : 1;
__REG8  TEMT  : 1;
__REG8  RXFE  : 1;
} __uartlsr_bits;

/* UART line control register */
typedef struct{
__REG8  WLS   : 2;
__REG8  SBS   : 1;
__REG8  PE    : 1;
__REG8  PS    : 2;
__REG8  BC    : 1;
__REG8  DLAB  : 1;
} __uartlcr_bits;

/* UART interrupt identification register and fifo control register */
typedef union {
  //UxIIR
  struct {
__REG32 IP     : 1;
__REG32 IID    : 3;
__REG32        : 2;
__REG32 IIRFE  : 2;
__REG32 ABEOINT: 1;
__REG32 ABTOINT: 1;
__REG32        :22;
  };
  //UxFCR
  struct {
__REG32 FCRFE  : 1;
__REG32 RFR    : 1;
__REG32 TFR    : 1;
__REG32        : 3;
__REG32 RTLS   : 2;
__REG32        :24;
  };
} __uartfcriir_bits;

/* UART modem control register */
typedef struct{
__REG8  DTR   : 1;
__REG8  RTS   : 1;
__REG8        : 2;
__REG8  LMS   : 1;
__REG8        : 1;
__REG8  RTSEN : 1;
__REG8  CTSEN : 1;
} __uartmcr_bits;

/* UART modem status register */
typedef union{
  //UxMSR
  struct {
__REG8  DCTS  : 1;
__REG8  DDSR  : 1;
__REG8  TERI  : 1;
__REG8  DDCD  : 1;
__REG8  CTS   : 1;
__REG8  DSR   : 1;
__REG8  RI    : 1;
__REG8  DCD   : 1;
  };
  //UxMSR
  struct {
__REG8  MSR0  : 1;
__REG8  MSR1  : 1;
__REG8  MSR2  : 1;
__REG8  MSR3  : 1;
__REG8  MSR4  : 1;
__REG8  MSR5  : 1;
__REG8  MSR6  : 1;
__REG8  MSR7  : 1;
  };
} __uartmsr_bits;

/* UART Auto-baud Control Register */
typedef struct{
__REG32 START        : 1;
__REG32 MODE         : 1;
__REG32 AUTORESTART  : 1;
__REG32              : 5;
__REG32 ABEOINTCLR   : 1;
__REG32 ABTOINTCLR   : 1;
__REG32              :22;
} __uartacr_bits;

/* IrDA Control Register for UART3 Only */
typedef struct{
__REG32 IRDAEN       : 1;
__REG32 IRDAINV      : 1;
__REG32 FIXPULSEEN   : 1;
__REG32 PULSEDIV     : 3;
__REG32              :26;
} __uarticr_bits;

/* UART Fractional Divider Register */
typedef struct{
__REG32 DIVADDVAL  : 4;
__REG32 MULVAL     : 4;
__REG32            :24;
} __uartfdr_bits;

/* SPI control register */
typedef struct{
__REG32           : 2;
__REG32 BITENABLE : 1;
__REG32 CPHA      : 1;
__REG32 CPOL      : 1;
__REG32 MSTR      : 1;
__REG32 LSBF      : 1;
__REG32 SPIE      : 1;
__REG32 BITS      : 4;
__REG32           :20;
} __spcr_bits;

/* SPI status register */
typedef struct{
__REG32         : 3;
__REG32 ABRT    : 1;
__REG32 MODF    : 1;
__REG32 ROVR    : 1;
__REG32 WCOL    : 1;
__REG32 SPIF    : 1;
__REG32         :24;
} __spsr_bits;

/* SPI clock counter register */
typedef struct{
__REG32 COUNTER  : 8;
__REG32          :24;
} __spccr_bits;

/* SPI interrupt register */
typedef struct{
__REG32 SPIINT  : 1;
__REG32         :31;
} __spint_bits;

/* SPI Test control register */
typedef struct{
__REG8          : 1;
__REG8  TEST    : 7;
} __sptcr_bits;

/* SPI Test Status Register */
typedef struct{
__REG8          : 3;
__REG8  ABRT    : 1;
__REG8  MODF    : 1;
__REG8  ROVR    : 1;
__REG8  WCOL    : 1;
__REG8  SPIF    : 1;
} __sptsr_bits;

/* SSP Control Register 0 */
typedef struct{
__REG32 DSS  : 4;
__REG32 FRF  : 2;
__REG32 SPO  : 1;
__REG32 SPH  : 1;
__REG32 SCR  : 8;
__REG32      :16;
} __sspcr0_bits;

/* SSP Control Register 1 */
typedef struct{
__REG32 LBM  : 1;
__REG32 SSE  : 1;
__REG32 MS   : 1;
__REG32 SOD  : 1;
__REG32      :28;
} __sspcr1_bits;

/* SSP Data Register */
typedef struct{
__REG32 DATA :16;
__REG32      :16;
} __sspdr_bits;

/* SSP Status Register */
typedef struct{
__REG32 TFE  : 1;
__REG32 TNF  : 1;
__REG32 RNE  : 1;
__REG32 RFF  : 1;
__REG32 BSY  : 1;
__REG32      :27;
} __sspsr_bits;

/* SSP Clock Prescale Register */
typedef struct{
__REG32 CPSDVSR : 8;
__REG32         :24;
} __sspcpsr_bits;

/* SSP Interrupt Mask Set/Clear Register */
typedef struct{
__REG32 RORIM  : 1;
__REG32 RTIM   : 1;
__REG32 RXIM   : 1;
__REG32 TXIM   : 1;
__REG32        :28;
} __sspimsc_bits;

/* SSP Raw Interrupt Status Register */
typedef struct{
__REG32 RORRIS  : 1;
__REG32 RTRIS   : 1;
__REG32 RXRIS   : 1;
__REG32 TXRIS   : 1;
__REG32         :28;
} __sspris_bits;

/* SSP Masked Interrupt Status Register */
typedef struct{
__REG32 RORMIS  : 1;
__REG32 RTMIS   : 1;
__REG32 RXMIS   : 1;
__REG32 TXMIS   : 1;
__REG32         :28;
} __sspmis_bits;

/* SSP Interrupt Clear Register */
typedef struct{
__REG32 RORIC  : 1;
__REG32 RTIC   : 1;
__REG32        :30;
} __sspicr_bits;

/* SSP DMA Control Register */
typedef struct{
__REG32 RXDMAE : 1;
__REG32 TXDMAE : 1;
__REG32        :30;
} __sspdmacr_bits;

/* SD/MMC Power control register */
typedef struct{
__REG32 CTRL       : 2;
__REG32            : 4;
__REG32 OPENDRAIN  : 1;
__REG32 ROD        : 1;
__REG32            :24;
} __mcipower_bits;

/* SD/MMC Clock control register */
typedef struct{
__REG32 CLKDIV   : 8;
__REG32 ENABLE   : 1;
__REG32 PWRSAVE  : 1;
__REG32 BYPASS   : 1;
__REG32 WIDEBUS  : 1;
__REG32          :20;
} __mciclock_bits;

/* SD/MMC Command register */
typedef struct{
__REG32 CMDINDEX   : 6;
__REG32 RESPONSE   : 1;
__REG32 LONGRSP    : 1;
__REG32 INTERRUPT  : 1;
__REG32 PENDING    : 1;
__REG32 ENABLE     : 1;
__REG32            :21;
} __mcicommand_bits;

/* SD/MMC Command response register */
typedef struct{
__REG32 RESPCMD  : 6;
__REG32          :26;
} __mcirespcmd_bits;

/* SD/MMC Data control register */
typedef struct{
__REG32 ENABLE     : 1;
__REG32 DIRECTION  : 1;
__REG32 MODE       : 1;
__REG32 DMAENABLE  : 1;
__REG32 BLOCKSIZE  : 4;
__REG32            :24;
} __mcidatactrl_bits;

/* SD/MMC Status register */
typedef struct{
__REG32 CMDCRCFAIL       : 1;
__REG32 DATACRCFAIL      : 1;
__REG32 CMDTIMEOUT       : 1;
__REG32 DATATIMEOUT      : 1;
__REG32 TXUNDERRUN       : 1;
__REG32 RXOVERRUN        : 1;
__REG32 CMDRESPEND       : 1;
__REG32 CMDSENT          : 1;
__REG32 DATAEND          : 1;
__REG32 STARTBITERR      : 1;
__REG32 DATABLOCKEND     : 1;
__REG32 CMDACTIVE        : 1;
__REG32 TXACTIVE         : 1;
__REG32 RXACTIVE         : 1;
__REG32 TXFIFOHALFEMPTY  : 1;
__REG32 RXFIFOHALFFULL   : 1;
__REG32 TXFIFOFULL       : 1;
__REG32 RXFIFOFULL       : 1;
__REG32 TXFIFOEMPTY      : 1;
__REG32 RXFIFOEMPTY      : 1;
__REG32 TXDATAAVLBL      : 1;
__REG32 RXDATAAVLBL      : 1;
__REG32                  :10;
} __mcistatus_bits;

/* SD/MMC Clear register */
typedef struct{
__REG32 CMDCRCFAILCLR    : 1;
__REG32 DATACRCFAILCLR   : 1;
__REG32 CMDTIMEOUTCLR    : 1;
__REG32 DATATIMEOUTCLR   : 1;
__REG32 TXUNDERRUNCLR    : 1;
__REG32 RXOVERRUNCLR     : 1;
__REG32 CMDRESPENDCLR    : 1;
__REG32 CMDSENTCLR       : 1;
__REG32 DATAENDCLR       : 1;
__REG32 STARTBITERRCLR   : 1;
__REG32 DATABLOCKENDCLR  : 1;
__REG32                  :21;
} __mciclear_bits;

/* SD/MMC FIFO counter register */
typedef struct{
__REG32 DATACOUNT  :15;
__REG32            :17;
} __mcififocnt_bits;

/* I2C control set register */
typedef struct{
__REG32       : 2;
__REG32 AA    : 1;
__REG32 SI    : 1;
__REG32 STO   : 1;
__REG32 STA   : 1;
__REG32 I2EN  : 1;
__REG32       :25;
} __i2conset_bits;

/* I2C control clear register */
typedef struct{
__REG32        : 2;
__REG32 AAC    : 1;
__REG32 SIC    : 1;
__REG32        : 1;
__REG32 STAC   : 1;
__REG32 I2ENC  : 1;
__REG32        :25;
} __i2conclr_bits;

/* I2C status register */
typedef struct{
__REG32 STATUS  : 8;
__REG32         :24;
} __i2stat_bits;

/* I2C data register */
typedef struct{
__REG32 DATA  : 8;
__REG32       :24;
} __i2dat_bits;

/* I2C slave address register */
typedef struct{
__REG32 GC    : 1;
__REG32 ADDR  : 7;
__REG32       :24;
} __i2adr_bits;

/* I2C SCL High Duty Cycle register */
typedef struct{
__REG32 SCLH   :16;
__REG32        :16;
} __i2sch_bits;

/* I2C scl duty cycle register */
typedef struct{
__REG32 SCLL   :16;
__REG32        :16;
} __i2scl_bits;

/* I2S Digital Audio Output Registes */
typedef struct{
__REG32 WORS_WIDTH    : 2;
__REG32 MONO          : 1;
__REG32 STOP          : 1;
__REG32 RESET         : 1;
__REG32 WS_SEL        : 1;
__REG32 WS_HALFPERIOD : 9;
__REG32 MUTE          : 1;
__REG32               :16;
} __i2sdao_bits;

/* I2S Digital Audio Input Register */
typedef struct{
__REG32 WORS_WIDTH    : 2;
__REG32 MONO          : 1;
__REG32 STOP          : 1;
__REG32 RESET         : 1;
__REG32 WS_SEL        : 1;
__REG32 WS_HALFPERIOD : 9;
__REG32               :17;
} __i2sdai_bits;

/* I2S Status Feedback Register */
typedef struct{
__REG32 IRQ           : 1;
__REG32 DMAREQ1       : 1;
__REG32 DMAREQ2       : 1;
__REG32               : 5;
__REG32 RX_LEVEL      : 8;
__REG32 TX_LEVEL      : 8;
__REG32               : 8;
} __i2sstate_bits;

/* I2S DMA Configuration Register */
typedef struct{
__REG32 RX_DMA_EN     : 1;
__REG32 TX_DMA_EN     : 1;
__REG32               : 6;
__REG32 RX_DEPTH_DMA  : 8;
__REG32 TX_DEPTH_DMA  : 8;
__REG32               : 8;
} __i2sdma_bits;

/* I2S Interrupt Request Control register */
typedef struct{
__REG32 RX_IRQ_EN     : 1;
__REG32 TX_IRQ_EN     : 1;
__REG32               : 6;
__REG32 RX_DEPTH_IRQ  : 8;
__REG32 TX_DEPTH_IRQ  : 8;
__REG32               : 8;
} __i2sirq_bits;

/* I2S Transmit Clock Rate Register */
typedef struct{
__REG32 TX_RATE       :10;
__REG32               :22;
} __i2stxrate_bits;

/* I2S Receive Clock Rate Register */
typedef struct{
__REG32 RX_RATE       :10;
__REG32               :22;
} __i2srxrate_bits;

/* TIMER interrupt register */
typedef struct{
__REG32 MR0INT  : 1;
__REG32 MR1INT  : 1;
__REG32 MR2INT  : 1;
__REG32 MR3INT  : 1;
__REG32 CR0INT  : 1;
__REG32 CR1INT  : 1;
__REG32 CR2INT  : 1;
__REG32 CR3INT  : 1;
__REG32         :24;
} __ir_bits;

/* TIMER control register */
typedef struct{
__REG32 CE  : 1;
__REG32 CR  : 1;
__REG32     :30;
} __tcr_bits;

/* TIMER count control register */
typedef struct{
__REG32 CTM : 2;     //Counter/Timer Mode
__REG32 CIS : 2;     //Count Input Select
__REG32     :28;
} __ctcr_bits;

/* TIMER match control register */
typedef struct{
__REG32 MR0I     : 1;
__REG32 MR0R     : 1;
__REG32 MR0S     : 1;
__REG32 MR1I     : 1;
__REG32 MR1R     : 1;
__REG32 MR1S     : 1;
__REG32 MR2I     : 1;
__REG32 MR2R     : 1;
__REG32 MR2S     : 1;
__REG32 MR3I     : 1;
__REG32 MR3R     : 1;
__REG32 MR3S     : 1;
__REG32          :20;
} __mcr_bits;

/* TIMER capture control register */
typedef struct{
__REG32 CAP0RE   : 1;
__REG32 CAP0FE   : 1;
__REG32 CAP0I    : 1;
__REG32 CAP1RE   : 1;
__REG32 CAP1FE   : 1;
__REG32 CAP1I    : 1;
__REG32 CAP2RE   : 1;
__REG32 CAP2FE   : 1;
__REG32 CAP2I    : 1;
__REG32 CAP3RE   : 1;
__REG32 CAP3FE   : 1;
__REG32 CAP3I    : 1;
__REG32          :20;
} __ccr_bits;

/* TIMER external match register */
typedef struct{
__REG32 EM0   : 1;
__REG32 EM1   : 1;
__REG32 EM2   : 1;
__REG32 EM3   : 1;
__REG32 EMC0  : 2;
__REG32 EMC1  : 2;
__REG32 EMC2  : 2;
__REG32 EMC3  : 2;
__REG32       :20;
} __emr_bits;

/* Watchdog mode register */
typedef struct{
__REG32 WDEN     : 1;
__REG32 WDRESET  : 1;
__REG32 WDTOF    : 1;
__REG32 WDINT    : 1;
__REG32          :28;
} __wdmod_bits;

/* Watchdog feed register */
typedef struct{
__REG32 FEED  : 8;
__REG32       :24;
} __wdfeed_bits;

/* Watchdog feed register */
typedef struct{
__REG32 WDSEL : 2;
__REG32       :30;
} __wdclksel_bits;

/* A/D Control Register */
typedef struct{
__REG32 SEL     : 8;
__REG32 CLKDIV  : 8;
__REG32 BURST   : 1;
__REG32 CLKS    : 3;
__REG32         : 1;
__REG32 PDN     : 1;
__REG32         : 2;
__REG32 START   : 3;
__REG32 EDGE    : 1;
__REG32         : 4;
} __adcr_bits;

/* A/D Global Data Register */
typedef struct{
__REG32         : 6;
__REG32 RESULT  :10;
__REG32         : 8;
__REG32 CHN     : 3;
__REG32         : 3;
__REG32 OVERUN  : 1;
__REG32 DONE    : 1;
} __adgdr_bits;

/* A/D Status Register */
typedef struct{
__REG32 DONE0     : 1;
__REG32 DONE1     : 1;
__REG32 DONE2     : 1;
__REG32 DONE3     : 1;
__REG32 DONE4     : 1;
__REG32 DONE5     : 1;
__REG32 DONE6     : 1;
__REG32 DONE7     : 1;
__REG32 OVERRUN0  : 1;
__REG32 OVERRUN1  : 1;
__REG32 OVERRUN2  : 1;
__REG32 OVERRUN3  : 1;
__REG32 OVERRUN4  : 1;
__REG32 OVERRUN5  : 1;
__REG32 OVERRUN6  : 1;
__REG32 OVERRUN7  : 1;
__REG32 ADINT     : 1;
__REG32           :15;
} __adstat_bits;

/* A/D Intrrupt Enable Register */
typedef struct{
__REG32 ADINTEN0  : 1;
__REG32 ADINTEN1  : 1;
__REG32 ADINTEN2  : 1;
__REG32 ADINTEN3  : 1;
__REG32 ADINTEN4  : 1;
__REG32 ADINTEN5  : 1;
__REG32 ADINTEN6  : 1;
__REG32 ADINTEN7  : 1;
__REG32 ADGINTEN  : 1;
__REG32           :23;
} __adinten_bits;

/* A/D Data Register */
typedef struct{
__REG32         : 6;
__REG32 RESULT  :10;
__REG32         :14;
__REG32 OVERUN  : 1;
__REG32 DONE    : 1;
} __addr_bits;

/* D/A Converter Register */
typedef struct{
__REG32        : 6;
__REG32 VALUE  :10;
__REG32 BIAS   : 1;
__REG32        :15;
} __dacr_bits;

/* PWM interrupt register */
typedef struct{
__REG32 PWMMR0I : 1;
__REG32 PWMMR1I : 1;
__REG32 PWMMR2I : 1;
__REG32 PWMMR3I : 1;
__REG32         : 4;
__REG32 PWMMR4I : 1;
__REG32 PWMMR5I : 1;
__REG32 PWMMR6I : 1;
__REG32         :21;
} __pwmir_bits;

/* PWM1 timer control register */
typedef struct{
__REG32 CE     : 1;
__REG32 CR     : 1;
__REG32        : 1;
__REG32 PWMEN  : 1;
__REG32        :28;
} __pwmtcr1_bits;

/* PWM Count Control Register */
typedef struct{
__REG32 CM     : 2;
__REG32 CIS    : 2;
__REG32        :28;
} __pwmctcr_bits;

/* PWM match control register */
typedef struct{
__REG32 PWMMR0I  : 1;
__REG32 PWMMR0R  : 1;
__REG32 PWMMR0S  : 1;
__REG32 PWMMR1I  : 1;
__REG32 PWMMR1R  : 1;
__REG32 PWMMR1S  : 1;
__REG32 PWMMR2I  : 1;
__REG32 PWMMR2R  : 1;
__REG32 PWMMR2S  : 1;
__REG32 PWMMR3I  : 1;
__REG32 PWMMR3R  : 1;
__REG32 PWMMR3S  : 1;
__REG32 PWMMR4I  : 1;
__REG32 PWMMR4R  : 1;
__REG32 PWMMR4S  : 1;
__REG32 PWMMR5I  : 1;
__REG32 PWMMR5R  : 1;
__REG32 PWMMR5S  : 1;
__REG32 PWMMR6I  : 1;
__REG32 PWMMR6R  : 1;
__REG32 PWMMR6S  : 1;
__REG32          :11;
} __pwmmcr_bits;

/* PWM Capture Control Register */
typedef struct{
__REG32 CAP0RE   : 1;
__REG32 CAP0FE   : 1;
__REG32 CAP0INT  : 1;
__REG32 CAP1RE   : 1;
__REG32 CAP1FE   : 1;
__REG32 CAP1INT  : 1;
__REG32 CAP2RE   : 1;
__REG32 CAP2FE   : 1;
__REG32 CAP2INT  : 1;
__REG32 CAP3RE   : 1;
__REG32 CAP3FE   : 1;
__REG32 CAP3INT  : 1;
__REG32          :20;
} __pwmccr_bits;

/* PWM  control register */
typedef struct{
__REG32         : 2;
__REG32 PWMSEL2 : 1;
__REG32 PWMSEL3 : 1;
__REG32 PWMSEL4 : 1;
__REG32 PWMSEL5 : 1;
__REG32 PWMSEL6 : 1;
__REG32         : 2;
__REG32 PWMENA1 : 1;
__REG32 PWMENA2 : 1;
__REG32 PWMENA3 : 1;
__REG32 PWMENA4 : 1;
__REG32 PWMENA5 : 1;
__REG32 PWMENA6 : 1;
__REG32         :17;
} __pwmpcr_bits;

/* PWM latch enable register */
typedef struct{
__REG32 EM0L  : 1;
__REG32 EM1L  : 1;
__REG32 EM2L  : 1;
__REG32 EM3L  : 1;
__REG32 EM4L  : 1;
__REG32 EM5L  : 1;
__REG32 EM6L  : 1;
__REG32       :25;
} __pwmler_bits;

/* RTC interrupt location register */
typedef struct{
__REG32 RTCCIF  : 1;
__REG32 RTCALF  : 1;
__REG32 RTSSF   : 1;
__REG32         :29;
} __ilr_bits;

/* RTC clock tick counter register */
typedef struct{
__REG32 COUNTER  :15;
__REG32          :17;
} __ctc_bits;

/* RTC clock control register */
typedef struct{
__REG32 CLKEN   : 1;
__REG32 CTCRST  : 1;
__REG32 CTTEST  : 2;
__REG32 CLKSRC  : 1;
__REG32         :27;
} __rtcccr_bits;

/* RTC counter increment interrupt register */
typedef struct{
__REG32 IMSEC   : 1;
__REG32 IMMIN   : 1;
__REG32 IMHOUR  : 1;
__REG32 IMDOM   : 1;
__REG32 IMDOW   : 1;
__REG32 IMDOY   : 1;
__REG32 IMMON   : 1;
__REG32 IMYEAR  : 1;
__REG32         :24;
} __ciir_bits;

/* RTC Counter Increment Select Mask Register */
typedef struct{
__REG32 SUBSECSEL : 3;
__REG32           : 4;
__REG32 SUBSECENA : 1;
__REG32           :24;
} __ciss_bits;

/* RTC alarm mask register */
typedef struct{
__REG32 AMRSEC   : 1;
__REG32 AMRMIN   : 1;
__REG32 AMRHOUR  : 1;
__REG32 AMRDOM   : 1;
__REG32 AMRDOW   : 1;
__REG32 AMRDOY   : 1;
__REG32 AMRMON   : 1;
__REG32 AMRYEAR  : 1;
__REG32          :24;
} __amr_bits;

/* RTC consolidated time register 0 */
typedef struct{
__REG32 SEC   : 6;
__REG32       : 2;
__REG32 MIN   : 6;
__REG32       : 2;
__REG32 HOUR  : 5;
__REG32       : 3;
__REG32 DOW   : 3;
__REG32       : 5;
} __ctime0_bits;

/* RTC consolidated time register 1 */
typedef struct{
__REG32 DOM   : 5;
__REG32       : 3;
__REG32 MON   : 4;
__REG32       : 4;
__REG32 YEAR  :12;
__REG32       : 4;
} __ctime1_bits;

/* RTC consolidated time register 2 */
typedef struct{
__REG32 DOY  :12;
__REG32      :20;
} __ctime2_bits;

/* RTC second register */
typedef struct{
__REG32 SEC  : 6;
__REG32      :26;
} __sec_bits;

/* RTC minute register */
typedef struct{
__REG32 MIN  : 6;
__REG32      :26;
} __min_bits;

/* RTC hour register */
typedef struct{
__REG32 HOUR  : 5;
__REG32       :27;
} __hour_bits;

/* RTC day of month register */
typedef struct{
__REG32 DOM  : 5;
__REG32      :27;
} __dom_bits;

/* RTC day of week register */
typedef struct{
__REG32 DOW  : 3;
__REG32      :29;
} __dow_bits;

/* RTC day of year register */
typedef struct{
__REG32 DOY  : 9;
__REG32      :23;
} __doy_bits;

/* RTC month register */
typedef struct{
__REG32 MON  : 4;
__REG32      :28;
} __month_bits;

/* RTC year register */
typedef struct{
__REG32 YEAR  :12;
__REG32       :20;
} __year_bits;

/* RTC prescaler value, integer portion register */
typedef struct{
__REG32 VALUE  :13;
__REG32        :19;
} __preint_bits;

/* RTC prescaler value, fractional portion register */
typedef struct{
__REG32 VALUE  :15;
__REG32        :17;
} __prefrac_bits;

/* DMA Interrupt Status Register */
typedef struct{
__REG32 INTSTATUS0  : 1;
__REG32 INTSTATUS1  : 1;
__REG32             :30;
} __dmacintstatus_bits;

/* DMA Interrupt Terminal Count Request Status Register */
typedef struct{
__REG32 INTTCSTATUS0  : 1;
__REG32 INTTCSTATUS1  : 1;
__REG32               :30;
} __dmacinttcstatus_bits;

/* DMA Interrupt Terminal Count Request Clear Register */
typedef struct{
__REG32 INTTCCLEAR0   : 1;
__REG32 INTTCCLEAR1   : 1;
__REG32               :30;
} __dmacinttcclear_bits;

/* DMA Interrupt Error Status Register */
typedef struct{
__REG32 INTERRORSTATUS0 : 1;
__REG32 INTERRORSTATUS1 : 1;
__REG32                 :30;
} __dmacinterrstat_bits;

/* DMA Interrupt Error Clear Register */
typedef struct{
__REG32 INTERRCLR0      : 1;
__REG32 INTERRCLR1      : 1;
__REG32                 :30;
} __dmacinterrclr_bits;

/* DMA Raw Interrupt Terminal Count Status Register */
typedef struct{
__REG32 RAWINTTCSTATUS0 : 1;
__REG32 RAWINTTCSTATUS1 : 1;
__REG32                 :30;
} __dmacrawinttcstatus_bits;

/* DMA Raw Error Interrupt Status Register */
typedef struct{
__REG32 RAWINTERRORSTATUS0  : 1;
__REG32 RAWINTERRORSTATUS1  : 1;
__REG32                     :30;
} __dmacrawinterrorstatus_bits;

/* DMA Enabled Channel Register */
typedef struct{
__REG32 ENABLEDCHANNELS0  : 1;
__REG32 ENABLEDCHANNELS1  : 1;
__REG32                   :30;
} __dmacenbldchns_bits;

/* DMA Software Burst Request Register */
typedef struct{
__REG32 SOFTBREQSSP0TX    : 1;
__REG32 SOFTBREQSSP0RX    : 1;
__REG32 SOFTBREQSSP1TX    : 1;
__REG32 SOFTBREQSSP1RX    : 1;
__REG32 SOFTBREQSDMMC     : 1;
__REG32                   :27;
} __dmacsoftbreq_bits;

/* DMA Software Single Request Register */
typedef struct{
__REG32 SOFTREQSSP0TX     : 1;
__REG32 SOFTREQSSP0RX     : 1;
__REG32 SOFTREQSSP1TX     : 1;
__REG32 SOFTREQSSP1RX     : 1;
__REG32 SOFTREQSDMMC      : 1;
__REG32 SOFTSREQI2S0      : 1;
__REG32 SOFTSREQI2S1      : 1;
__REG32                   :25;
} __dmacsoftsreq_bits;

/* DMA Software Last Burst Request Register */
typedef struct{
__REG32                   : 4;
__REG32 SOFTLBREQSDMMC    : 1;
__REG32                   :27;
} __dmacsoftlbreq_bits;

/* DMA Software Last Single Request Register */
typedef struct{
__REG32                   : 4;
__REG32 SOFTLSREQSDMMC    : 1;
__REG32                   :27;
} __dmacsoftlsreq_bits;

/* DMA Synchronization Register */
typedef struct{
__REG32 DMACSYNC    :16;
__REG32             :16;
} __dmacsync_bits;

/* DMA Configuration Register */
typedef struct{
__REG32 E   : 1;
__REG32 M   : 1;
__REG32     :30;
} __dmacconfig_bits;

/* DMA Software Burst Request Register */
typedef struct{
__REG32      : 2;
__REG32 LLI  :30;
} __dma_lli_bits;

/* DMA Channel Control Registers */
typedef struct{
__REG32 TRANSFERSIZE  :12;
__REG32 SBSIZE        : 3;
__REG32 DBSIZE        : 3;
__REG32 SWIDTH        : 3;
__REG32 DWIDTH        : 3;
__REG32               : 2;
__REG32 SI            : 1;
__REG32 DI            : 1;
__REG32 PROT1         : 1;
__REG32 PROT2         : 1;
__REG32 PROT3         : 1;
__REG32 I             : 1;
} __dma_ctrl_bits;

/* DMA Channel Configuration Registers */
typedef struct{
__REG32 E               : 1;
__REG32 SRCPERIPHERAL   : 4;
__REG32                 : 1;
__REG32 DESTPERIPHERAL  : 4;
__REG32                 : 1;
__REG32 FLOWCNTRL       : 3;
__REG32 IE              : 1;
__REG32 ITC             : 1;
__REG32 L               : 1;
__REG32 A               : 1;
__REG32 H               : 1;
__REG32                 :13;
} __dma_cfg_bits;

#endif    /* __IAR_SYSTEMS_ICC__ */

/* Declarations common to compiler and assembler **************************/

/***************************************************************************
 **
 ** System control block
 **
 ***************************************************************************/
#define MEMMAP         VOLATILE32(0xE01FC040)
#define MEMMAP_bit     VOLATILE_TYPE(0xE01FC040, __memmap_bits)
#define RSIR         VOLATILE32(0xE01FC180)
#define RSIR_bit     VOLATILE_TYPE(0xE01FC180, __rsir_bits)
#define EXTINT         VOLATILE32(0xE01FC140)
#define EXTINT_bit     VOLATILE_TYPE(0xE01FC140, __extint_bits)
#define EXTMODE         VOLATILE32(0xE01FC148)
#define EXTMODE_bit     VOLATILE_TYPE(0xE01FC148, __extmode_bits)
#define EXTPOLAR         VOLATILE32(0xE01FC14C)
#define EXTPOLAR_bit     VOLATILE_TYPE(0xE01FC14C, __extpolar_bits)
#define SCS         VOLATILE32(0xE01FC1A0)
#define SCS_bit     VOLATILE_TYPE(0xE01FC1A0, __scs_bits)
#define CSPR         VOLATILE32(0xE01FC184)
#define CSPR_bit     VOLATILE_TYPE(0xE01FC184, //)
#define PLLCON         VOLATILE32(0xE01FC080)
#define PLLCON_bit     VOLATILE_TYPE(0xE01FC080, __pllcon_bits)
#define PLLCFG         VOLATILE32(0xE01FC084)
#define PLLCFG_bit     VOLATILE_TYPE(0xE01FC084, __pllcfg_bits)
#define PLLSTAT         VOLATILE32(0xE01FC088)
#define PLLSTAT_bit     VOLATILE_TYPE(0xE01FC088, __pllstat_bits)
#define PLLFEED         VOLATILE32(0xE01FC08C)
#define PLLFEED_bit     VOLATILE_TYPE(0xE01FC08C, __pllfeed_bits)
#define APBDIV         VOLATILE32(0xE01FC100)
#define APBDIV_bit     VOLATILE_TYPE(0xE01FC100, __apbdiv_bits)
#define CCLKCFG         VOLATILE32(0xE01FC104)
#define CCLKCFG_bit     VOLATILE_TYPE(0xE01FC104, __cclkcfg_bits)
#define USBCLKCFG         VOLATILE32(0xE01FC108)
#define USBCLKCFG_bit     VOLATILE_TYPE(0xE01FC108, __usbclkcfg_bits)
#define CLKSRCSEL         VOLATILE32(0xE01FC10C)
#define CLKSRCSEL_bit     VOLATILE_TYPE(0xE01FC10C, __clksrcsel_bits)
#define IRCTRIM         VOLATILE32(0xE01FC1A4)
#define IRCTRIM_bit     VOLATILE_TYPE(0xE01FC1A4, __irctrim_bits)
#define PCLKSEL0         VOLATILE32(0xE01FC1A8)
#define PCLKSEL0_bit     VOLATILE_TYPE(0xE01FC1A8, __pclksel0_bits)
#define PCLKSEL1         VOLATILE32(0xE01FC1AC)
#define PCLKSEL1_bit     VOLATILE_TYPE(0xE01FC1AC, __pclksel1_bits)
#define PCON         VOLATILE32(0xE01FC0C0)
#define PCON_bit     VOLATILE_TYPE(0xE01FC0C0, __pcon_bits)
#define PCONP         VOLATILE32(0xE01FC0C4)
#define PCONP_bit     VOLATILE_TYPE(0xE01FC0C4, __pconp_bits)
#define INTWAKE         VOLATILE32(0xE01FC144)
#define INTWAKE_bit     VOLATILE_TYPE(0xE01FC144, __intwake_bits)

/***************************************************************************
 **
 ** AHB
 **
 ***************************************************************************/
#define AHBCFG1         VOLATILE32(0xE01FC188)
#define AHBCFG1_bit     VOLATILE_TYPE(0xE01FC188, __ahbcfg1_bits)
#define AHBCFG2         VOLATILE32(0xE01FC18C)
#define AHBCFG2_bit     VOLATILE_TYPE(0xE01FC18C, __ahbcfg2_bits)

/***************************************************************************
 **
 ** MAM
 **
 ***************************************************************************/
#define MAMCR         VOLATILE32(0xE01FC000)
#define MAMCR_bit     VOLATILE_TYPE(0xE01FC000, __mamcr_bits)
#define MAMTIM         VOLATILE32(0xE01FC004)
#define MAMTIM_bit     VOLATILE_TYPE(0xE01FC004, __mamtim_bits)

/***************************************************************************
 **
 ** EMC
 **
 ***************************************************************************/
#define EMCCONTROL         VOLATILE32(0xFFE08000)
#define EMCCONTROL_bit     VOLATILE_TYPE(0xFFE08000, __emc_ctrl_bits)
#define EMCSTATUS         VOLATILE32(0xFFE08004)
#define EMCSTATUS_bit     VOLATILE_TYPE(0xFFE08004, __emc_st_bits)
#define EMCCONFIG         VOLATILE32(0xFFE08008)
#define EMCCONFIG_bit     VOLATILE_TYPE(0xFFE08008, __emc_cfg_bits)
#define EMCSTATICCNFG0         VOLATILE32(0xFFE08200)
#define EMCSTATICCNFG0_bit     VOLATILE_TYPE(0xFFE08200, __emc_s_config_bits)
#define EMCSTATICWAITWEN0         VOLATILE32(0xFFE08204)
#define EMCSTATICWAITWEN0_bit     VOLATILE_TYPE(0xFFE08204, __emc_s_wait_wen_bits)
#define EMCSTATICWAITOEN0         VOLATILE32(0xFFE08208)
#define EMCSTATICWAITOEN0_bit     VOLATILE_TYPE(0xFFE08208, __emc_s_wait_oen_bits)
#define EMCSTATICWAITRD0         VOLATILE32(0xFFE0820C)
#define EMCSTATICWAITRD0_bit     VOLATILE_TYPE(0xFFE0820C, __emc_s_wait_rd_bits)
#define EMCSTATICWAITPG0         VOLATILE32(0xFFE08210)
#define EMCSTATICWAITPG0_bit     VOLATILE_TYPE(0xFFE08210, __emc_s_wait_pg_bits)
#define EMCSTATICWAITWR0         VOLATILE32(0xFFE08214)
#define EMCSTATICWAITWR0_bit     VOLATILE_TYPE(0xFFE08214, __emc_s_wait_wr_bits)
#define EMCSTATICWAITTURN0         VOLATILE32(0xFFE08218)
#define EMCSTATICWAITTURN0_bit     VOLATILE_TYPE(0xFFE08218, __emc_s_wait_turn_bits)
#define EMCSTATICCNFG1         VOLATILE32(0xFFE08220)
#define EMCSTATICCNFG1_bit     VOLATILE_TYPE(0xFFE08220, __emc_s_config_bits)
#define EMCSTATICWAITWEN1         VOLATILE32(0xFFE08224)
#define EMCSTATICWAITWEN1_bit     VOLATILE_TYPE(0xFFE08224, __emc_s_wait_wen_bits)
#define EMCSTATICWAITOEN1         VOLATILE32(0xFFE08228)
#define EMCSTATICWAITOEN1_bit     VOLATILE_TYPE(0xFFE08228, __emc_s_wait_oen_bits)
#define EMCSTATICWAITRD1         VOLATILE32(0xFFE0822C)
#define EMCSTATICWAITRD1_bit     VOLATILE_TYPE(0xFFE0822C, __emc_s_wait_rd_bits)
#define EMCSTATICWAITPG1         VOLATILE32(0xFFE08230)
#define EMCSTATICWAITPG1_bit     VOLATILE_TYPE(0xFFE08230, __emc_s_wait_pg_bits)
#define EMCSTATICWAITWR1         VOLATILE32(0xFFE08234)
#define EMCSTATICWAITWR1_bit     VOLATILE_TYPE(0xFFE08234, __emc_s_wait_wr_bits)
#define EMCSTATICWAITTURN1         VOLATILE32(0xFFE08238)
#define EMCSTATICWAITTURN1_bit     VOLATILE_TYPE(0xFFE08238, __emc_s_wait_turn_bits)
#define EMCSTATICEXTENDEDWAIT         VOLATILE32(0xFFE08880)
#define EMCSTATICEXTENDEDWAIT_bit     VOLATILE_TYPE(0xFFE08880, __emc_s_ext_wait_bits)


/***************************************************************************
 **
 ** VIC
 **
 ***************************************************************************/
#define VICIRQSTATUS         VOLATILE32(0xFFFFF000)
#define VICIRQSTATUS_bit     VOLATILE_TYPE(0xFFFFF000, __vicint_bits)
#define VICFIQSTATUS         VOLATILE32(0xFFFFF004)
#define VICFIQSTATUS_bit     VOLATILE_TYPE(0xFFFFF004, __vicint_bits)
#define VICRAWINTR         VOLATILE32(0xFFFFF008)
#define VICRAWINTR_bit     VOLATILE_TYPE(0xFFFFF008, __vicint_bits)
#define VICINTSELECT         VOLATILE32(0xFFFFF00C)
#define VICINTSELECt_bit     VOLATILE_TYPE(0xFFFFF00C, __vicint_bits)
#define VICINTENABLE         VOLATILE32(0xFFFFF010)
#define VICINTENABLE_bit     VOLATILE_TYPE(0xFFFFF010, __vicint_bits)
#define VICINTENCLEAR         VOLATILE32(0xFFFFF014)
#define VICINTENCLEAR_bit     VOLATILE_TYPE(0xFFFFF014, __vicint_bits)
#define VICSOFTINT         VOLATILE32(0xFFFFF018)
#define VICSOFTINT_bit     VOLATILE_TYPE(0xFFFFF018, __vicint_bits)
#define VICSOFTINTCLEAR         VOLATILE32(0xFFFFF01C)
#define VICSOFTINTCLEAR_bit     VOLATILE_TYPE(0xFFFFF01C, __vicint_bits)
#define VICPROTECTION         VOLATILE32(0xFFFFF020)
#define VICPROTECTION_bit     VOLATILE_TYPE(0xFFFFF020, __vicprotection_bits)
#define VICSWPRIORITYMASK         VOLATILE32(0xFFFFF024)
#define VICSWPRIORITYMASK_bit     VOLATILE_TYPE(0xFFFFF024, __vicswprmask_bits)
#define VICVECTADDR0           VOLATILE32(0xFFFFF100)   //
#define VICVECTADDR1           VOLATILE32(0xFFFFF104)   //
#define VICVECTADDR2           VOLATILE32(0xFFFFF108)   //
#define VICVECTADDR3           VOLATILE32(0xFFFFF10C)   //
#define VICVECTADDR4           VOLATILE32(0xFFFFF110)   //
#define VICVECTADDR5           VOLATILE32(0xFFFFF114)   //
#define VICVECTADDR6           VOLATILE32(0xFFFFF118)   //
#define VICVECTADDR7           VOLATILE32(0xFFFFF11C)   //
#define VICVECTADDR8           VOLATILE32(0xFFFFF120)   //
#define VICVECTADDR9           VOLATILE32(0xFFFFF124)   //
#define VICVECTADDR10          VOLATILE32(0xFFFFF128)   //
#define VICVECTADDR11          VOLATILE32(0xFFFFF12C)   //
#define VICVECTADDR12          VOLATILE32(0xFFFFF130)   //
#define VICVectAddr13          VOLATILE32(0xFFFFF134)   //
#define VICVectAddr14          VOLATILE32(0xFFFFF138)   //
#define VICVectAddr15          VOLATILE32(0xFFFFF13C)   //
#define VICVectAddr16          VOLATILE32(0xFFFFF140)   //
#define VICVectAddr17          VOLATILE32(0xFFFFF144)   //
#define VICVectAddr18          VOLATILE32(0xFFFFF148)   //
#define VICVectAddr19          VOLATILE32(0xFFFFF14C)   //
#define VICVectAddr20          VOLATILE32(0xFFFFF150)   //
#define VICVectAddr21          VOLATILE32(0xFFFFF154)   //
#define VICVectAddr22          VOLATILE32(0xFFFFF158)   //
#define VICVectAddr23          VOLATILE32(0xFFFFF15C)   //
#define VICVectAddr24          VOLATILE32(0xFFFFF160)   //
#define VICVectAddr25          VOLATILE32(0xFFFFF164)   //
#define VICVectAddr26          VOLATILE32(0xFFFFF168)   //
#define VICVectAddr27          VOLATILE32(0xFFFFF16C)   //
#define VICVectAddr28          VOLATILE32(0xFFFFF170)   //
#define VICVectAddr29          VOLATILE32(0xFFFFF174)   //
#define VICVectAddr30          VOLATILE32(0xFFFFF178)   //
#define VICVectAddr31          VOLATILE32(0xFFFFF17C)   //
#define VICVECTPRIORITY0         VOLATILE32(0xFFFFF200)
#define VICVectPriority0_bit     VOLATILE_TYPE(0xFFFFF200, __vicvectpr_bits)
#define VICVectPriority1         VOLATILE32(0xFFFFF204)
#define VICVectPriority1_bit     VOLATILE_TYPE(0xFFFFF204, __vicvectpr_bits)
#define VICVectPriority2         VOLATILE32(0xFFFFF208)
#define VICVectPriority2_bit     VOLATILE_TYPE(0xFFFFF208, __vicvectpr_bits)
#define VICVectPriority3         VOLATILE32(0xFFFFF20C)
#define VICVectPriority3_bit     VOLATILE_TYPE(0xFFFFF20C, __vicvectpr_bits)
#define VICVectPriority4         VOLATILE32(0xFFFFF210)
#define VICVectPriority4_bit     VOLATILE_TYPE(0xFFFFF210, __vicvectpr_bits)
#define VICVectPriority5         VOLATILE32(0xFFFFF214)
#define VICVectPriority5_bit     VOLATILE_TYPE(0xFFFFF214, __vicvectpr_bits)
#define VICVectPriority6         VOLATILE32(0xFFFFF218)
#define VICVectPriority6_bit     VOLATILE_TYPE(0xFFFFF218, __vicvectpr_bits)
#define VICVectPriority7         VOLATILE32(0xFFFFF21C)
#define VICVectPriority7_bit     VOLATILE_TYPE(0xFFFFF21C, __vicvectpr_bits)
#define VICVectPriority8         VOLATILE32(0xFFFFF220)
#define VICVectPriority8_bit     VOLATILE_TYPE(0xFFFFF220, __vicvectpr_bits)
#define VICVectPriority9         VOLATILE32(0xFFFFF224)
#define VICVectPriority9_bit     VOLATILE_TYPE(0xFFFFF224, __vicvectpr_bits)
#define VICVectPriority10         VOLATILE32(0xFFFFF228)
#define VICVectPriority10_bit     VOLATILE_TYPE(0xFFFFF228, __vicvectpr_bits)
#define VICVectPriority11         VOLATILE32(0xFFFFF22C)
#define VICVectPriority11_bit     VOLATILE_TYPE(0xFFFFF22C, __vicvectpr_bits)
#define VICVectPriority12         VOLATILE32(0xFFFFF230)
#define VICVectPriority12_bit     VOLATILE_TYPE(0xFFFFF230, __vicvectpr_bits)
#define VICVectPriority13         VOLATILE32(0xFFFFF234)
#define VICVectPriority13_bit     VOLATILE_TYPE(0xFFFFF234, __vicvectpr_bits)
#define VICVectPriority14         VOLATILE32(0xFFFFF238)
#define VICVectPriority14_bit     VOLATILE_TYPE(0xFFFFF238, __vicvectpr_bits)
#define VICVectPriority15         VOLATILE32(0xFFFFF23C)
#define VICVectPriority15_bit     VOLATILE_TYPE(0xFFFFF23C, __vicvectpr_bits)
#define VICVectPriority16         VOLATILE32(0xFFFFF240)
#define VICVectPriority16_bit     VOLATILE_TYPE(0xFFFFF240, __vicvectpr_bits)
#define VICVectPriority17         VOLATILE32(0xFFFFF244)
#define VICVectPriority17_bit     VOLATILE_TYPE(0xFFFFF244, __vicvectpr_bits)
#define VICVectPriority18         VOLATILE32(0xFFFFF248)
#define VICVectPriority18_bit     VOLATILE_TYPE(0xFFFFF248, __vicvectpr_bits)
#define VICVectPriority19         VOLATILE32(0xFFFFF24C)
#define VICVectPriority19_bit     VOLATILE_TYPE(0xFFFFF24C, __vicvectpr_bits)
#define VICVectPriority20         VOLATILE32(0xFFFFF250)
#define VICVectPriority20_bit     VOLATILE_TYPE(0xFFFFF250, __vicvectpr_bits)
#define VICVectPriority21         VOLATILE32(0xFFFFF254)
#define VICVectPriority21_bit     VOLATILE_TYPE(0xFFFFF254, __vicvectpr_bits)
#define VICVectPriority22         VOLATILE32(0xFFFFF258)
#define VICVectPriority22_bit     VOLATILE_TYPE(0xFFFFF258, __vicvectpr_bits)
#define VICVectPriority23         VOLATILE32(0xFFFFF25C)
#define VICVectPriority23_bit     VOLATILE_TYPE(0xFFFFF25C, __vicvectpr_bits)
#define VICVectPriority24         VOLATILE32(0xFFFFF260)
#define VICVectPriority24_bit     VOLATILE_TYPE(0xFFFFF260, __vicvectpr_bits)
#define VICVectPriority25         VOLATILE32(0xFFFFF264)
#define VICVectPriority25_bit     VOLATILE_TYPE(0xFFFFF264, __vicvectpr_bits)
#define VICVectPriority26         VOLATILE32(0xFFFFF268)
#define VICVectPriority26_bit     VOLATILE_TYPE(0xFFFFF268, __vicvectpr_bits)
#define VICVectPriority27         VOLATILE32(0xFFFFF26C)
#define VICVectPriority27_bit     VOLATILE_TYPE(0xFFFFF26C, __vicvectpr_bits)
#define VICVectPriority28         VOLATILE32(0xFFFFF270)
#define VICVectPriority28_bit     VOLATILE_TYPE(0xFFFFF270, __vicvectpr_bits)
#define VICVectPriority29         VOLATILE32(0xFFFFF274)
#define VICVectPriority29_bit     VOLATILE_TYPE(0xFFFFF274, __vicvectpr_bits)
#define VICVectPriority30         VOLATILE32(0xFFFFF278)
#define VICVectPriority30_bit     VOLATILE_TYPE(0xFFFFF278, __vicvectpr_bits)
#define VICVectPriority31         VOLATILE32(0xFFFFF27C)
#define VICVectPriority31_bit     VOLATILE_TYPE(0xFFFFF27C, __vicvectpr_bits)
#define VICADDRESS             VOLATILE32(0xFFFFFF00)   //

/***************************************************************************
 **
 ** Pin connect block
 **
 ***************************************************************************/
#define PINSEL0         VOLATILE32(0xE002C000)
#define PINSEL0_bit     VOLATILE_TYPE(0xE002C000, __pinsel0_bits)
#define PINSEL1         VOLATILE32(0xE002C004)
#define PINSEL1_bit     VOLATILE_TYPE(0xE002C004, __pinsel1_bits)
#define PINSEL2         VOLATILE32(0xE002C008)
#define PINSEL2_bit     VOLATILE_TYPE(0xE002C008, __pinsel2_bits)
#define PINSEL3         VOLATILE32(0xE002C00C)
#define PINSEL3_bit     VOLATILE_TYPE(0xE002C00C, __pinsel3_bits)
#define PINSEL4         VOLATILE32(0xE002C010)
#define PINSEL4_bit     VOLATILE_TYPE(0xE002C010, __pinsel4_bits)
#define PINSEL5         VOLATILE32(0xE002C014)
#define PINSEL5_bit     VOLATILE_TYPE(0xE002C014, __pinsel5_bits)
#define PINSEL6         VOLATILE32(0xE002C018)
#define PINSEL6_bit     VOLATILE_TYPE(0xE002C018, __pinsel6_bits)
#define PINSEL7         VOLATILE32(0xE002C01C)
#define PINSEL7_bit     VOLATILE_TYPE(0xE002C01C, __pinsel7_bits)
#define PINSEL8         VOLATILE32(0xE002C020)
#define PINSEL8_bit     VOLATILE_TYPE(0xE002C020, __pinsel8_bits)
#define PINSEL9         VOLATILE32(0xE002C024)
#define PINSEL9_bit     VOLATILE_TYPE(0xE002C024, __pinsel9_bits)
#define PINSEL10         VOLATILE32(0xE002C028)
#define PINSEL10_bit     VOLATILE_TYPE(0xE002C028, __pinsel10_bits)
#define PINMODE0         VOLATILE32(0xE002C040)
#define PINMODE0_bit     VOLATILE_TYPE(0xE002C040, __pinsel0_bits)
#define PINMODE1         VOLATILE32(0xE002C044)
#define PINMODE1_bit     VOLATILE_TYPE(0xE002C044, __pinsel1_bits)
#define PINMODE2         VOLATILE32(0xE002C048)
#define PINMODE2_bit     VOLATILE_TYPE(0xE002C048, __pinsel2_bits)
#define PINMODE3         VOLATILE32(0xE002C04C)
#define PINMODE3_bit     VOLATILE_TYPE(0xE002C04C, __pinsel3_bits)
#define PINMODE4         VOLATILE32(0xE002C050)
#define PINMODE4_bit     VOLATILE_TYPE(0xE002C050, __pinsel4_bits)
#define PINMODE5         VOLATILE32(0xE002C054)
#define PINMODE5_bit     VOLATILE_TYPE(0xE002C054, __pinsel5_bits)
#define PINMODE6         VOLATILE32(0xE002C058)
#define PINMODE6_bit     VOLATILE_TYPE(0xE002C058, __pinsel6_bits)
#define PINMODE7         VOLATILE32(0xE002C05C)
#define PINMODE7_bit     VOLATILE_TYPE(0xE002C05C, __pinsel7_bits)
#define PINMODE8         VOLATILE32(0xE002C060)
#define PINMODE8_bit     VOLATILE_TYPE(0xE002C060, __pinsel8_bits)
#define PINMODE9         VOLATILE32(0xE002C064)
#define PINMODE9_bit     VOLATILE_TYPE(0xE002C064, __pinsel9_bits)

/***************************************************************************
 **
 ** GPIO
 **
 ***************************************************************************/
#define IO0PIN         VOLATILE32(0xE0028000)
#define IO0PIN_bit     VOLATILE_TYPE(0xE0028000, __gpio0_bits)
#define IO0SET         VOLATILE32(0xE0028004)
#define IO0SET_bit     VOLATILE_TYPE(0xE0028004, __gpio0_bits)
#define IO0DIR         VOLATILE32(0xE0028008)
#define IO0DIR_bit     VOLATILE_TYPE(0xE0028008, __gpio0_bits)
#define IO0CLR         VOLATILE32(0xE002800C)
#define IO0CLR_bit     VOLATILE_TYPE(0xE002800C, __gpio0_bits)
#define FIO0DIR         VOLATILE32(0x3FFFC000)
#define FIO0DIR_bit     VOLATILE_TYPE(0x3FFFC000, __fgpio0_bits)
#define FIO0DIR0          FIO0DIR_bit.__byte0
#define FIO0DIR0_bit      FIO0DIR_bit.__byte0_bit
#define FIO0DIR1          FIO0DIR_bit.__byte1
#define FIO0DIR1_bit      FIO0DIR_bit.__byte1_bit
#define FIO0DIR2          FIO0DIR_bit.__byte2
#define FIO0DIR2_bit      FIO0DIR_bit.__byte2_bit
#define FIO0DIR3          FIO0DIR_bit.__byte3
#define FIO0DIR3_bit      FIO0DIR_bit.__byte3_bit
#define FIO0DIRL          FIO0DIR_bit.__shortl
#define FIO0DIRL_bit      FIO0DIR_bit.__shortl_bit
#define FIO0DIRU          FIO0DIR_bit.__shortu
#define FIO0DIRU_bit      FIO0DIR_bit.__shortu_bit
#define FIO0MASK         VOLATILE32(0x3FFFC010)
#define FIO0MASK_bit     VOLATILE_TYPE(0x3FFFC010, __fgpio0_bits)
#define FIO0MASK0         FIO0MASK_bit.__byte0
#define FIO0MASK0_bit     FIO0MASK_bit.__byte0_bit
#define FIO0MASK1         FIO0MASK_bit.__byte1
#define FIO0MASK1_bit     FIO0MASK_bit.__byte1_bit
#define FIO0MASK2         FIO0MASK_bit.__byte2
#define FIO0MASK2_bit     FIO0MASK_bit.__byte2_bit
#define FIO0MASK3         FIO0MASK_bit.__byte3
#define FIO0MASK3_bit     FIO0MASK_bit.__byte3_bit
#define FIO0MASKL         FIO0MASK_bit.__shortl
#define FIO0MASKL_bit     FIO0MASK_bit.__shortl_bit
#define FIO0MASKU         FIO0MASK_bit.__shortu
#define FIO0MASKU_bit     FIO0MASK_bit.__shortu_bit
#define FIO0PIN         VOLATILE32(0x3FFFC014)
#define FIO0PIN_bit     VOLATILE_TYPE(0x3FFFC014, __fgpio0_bits)
#define FIO0PIN0          FIO0PIN_bit.__byte0
#define FIO0PIN0_bit      FIO0PIN_bit.__byte0_bit
#define FIO0PIN1          FIO0PIN_bit.__byte1
#define FIO0PIN1_bit      FIO0PIN_bit.__byte1_bit
#define FIO0PIN2          FIO0PIN_bit.__byte2
#define FIO0PIN2_bit      FIO0PIN_bit.__byte2_bit
#define FIO0PIN3          FIO0PIN_bit.__byte3
#define FIO0PIN3_bit      FIO0PIN_bit.__byte3_bit
#define FIO0PINL          FIO0PIN_bit.__shortl
#define FIO0PINL_bit      FIO0PIN_bit.__shortl_bit
#define FIO0PINU          FIO0PIN_bit.__shortu
#define FIO0PINU_bit      FIO0PIN_bit.__shortu_bit
#define FIO0SET         VOLATILE32(0x3FFFC018)
#define FIO0SET_bit     VOLATILE_TYPE(0x3FFFC018, __fgpio0_bits)
#define FIO0SET0          FIO0SET_bit.__byte0
#define FIO0SET0_bit      FIO0SET_bit.__byte0_bit
#define FIO0SET1          FIO0SET_bit.__byte1
#define FIO0SET1_bit      FIO0SET_bit.__byte1_bit
#define FIO0SET2          FIO0SET_bit.__byte2
#define FIO0SET2_bit      FIO0SET_bit.__byte2_bit
#define FIO0SET3          FIO0SET_bit.__byte3
#define FIO0SET3_bit      FIO0SET_bit.__byte3_bit
#define FIO0SETL          FIO0SET_bit.__shortl
#define FIO0SETL_bit      FIO0SET_bit.__shortl_bit
#define FIO0SETU          FIO0SET_bit.__shortu
#define FIO0SETU_bit      FIO0SET_bit.__shortu_bit
#define FIO0CLR         VOLATILE32(0x3FFFC01C)
#define FIO0CLR_bit     VOLATILE_TYPE(0x3FFFC01C, __fgpio0_bits)
#define FIO0CLR0          FIO0CLR_bit.__byte0
#define FIO0CLR0_bit      FIO0CLR_bit.__byte0_bit
#define FIO0CLR1          FIO0CLR_bit.__byte1
#define FIO0CLR1_bit      FIO0CLR_bit.__byte1_bit
#define FIO0CLR2          FIO0CLR_bit.__byte2
#define FIO0CLR2_bit      FIO0CLR_bit.__byte2_bit
#define FIO0CLR3          FIO0CLR_bit.__byte3
#define FIO0CLR3_bit      FIO0CLR_bit.__byte3_bit
#define FIO0CLRL          FIO0CLR_bit.__shortl
#define FIO0CLRL_bit      FIO0CLR_bit.__shortl_bit
#define FIO0CLRU          FIO0CLR_bit.__shortu
#define FIO0CLRU_bit      FIO0CLR_bit.__shortu_bit
#define IO1PIN         VOLATILE32(0xE0028010)
#define IO1PIN_bit     VOLATILE_TYPE(0xE0028010, __gpio1_bits)
#define IO1SET         VOLATILE32(0xE0028014)
#define IO1SET_bit     VOLATILE_TYPE(0xE0028014, __gpio1_bits)
#define IO1DIR         VOLATILE32(0xE0028018)
#define IO1DIR_bit     VOLATILE_TYPE(0xE0028018, __gpio1_bits)
#define IO1CLR         VOLATILE32(0xE002801C)
#define IO1CLR_bit     VOLATILE_TYPE(0xE002801C, __gpio1_bits)
#define FIO1DIR         VOLATILE32(0x3FFFC020)
#define FIO1DIR_bit     VOLATILE_TYPE(0x3FFFC020, __fgpio1_bits)
#define FIO1DIR0          FIO1DIR_bit.__byte0
#define FIO1DIR0_bit      FIO1DIR_bit.__byte0_bit
#define FIO1DIR1          FIO1DIR_bit.__byte1
#define FIO1DIR1_bit      FIO1DIR_bit.__byte1_bit
#define FIO1DIR2          FIO1DIR_bit.__byte2
#define FIO1DIR2_bit      FIO1DIR_bit.__byte2_bit
#define FIO1DIR3          FIO1DIR_bit.__byte3
#define FIO1DIR3_bit      FIO1DIR_bit.__byte3_bit
#define FIO1DIRL          FIO1DIR_bit.__shortl
#define FIO1DIRL_bit      FIO1DIR_bit.__shortl_bit
#define FIO1DIRU          FIO1DIR_bit.__shortu
#define FIO1DIRU_bit      FIO1DIR_bit.__shortu_bit
#define FIO1MASK         VOLATILE32(0x3FFFC030)
#define FIO1MASK_bit     VOLATILE_TYPE(0x3FFFC030, __fgpio1_bits)
#define FIO1MASK0         FIO1MASK_bit.__byte0
#define FIO1MASK0_bit     FIO1MASK_bit.__byte0_bit
#define FIO1MASK1         FIO1MASK_bit.__byte1
#define FIO1MASK1_bit     FIO1MASK_bit.__byte1_bit
#define FIO1MASK2         FIO1MASK_bit.__byte2
#define FIO1MASK2_bit     FIO1MASK_bit.__byte2_bit
#define FIO1MASK3         FIO1MASK_bit.__byte3
#define FIO1MASK3_bit     FIO1MASK_bit.__byte3_bit
#define FIO1MASKL         FIO1MASK_bit.__shortl
#define FIO1MASKL_bit     FIO1MASK_bit.__shortl_bit
#define FIO1MASKU         FIO1MASK_bit.__shortu
#define FIO1MASKU_bit     FIO1MASK_bit.__shortu_bit
#define FIO1PIN         VOLATILE32(0x3FFFC034)
#define FIO1PIN_bit     VOLATILE_TYPE(0x3FFFC034, __fgpio1_bits)
#define FIO1PIN0          FIO1PIN_bit.__byte0
#define FIO1PIN0_bit      FIO1PIN_bit.__byte0_bit
#define FIO1PIN1          FIO1PIN_bit.__byte1
#define FIO1PIN1_bit      FIO1PIN_bit.__byte1_bit
#define FIO1PIN2          FIO1PIN_bit.__byte2
#define FIO1PIN2_bit      FIO1PIN_bit.__byte2_bit
#define FIO1PIN3          FIO1PIN_bit.__byte3
#define FIO1PIN3_bit      FIO1PIN_bit.__byte3_bit
#define FIO1PINL          FIO1PIN_bit.__shortl
#define FIO1PINL_bit      FIO1PIN_bit.__shortl_bit
#define FIO1PINU          FIO1PIN_bit.__shortu
#define FIO1PINU_bit      FIO1PIN_bit.__shortu_bit
#define FIO1SET         VOLATILE32(0x3FFFC038)
#define FIO1SET_bit     VOLATILE_TYPE(0x3FFFC038, __fgpio1_bits)
#define FIO1SET0          FIO1SET_bit.__byte0
#define FIO1SET0_bit      FIO1SET_bit.__byte0_bit
#define FIO1SET1          FIO1SET_bit.__byte1
#define FIO1SET1_bit      FIO1SET_bit.__byte1_bit
#define FIO1SET2          FIO1SET_bit.__byte2
#define FIO1SET2_bit      FIO1SET_bit.__byte2_bit
#define FIO1SET3          FIO1SET_bit.__byte3
#define FIO1SET3_bit      FIO1SET_bit.__byte3_bit
#define FIO1SETL          FIO1SET_bit.__shortl
#define FIO1SETL_bit      FIO1SET_bit.__shortl_bit
#define FIO1SETU          FIO1SET_bit.__shortu
#define FIO1SETU_bit      FIO1SET_bit.__shortu_bit
#define FIO1CLR         VOLATILE32(0x3FFFC03C)
#define FIO1CLR_bit     VOLATILE_TYPE(0x3FFFC03C, __fgpio1_bits)
#define FIO1CLR0          FIO1CLR_bit.__byte0
#define FIO1CLR0_bit      FIO1CLR_bit.__byte0_bit
#define FIO1CLR1          FIO1CLR_bit.__byte1
#define FIO1CLR1_bit      FIO1CLR_bit.__byte1_bit
#define FIO1CLR2          FIO1CLR_bit.__byte2
#define FIO1CLR2_bit      FIO1CLR_bit.__byte2_bit
#define FIO1CLR3          FIO1CLR_bit.__byte3
#define FIO1CLR3_bit      FIO1CLR_bit.__byte3_bit
#define FIO1CLRL          FIO1CLR_bit.__shortl
#define FIO1CLRL_bit      FIO1CLR_bit.__shortl_bit
#define FIO1CLRU          FIO1CLR_bit.__shortu
#define FIO1CLRU_bit      FIO1CLR_bit.__shortu_bit
#define FIO2DIR         VOLATILE32(0x3FFFC040)
#define FIO2DIR_bit     VOLATILE_TYPE(0x3FFFC040, __fgpio2_bits)
#define FIO2DIR0          FIO2DIR_bit.__byte0
#define FIO2DIR0_bit      FIO2DIR_bit.__byte0_bit
#define FIO2DIR1          FIO2DIR_bit.__byte1
#define FIO2DIR1_bit      FIO2DIR_bit.__byte1_bit
#define FIO2DIR2          FIO2DIR_bit.__byte2
#define FIO2DIR2_bit      FIO2DIR_bit.__byte2_bit
#define FIO2DIR3          FIO2DIR_bit.__byte3
#define FIO2DIR3_bit      FIO2DIR_bit.__byte3_bit
#define FIO2DIRL          FIO2DIR_bit.__shortl
#define FIO2DIRL_bit      FIO2DIR_bit.__shortl_bit
#define FIO2DIRU          FIO2DIR_bit.__shortu
#define FIO2DIRU_bit      FIO2DIR_bit.__shortu_bit
#define FIO2MASK         VOLATILE32(0x3FFFC050)
#define FIO2MASK_bit     VOLATILE_TYPE(0x3FFFC050, __fgpio2_bits)
#define FIO2MASK0         FIO2MASK_bit.__byte0
#define FIO2MASK0_bit     FIO2MASK_bit.__byte0_bit
#define FIO2MASK1         FIO2MASK_bit.__byte1
#define FIO2MASK1_bit     FIO2MASK_bit.__byte1_bit
#define FIO2MASK2         FIO2MASK_bit.__byte2
#define FIO2MASK2_bit     FIO2MASK_bit.__byte2_bit
#define FIO2MASK3         FIO2MASK_bit.__byte3
#define FIO2MASK3_bit     FIO2MASK_bit.__byte3_bit
#define FIO2MASKL         FIO2MASK_bit.__shortl
#define FIO2MASKL_bit     FIO2MASK_bit.__shortl_bit
#define FIO2MASKU         FIO2MASK_bit.__shortu
#define FIO2MASKU_bit     FIO2MASK_bit.__shortu_bit
#define FIO2PIN         VOLATILE32(0x3FFFC054)
#define FIO2PIN_bit     VOLATILE_TYPE(0x3FFFC054, __fgpio2_bits)
#define FIO2PIN0          FIO2PIN_bit.__byte0
#define FIO2PIN0_bit      FIO2PIN_bit.__byte0_bit
#define FIO2PIN1          FIO2PIN_bit.__byte1
#define FIO2PIN1_bit      FIO2PIN_bit.__byte1_bit
#define FIO2PIN2          FIO2PIN_bit.__byte2
#define FIO2PIN2_bit      FIO2PIN_bit.__byte2_bit
#define FIO2PIN3          FIO2PIN_bit.__byte3
#define FIO2PIN3_bit      FIO2PIN_bit.__byte3_bit
#define FIO2PINL          FIO2PIN_bit.__shortl
#define FIO2PINL_bit      FIO2PIN_bit.__shortl_bit
#define FIO2PINU          FIO2PIN_bit.__shortu
#define FIO2PINU_bit      FIO2PIN_bit.__shortu_bit
#define FIO2SET         VOLATILE32(0x3FFFC058)
#define FIO2SET_bit     VOLATILE_TYPE(0x3FFFC058, __fgpio2_bits)
#define FIO2SET0          FIO2SET_bit.__byte0
#define FIO2SET0_bit      FIO2SET_bit.__byte0_bit
#define FIO2SET1          FIO2SET_bit.__byte1
#define FIO2SET1_bit      FIO2SET_bit.__byte1_bit
#define FIO2SET2          FIO2SET_bit.__byte2
#define FIO2SET2_bit      FIO2SET_bit.__byte2_bit
#define FIO2SET3          FIO2SET_bit.__byte3
#define FIO2SET3_bit      FIO2SET_bit.__byte3_bit
#define FIO2SETL          FIO2SET_bit.__shortl
#define FIO2SETL_bit      FIO2SET_bit.__shortl_bit
#define FIO2SETU          FIO2SET_bit.__shortu
#define FIO2SETU_bit      FIO2SET_bit.__shortu_bit
#define FIO2CLR         VOLATILE32(0x3FFFC05C)
#define FIO2CLR_bit     VOLATILE_TYPE(0x3FFFC05C, __fgpio2_bits)
#define FIO2CLR0          FIO2CLR_bit.__byte0
#define FIO2CLR0_bit      FIO2CLR_bit.__byte0_bit
#define FIO2CLR1          FIO2CLR_bit.__byte1
#define FIO2CLR1_bit      FIO2CLR_bit.__byte1_bit
#define FIO2CLR2          FIO2CLR_bit.__byte2
#define FIO2CLR2_bit      FIO2CLR_bit.__byte2_bit
#define FIO2CLR3          FIO2CLR_bit.__byte3
#define FIO2CLR3_bit      FIO2CLR_bit.__byte3_bit
#define FIO2CLRL          FIO2CLR_bit.__shortl
#define FIO2CLRL_bit      FIO2CLR_bit.__shortl_bit
#define FIO2CLRU          FIO2CLR_bit.__shortu
#define FIO2CLRU_bit      FIO2CLR_bit.__shortu_bit
#define FIO3DIR         VOLATILE32(0x3FFFC060)
#define FIO3DIR_bit     VOLATILE_TYPE(0x3FFFC060, __fgpio3_bits)
#define FIO3DIR0          FIO3DIR_bit.__byte0
#define FIO3DIR0_bit      FIO3DIR_bit.__byte0_bit
#define FIO3DIR1          FIO3DIR_bit.__byte1
#define FIO3DIR1_bit      FIO3DIR_bit.__byte1_bit
#define FIO3DIR2          FIO3DIR_bit.__byte2
#define FIO3DIR2_bit      FIO3DIR_bit.__byte2_bit
#define FIO3DIR3          FIO3DIR_bit.__byte3
#define FIO3DIR3_bit      FIO3DIR_bit.__byte3_bit
#define FIO3DIRL          FIO3DIR_bit.__shortl
#define FIO3DIRL_bit      FIO3DIR_bit.__shortl_bit
#define FIO3DIRU          FIO3DIR_bit.__shortu
#define FIO3DIRU_bit      FIO3DIR_bit.__shortu_bit
#define FIO3MASK         VOLATILE32(0x3FFFC070)
#define FIO3MASK_bit     VOLATILE_TYPE(0x3FFFC070, __fgpio3_bits)
#define FIO3MASK0         FIO3MASK_bit.__byte0
#define FIO3MASK0_bit     FIO3MASK_bit.__byte0_bit
#define FIO3MASK1         FIO3MASK_bit.__byte1
#define FIO3MASK1_bit     FIO3MASK_bit.__byte1_bit
#define FIO3MASK2         FIO3MASK_bit.__byte2
#define FIO3MASK2_bit     FIO3MASK_bit.__byte2_bit
#define FIO3MASK3         FIO3MASK_bit.__byte3
#define FIO3MASK3_bit     FIO3MASK_bit.__byte3_bit
#define FIO3MASKL         FIO3MASK_bit.__shortl
#define FIO3MASKL_bit     FIO3MASK_bit.__shortl_bit
#define FIO3MASKU         FIO3MASK_bit.__shortu
#define FIO3MASKU_bit     FIO3MASK_bit.__shortu_bit
#define FIO3PIN         VOLATILE32(0x3FFFC074)
#define FIO3PIN_bit     VOLATILE_TYPE(0x3FFFC074, __fgpio3_bits)
#define FIO3PIN0          FIO3PIN_bit.__byte0
#define FIO3PIN0_bit      FIO3PIN_bit.__byte0_bit
#define FIO3PIN1          FIO3PIN_bit.__byte1
#define FIO3PIN1_bit      FIO3PIN_bit.__byte1_bit
#define FIO3PIN2          FIO3PIN_bit.__byte2
#define FIO3PIN2_bit      FIO3PIN_bit.__byte2_bit
#define FIO3PIN3          FIO3PIN_bit.__byte3
#define FIO3PIN3_bit      FIO3PIN_bit.__byte3_bit
#define FIO3PINL          FIO3PIN_bit.__shortl
#define FIO3PINL_bit      FIO3PIN_bit.__shortl_bit
#define FIO3PINU          FIO3PIN_bit.__shortu
#define FIO3PINU_bit      FIO3PIN_bit.__shortu_bit
#define FIO3SET         VOLATILE32(0x3FFFC078)
#define FIO3SET_bit     VOLATILE_TYPE(0x3FFFC078, __fgpio3_bits)
#define FIO3SET0          FIO3SET_bit.__byte0
#define FIO3SET0_bit      FIO3SET_bit.__byte0_bit
#define FIO3SET1          FIO3SET_bit.__byte1
#define FIO3SET1_bit      FIO3SET_bit.__byte1_bit
#define FIO3SET2          FIO3SET_bit.__byte2
#define FIO3SET2_bit      FIO3SET_bit.__byte2_bit
#define FIO3SET3          FIO3SET_bit.__byte3
#define FIO3SET3_bit      FIO3SET_bit.__byte3_bit
#define FIO3SETL          FIO3SET_bit.__shortl
#define FIO3SETL_bit      FIO3SET_bit.__shortl_bit
#define FIO3SETU          FIO3SET_bit.__shortu
#define FIO3SETU_bit      FIO3SET_bit.__shortu_bit
#define FIO3CLR         VOLATILE32(0x3FFFC07C)
#define FIO3CLR_bit     VOLATILE_TYPE(0x3FFFC07C, __fgpio3_bits)
#define FIO3CLR0          FIO3CLR_bit.__byte0
#define FIO3CLR0_bit      FIO3CLR_bit.__byte0_bit
#define FIO3CLR1          FIO3CLR_bit.__byte1
#define FIO3CLR1_bit      FIO3CLR_bit.__byte1_bit
#define FIO3CLR2          FIO3CLR_bit.__byte2
#define FIO3CLR2_bit      FIO3CLR_bit.__byte2_bit
#define FIO3CLR3          FIO3CLR_bit.__byte3
#define FIO3CLR3_bit      FIO3CLR_bit.__byte3_bit
#define FIO3CLRL          FIO3CLR_bit.__shortl
#define FIO3CLRL_bit      FIO3CLR_bit.__shortl_bit
#define FIO3CLRU          FIO3CLR_bit.__shortu
#define FIO3CLRU_bit      FIO3CLR_bit.__shortu_bit
#define FIO4DIR         VOLATILE32(0x3FFFC080)
#define FIO4DIR_bit     VOLATILE_TYPE(0x3FFFC080, __fgpio4_bits)
#define FIO4DIR0          FIO4DIR_bit.__byte0
#define FIO4DIR0_bit      FIO4DIR_bit.__byte0_bit
#define FIO4DIR1          FIO4DIR_bit.__byte1
#define FIO4DIR1_bit      FIO4DIR_bit.__byte1_bit
#define FIO4DIR2          FIO4DIR_bit.__byte2
#define FIO4DIR2_bit      FIO4DIR_bit.__byte2_bit
#define FIO4DIR3          FIO4DIR_bit.__byte3
#define FIO4DIR3_bit      FIO4DIR_bit.__byte3_bit
#define FIO4DIRL          FIO4DIR_bit.__shortl
#define FIO4DIRL_bit      FIO4DIR_bit.__shortl_bit
#define FIO4DIRU          FIO4DIR_bit.__shortu
#define FIO4DIRU_bit      FIO4DIR_bit.__shortu_bit
#define FIO4MASK         VOLATILE32(0x3FFFC090)
#define FIO4MASK_bit     VOLATILE_TYPE(0x3FFFC090, __fgpio4_bits)
#define FIO4MASK0         FIO4MASK_bit.__byte0
#define FIO4MASK0_bit     FIO4MASK_bit.__byte0_bit
#define FIO4MASK1         FIO4MASK_bit.__byte1
#define FIO4MASK1_bit     FIO4MASK_bit.__byte1_bit
#define FIO4MASK2         FIO4MASK_bit.__byte2
#define FIO4MASK2_bit     FIO4MASK_bit.__byte2_bit
#define FIO4MASK3         FIO4MASK_bit.__byte3
#define FIO4MASK3_bit     FIO4MASK_bit.__byte3_bit
#define FIO4MASKL         FIO4MASK_bit.__shortl
#define FIO4MASKL_bit     FIO4MASK_bit.__shortl_bit
#define FIO4MASKU         FIO4MASK_bit.__shortu
#define FIO4MASKU_bit     FIO4MASK_bit.__shortu_bit
#define FIO4PIN         VOLATILE32(0x3FFFC094)
#define FIO4PIN_bit     VOLATILE_TYPE(0x3FFFC094, __fgpio4_bits)
#define FIO4PIN0          FIO4PIN_bit.__byte0
#define FIO4PIN0_bit      FIO4PIN_bit.__byte0_bit
#define FIO4PIN1          FIO4PIN_bit.__byte1
#define FIO4PIN1_bit      FIO4PIN_bit.__byte1_bit
#define FIO4PIN2          FIO4PIN_bit.__byte2
#define FIO4PIN2_bit      FIO4PIN_bit.__byte2_bit
#define FIO4PIN3          FIO4PIN_bit.__byte3
#define FIO4PIN3_bit      FIO4PIN_bit.__byte3_bit
#define FIO4PINL          FIO4PIN_bit.__shortl
#define FIO4PINL_bit      FIO4PIN_bit.__shortl_bit
#define FIO4PINU          FIO4PIN_bit.__shortu
#define FIO4PINU_bit      FIO4PIN_bit.__shortu_bit
#define FIO4SET         VOLATILE32(0x3FFFC098)
#define FIO4SET_bit     VOLATILE_TYPE(0x3FFFC098, __fgpio4_bits)
#define FIO4SET0          FIO4SET_bit.__byte0
#define FIO4SET0_bit      FIO4SET_bit.__byte0_bit
#define FIO4SET1          FIO4SET_bit.__byte1
#define FIO4SET1_bit      FIO4SET_bit.__byte1_bit
#define FIO4SET2          FIO4SET_bit.__byte2
#define FIO4SET2_bit      FIO4SET_bit.__byte2_bit
#define FIO4SET3          FIO4SET_bit.__byte3
#define FIO4SET3_bit      FIO4SET_bit.__byte3_bit
#define FIO4SETL          FIO4SET_bit.__shortl
#define FIO4SETL_bit      FIO4SET_bit.__shortl_bit
#define FIO4SETU          FIO4SET_bit.__shortu
#define FIO4SETU_bit      FIO4SET_bit.__shortu_bit
#define FIO4CLR         VOLATILE32(0x3FFFC09C)
#define FIO4CLR_bit     VOLATILE_TYPE(0x3FFFC09C, __fgpio4_bits)
#define FIO4CLR0          FIO4CLR_bit.__byte0
#define FIO4CLR0_bit      FIO4CLR_bit.__byte0_bit
#define FIO4CLR1          FIO4CLR_bit.__byte1
#define FIO4CLR1_bit      FIO4CLR_bit.__byte1_bit
#define FIO4CLR2          FIO4CLR_bit.__byte2
#define FIO4CLR2_bit      FIO4CLR_bit.__byte2_bit
#define FIO4CLR3          FIO4CLR_bit.__byte3
#define FIO4CLR3_bit      FIO4CLR_bit.__byte3_bit
#define FIO4CLRL          FIO4CLR_bit.__shortl
#define FIO4CLRL_bit      FIO4CLR_bit.__shortl_bit
#define FIO4CLRU          FIO4CLR_bit.__shortu
#define FIO4CLRU_bit      FIO4CLR_bit.__shortu_bit
#define IO0INTENR         VOLATILE32(0xE0028090)
#define IO0INTENR_bit     VOLATILE_TYPE(0xE0028090, __gpio0_bits)
#define IO0INTENF         VOLATILE32(0xE0028094)
#define IO0INTENF_bit     VOLATILE_TYPE(0xE0028094, __gpio0_bits)
#define IO0INTSTATR         VOLATILE32(0xE0028084)
#define IO0INTSTATR_bit     VOLATILE_TYPE(0xE0028084, __gpio0_bits)
#define IO0INTSTATF         VOLATILE32(0xE0028088)
#define IO0INTSTATF_bit     VOLATILE_TYPE(0xE0028088, __gpio0_bits)
#define IO0INTCLR         VOLATILE32(0xE002808C)
#define IO0INTCLR_bit     VOLATILE_TYPE(0xE002808C, __gpio0_bits)
#define IO1INTENR         VOLATILE32(0xE00280B0)
#define IO1INTENR_bit     VOLATILE_TYPE(0xE00280B0, __gpio1_bits)
#define IO1INTENF         VOLATILE32(0xE00280B4)
#define IO1INTENF_bit     VOLATILE_TYPE(0xE00280B4, __gpio1_bits)
#define IO1INTSTATR         VOLATILE32(0xE00280A4)
#define IO1INTSTATR_bit     VOLATILE_TYPE(0xE00280A4, __gpio1_bits)
#define IO1INTSTATF         VOLATILE32(0xE00280A8)
#define IO1INTSTATF_bit     VOLATILE_TYPE(0xE00280A8, __gpio1_bits)
#define IO1INTCLR         VOLATILE32(0xE00280AC)
#define IO1INTCLR_bit     VOLATILE_TYPE(0xE00280AC, __gpio1_bits)
#define IOINTSTATUS         VOLATILE32(0xE0028080)
#define IOINTSTATUS_bit     VOLATILE_TYPE(0xE0028080, __iointst_bits)

/***************************************************************************
 **
 **  ETHERNET
 **
 ***************************************************************************/
#define MAC1         VOLATILE32(0xFFE00000)
#define MAC1_bit     VOLATILE_TYPE(0xFFE00000, __mac1_bits)
#define MAC2         VOLATILE32(0xFFE00004)
#define MAC2_bit     VOLATILE_TYPE(0xFFE00004, __mac2_bits)
#define IPGT         VOLATILE32(0xFFE00008)
#define IPGT_bit     VOLATILE_TYPE(0xFFE00008, __ipgt_bits)
#define IPGR         VOLATILE32(0xFFE0000C)
#define IPGR_bit     VOLATILE_TYPE(0xFFE0000C, __ipgr_bits)
#define CLRT         VOLATILE32(0xFFE00010)
#define CLRT_bit     VOLATILE_TYPE(0xFFE00010, __clrt_bits)
#define MAXF         VOLATILE32(0xFFE00014)
#define MAXF_bit     VOLATILE_TYPE(0xFFE00014, __maxf_bits)
#define SUPP         VOLATILE32(0xFFE00018)
#define SUPP_bit     VOLATILE_TYPE(0xFFE00018, __supp_bits)
#define TEST         VOLATILE32(0xFFE0001C)
#define TEST_bit     VOLATILE_TYPE(0xFFE0001C, __test_bits)
#define MCFG         VOLATILE32(0xFFE00020)
#define MCFG_bit     VOLATILE_TYPE(0xFFE00020, __mcfg_bits)
#define MCMD         VOLATILE32(0xFFE00024)
#define MCMD_bit     VOLATILE_TYPE(0xFFE00024, __mcmd_bits)
#define MADR         VOLATILE32(0xFFE00028)
#define MADR_bit     VOLATILE_TYPE(0xFFE00028, __madr_bits)
#define MWTD         VOLATILE32(0xFFE0002C)
#define MWTD_bit     VOLATILE_TYPE(0xFFE0002C, __mwtd_bits)
#define MRDD         VOLATILE32(0xFFE00030)
#define MRDD_bit     VOLATILE_TYPE(0xFFE00030, __mrdd_bits)
#define MIND         VOLATILE32(0xFFE00034)
#define MIND_bit     VOLATILE_TYPE(0xFFE00034, __mind_bits)
#define SA0         VOLATILE32(0xFFE00040)
#define SA0_bit     VOLATILE_TYPE(0xFFE00040, __sa0_bits)
#define SA1         VOLATILE32(0xFFE00044)
#define SA1_bit     VOLATILE_TYPE(0xFFE00044, __sa1_bits)
#define SA2         VOLATILE32(0xFFE00048)
#define SA2_bit     VOLATILE_TYPE(0xFFE00048, __sa2_bits)
#define COMMAND         VOLATILE32(0xFFE00100)
#define COMMAND_bit     VOLATILE_TYPE(0xFFE00100, __command_bits)
#define STATUS         VOLATILE32(0xFFE00104)
#define STATUS_bit     VOLATILE_TYPE(0xFFE00104, __status_bits)
#define RXDESCRIPTOR           VOLATILE32(0xFFE00108)   //
#define RXSTATUS               VOLATILE32(0xFFE0010C)   //
#define RXDESCRIPTORNUMBER         VOLATILE32(0xFFE00110)
#define RXDESCRIPTORNUMBER_bit     VOLATILE_TYPE(0xFFE00110, __rxdescrn_bits)
#define RXPRODUCEINDEX         VOLATILE32(0xFFE00114)
#define RXPRODUCEINDEX_bit     VOLATILE_TYPE(0xFFE00114, __rxprodind_bits)
#define RXCONSUMEINDEX         VOLATILE32(0xFFE00118)
#define RXCONSUMEINDEX_bit     VOLATILE_TYPE(0xFFE00118, __rxcomind_bits)
#define TXDESCRIPTOR           VOLATILE32(0xFFE0011C)   //
#define TXSTATUS               VOLATILE32(0xFFE00120)   //
#define TXDESCRIPTORNUMBER         VOLATILE32(0xFFE00124)
#define TXDESCRIPTORNUMBER_bit     VOLATILE_TYPE(0xFFE00124, __txdescrn_bits)
#define TXPRODUCEINDEX         VOLATILE32(0xFFE00128)
#define TXPRODUCEINDEX_bit     VOLATILE_TYPE(0xFFE00128, __txprodind_bits)
#define TXCONSUMEINDEX         VOLATILE32(0xFFE0012C)
#define TXCONSUMEINDEX_bit     VOLATILE_TYPE(0xFFE0012C, __txcomind_bits)
#define TSV0         VOLATILE32(0xFFE00158)
#define TSV0_bit     VOLATILE_TYPE(0xFFE00158, __tsv0_bits)
#define TSV1         VOLATILE32(0xFFE0015C)
#define TSV1_bit     VOLATILE_TYPE(0xFFE0015C, __tsv1_bits)
#define RSV         VOLATILE32(0xFFE00160)
#define RSV_bit     VOLATILE_TYPE(0xFFE00160, __rsv_bits)
#define FLOWCONTROLCOUNTER         VOLATILE32(0xFFE00170)
#define FLOWCONTROLCOUNTER_bit     VOLATILE_TYPE(0xFFE00170, __fwctrlcnt_bits)
#define FLOWCONTROLSTATUS         VOLATILE32(0xFFE00174)
#define FLOWCONTROLSTATUS_bit     VOLATILE_TYPE(0xFFE00174, __fwctrlstat_bits)
#define RXFILTERCTRL         VOLATILE32(0xFFE00200)
#define RXFILTERCTRL_bit     VOLATILE_TYPE(0xFFE00200, __rxflctrl_bits)
#define RXFILTERWOLSTATUS         VOLATILE32(0xFFE00204)
#define RXFILTERWOLSTATUS_bit     VOLATILE_TYPE(0xFFE00204, __rxflwolstat_bits)
#define RXFILTERWOLCLEAR         VOLATILE32(0xFFE00208)
#define RXFILTERWOLCLEAR_bit     VOLATILE_TYPE(0xFFE00208, __rxflwolclr_bits)
#define HASHFILTERL            VOLATILE32(0xFFE00210)   //
#define HASHFILTERH            VOLATILE32(0xFFE00214)   //
#define INTSTATUS         VOLATILE32(0xFFE00FE0)
#define INTSTATUS_bit     VOLATILE_TYPE(0xFFE00FE0, __intstat_bits)
#define INTENABLE         VOLATILE32(0xFFE00FE4)
#define INTENABLE_bit     VOLATILE_TYPE(0xFFE00FE4, __intena_bits)
#define INTCLEAR         VOLATILE32(0xFFE00FE8)
#define INTCLEAR_bit     VOLATILE_TYPE(0xFFE00FE8, __intclr_bits)
#define INTSET         VOLATILE32(0xFFE00FEC)
#define INTSET_bit     VOLATILE_TYPE(0xFFE00FEC, __intset_bits)
#define POWERDOWN         VOLATILE32(0xFFE00FF4)
#define POWERDOWN_bit     VOLATILE_TYPE(0xFFE00FF4, __pwrdn_bits)

/***************************************************************************
 **
 ** USB
 **
 ***************************************************************************/
#define USBPORTSEL         VOLATILE32(0xFFE0C110)
#define USBPORTSEL_bit     VOLATILE_TYPE(0xFFE0C110, __usbportsel_bits)
#define USBCLKCTRL         VOLATILE32(0xFFE0CFF4)
#define USBCLKCTRL_bit     VOLATILE_TYPE(0xFFE0CFF4, __usbclkctrl_bits)
#define USBCLKST         VOLATILE32(0xFFE0CFF8)
#define USBCLKST_bit     VOLATILE_TYPE(0xFFE0CFF8, __usbclkctrl_bits)
#define USBINTS         VOLATILE32(0xE01FC1C0)
#define USBINTS_bit     VOLATILE_TYPE(0xE01FC1C0, __usbints_bits)
#define USBDEVINTST         VOLATILE32(0xFFE0C200)
#define USBDEVINTST_bit     VOLATILE_TYPE(0xFFE0C200, __usbdevintst_bits)
#define USBDEVINTEN         VOLATILE32(0xFFE0C204)
#define USBDEVINTEN_bit     VOLATILE_TYPE(0xFFE0C204, __usbdevintst_bits)
#define USBDEVINTCLR         VOLATILE32(0xFFE0C208)
#define USBDEVINTCLR_bit     VOLATILE_TYPE(0xFFE0C208, __usbdevintst_bits)
#define USBDEVINTSET         VOLATILE32(0xFFE0C20C)
#define USBDEVINTSET_bit     VOLATILE_TYPE(0xFFE0C20C, __usbdevintst_bits)
#define USBDEVINTPRI         VOLATILE32(0xFFE0C22C)
#define USBDEVINTPRI_bit     VOLATILE_TYPE(0xFFE0C22C, __usbdevintpri_bits)
#define USBEPINTST         VOLATILE32(0xFFE0C230)
#define USBEPINTST_bit     VOLATILE_TYPE(0xFFE0C230, __usbepintst_bits)
#define USBEPINTEN         VOLATILE32(0xFFE0C234)
#define USBEPINTEN_bit     VOLATILE_TYPE(0xFFE0C234, __usbepintst_bits)
#define USBEPINTCLR         VOLATILE32(0xFFE0C238)
#define USBEPINTCLR_bit     VOLATILE_TYPE(0xFFE0C238, __usbepintst_bits)
#define USBEPINTSET         VOLATILE32(0xFFE0C23C)
#define USBEPINTSET_bit     VOLATILE_TYPE(0xFFE0C23C, __usbepintst_bits)
#define USBEPINTPRI         VOLATILE32(0xFFE0C240)
#define USBEPINTPRI_bit     VOLATILE_TYPE(0xFFE0C240, __usbepintst_bits)
#define USBREEP         VOLATILE32(0xFFE0C244)
#define USBREEP_bit     VOLATILE_TYPE(0xFFE0C244, __usbreep_bits)
#define USBEPIN         VOLATILE32(0xFFE0C248)
#define USBEPIN_bit     VOLATILE_TYPE(0xFFE0C248, __usbepin_bits)
#define USBMAXPSIZE         VOLATILE32(0xFFE0C24C)
#define USBMAXPSIZE_bit     VOLATILE_TYPE(0xFFE0C24C, __usbmaxpsize_bits)
#define USBRXDATA              VOLATILE32(0xFFE0C218)   //
#define USBRXPLEN         VOLATILE32(0xFFE0C220)
#define USBRXPLEN_bit     VOLATILE_TYPE(0xFFE0C220, __usbrxplen_bits)
#define TDATA                  VOLATILE32(0xFFE0C21C)   //
#define USBTXPLEN         VOLATILE32(0xFFE0C224)
#define USBTXPLEN_bit     VOLATILE_TYPE(0xFFE0C224, __usbtxplen_bits)
#define USBCTRL         VOLATILE32(0xFFE0C228)
#define USBCTRL_bit     VOLATILE_TYPE(0xFFE0C228, __usbctrl_bits)
#define USBCMDCODE         VOLATILE32(0xFFE0C210)
#define USBCMDCODE_bit     VOLATILE_TYPE(0xFFE0C210, __usbcmdcode_bits)
#define USBCMDDATA         VOLATILE32(0xFFE0C214)
#define USBCMDDATA_bit     VOLATILE_TYPE(0xFFE0C214, __usbcmddata_bits)
#define USBDMARST         VOLATILE32(0xFFE0C250)
#define USBDMARST_bit     VOLATILE_TYPE(0xFFE0C250, __usbreep_bits)
#define USBDMARCLR         VOLATILE32(0xFFE0C254)
#define USBDMARCLR_bit     VOLATILE_TYPE(0xFFE0C254, __usbreep_bits)
#define USBDMARSET         VOLATILE32(0xFFE0C258)
#define USBDMARSET_bit     VOLATILE_TYPE(0xFFE0C258, __usbreep_bits)
#define USBUDCAH               VOLATILE32(0xFFE0C280)   //
#define USBEPDMAST         VOLATILE32(0xFFE0C284)
#define USBEPDMAST_bit     VOLATILE_TYPE(0xFFE0C284, __usbreep_bits)
#define USBEPDMAEN         VOLATILE32(0xFFE0C288)
#define USBEPDMAEN_bit     VOLATILE_TYPE(0xFFE0C288, __usbreep_bits)
#define USBEPDMADIS         VOLATILE32(0xFFE0C28C)
#define USBEPDMADIS_bit     VOLATILE_TYPE(0xFFE0C28C, __usbreep_bits)
#define USBDMAINTST         VOLATILE32(0xFFE0C290)
#define USBDMAINTST_bit     VOLATILE_TYPE(0xFFE0C290, __usbdmaintst_bits)
#define USBDMAINTEN         VOLATILE32(0xFFE0C294)
#define USBDMAINTEN_bit     VOLATILE_TYPE(0xFFE0C294, __usbdmaintst_bits)
#define USBNDDRINTST         VOLATILE32(0xFFE0C2AC)
#define USBNDDRINTST_bit     VOLATILE_TYPE(0xFFE0C2AC, __usbreep_bits)
#define USBNDDRINTCLR         VOLATILE32(0xFFE0C2B0)
#define USBNDDRINTCLR_bit     VOLATILE_TYPE(0xFFE0C2B0, __usbreep_bits)
#define USBNDDRINTSET         VOLATILE32(0xFFE0C2B4)
#define USBNDDRINTSET_bit     VOLATILE_TYPE(0xFFE0C2B4, __usbreep_bits)
#define USBEOTINTST         VOLATILE32(0xFFE0C2A0)
#define USBEOTINTST_bit     VOLATILE_TYPE(0xFFE0C2A0, __usbreep_bits)
#define USBEOTINTCLR         VOLATILE32(0xFFE0C2A4)
#define USBEOTINTCLR_bit     VOLATILE_TYPE(0xFFE0C2A4, __usbreep_bits)
#define USBEOTINTSET         VOLATILE32(0xFFE0C2A8)
#define USBEOTINTSET_bit     VOLATILE_TYPE(0xFFE0C2A8, __usbreep_bits)
#define USBSYSERRINTST         VOLATILE32(0xFFE0C2B8)
#define USBSYSERRINTST_bit     VOLATILE_TYPE(0xFFE0C2B8, __usbreep_bits)
#define USBSYSERRINTCLR         VOLATILE32(0xFFE0C2BC)
#define USBSYSERRINTCLR_bit     VOLATILE_TYPE(0xFFE0C2BC, __usbreep_bits)
#define USBSYSERRINTSET         VOLATILE32(0xFFE0C2C0)
#define USBSYSERRINTSET_bit     VOLATILE_TYPE(0xFFE0C2C0, __usbreep_bits)

/***************************************************************************
 **
 ** CAN
 **
 ***************************************************************************/
#define AFMR         VOLATILE32(0xE003C000)
#define AFMR_bit     VOLATILE_TYPE(0xE003C000, __afmr_bits)
#define SFF_SA                 VOLATILE32(0xE003C004)   //
#define SFF_GRP_SA             VOLATILE32(0xE003C008)   //
#define EFF_SA                 VOLATILE32(0xE003C00C)   //
#define EFF_GRP_SA             VOLATILE32(0xE003C010)   //
#define ENDOFTABLE             VOLATILE32(0xE003C014)   //
#define LUTERRAD               VOLATILE32(0xE003C018)   //
#define LUTERR                 VOLATILE32(0xE003C01C)   //
#define FCANIE         VOLATILE32(0xE003C020)
#define FCANIE_bit     VOLATILE_TYPE(0xE003C020, __fcanie_bits)
#define FCANIC0         VOLATILE32(0xE003C024)
#define FCANIC0_bit     VOLATILE_TYPE(0xE003C024, __fcanic0_bits)
#define FCANIC1         VOLATILE32(0xE003C028)
#define FCANIC1_bit     VOLATILE_TYPE(0xE003C028, __fcanic1_bits)
#define CANTXSR         VOLATILE32(0xE0040000)
#define CANTXSR_bit     VOLATILE_TYPE(0xE0040000, __cantxsr_bits)
#define CANRXSR         VOLATILE32(0xE0040004)
#define CANRXSR_bit     VOLATILE_TYPE(0xE0040004, __canrxsr_bits)
#define CANMSR         VOLATILE32(0xE0040008)
#define CANMSR_bit     VOLATILE_TYPE(0xE0040008, __canmsr_bits)
#define CAN1MOD         VOLATILE32(0xE0044000)
#define CAN1MOD_bit     VOLATILE_TYPE(0xE0044000, __canmod_bits)
#define CAN1CMR         VOLATILE32(0xE0044004)
#define CAN1CMR_bit     VOLATILE_TYPE(0xE0044004, __cancmr_bits)
#define CAN1GSR         VOLATILE32(0xE0044008)
#define CAN1GSR_bit     VOLATILE_TYPE(0xE0044008, __cangsr_bits)
#define CAN1ICR         VOLATILE32(0xE004400C)
#define CAN1ICR_bit     VOLATILE_TYPE(0xE004400C, __canicr_bits)
#define CAN1IER         VOLATILE32(0xE0044010)
#define CAN1IER_bit     VOLATILE_TYPE(0xE0044010, __canier_bits)
#define CAN1BTR         VOLATILE32(0xE0044014)
#define CAN1BTR_bit     VOLATILE_TYPE(0xE0044014, __canbtr_bits)
#define CAN1EWL         VOLATILE32(0xE0044018)
#define CAN1EWL_bit     VOLATILE_TYPE(0xE0044018, __canewl_bits)
#define CAN1SR         VOLATILE32(0xE004401C)
#define CAN1SR_bit     VOLATILE_TYPE(0xE004401C, __cansr_bits)
#define CAN1RFS         VOLATILE32(0xE0044020)
#define CAN1RFS_bit     VOLATILE_TYPE(0xE0044020, __canrfs_bits)
#define CAN1RID         VOLATILE32(0xE0044024)
#define CAN1RID_bit     VOLATILE_TYPE(0xE0044024, __canrid_bits)
#define CAN1RDA         VOLATILE32(0xE0044028)
#define CAN1RDA_bit     VOLATILE_TYPE(0xE0044028, __canrda_bits)
#define CAN1RDB         VOLATILE32(0xE004402C)
#define CAN1RDB_bit     VOLATILE_TYPE(0xE004402C, __canrdb_bits)
#define CAN1TFI1         VOLATILE32(0xE0044030)
#define CAN1TFI1_bit     VOLATILE_TYPE(0xE0044030, __cantfi_bits)
#define CAN1TID1         VOLATILE32(0xE0044034)
#define CAN1TID1_bit     VOLATILE_TYPE(0xE0044034, __cantid_bits)
#define CAN1TDA1         VOLATILE32(0xE0044038)
#define CAN1TDA1_bit     VOLATILE_TYPE(0xE0044038, __cantda_bits)
#define CAN1TDB1         VOLATILE32(0xE004403C)
#define CAN1TDB1_bit     VOLATILE_TYPE(0xE004403C, __cantdb_bits)
#define CAN1TFI2         VOLATILE32(0xE0044040)
#define CAN1TFI2_bit     VOLATILE_TYPE(0xE0044040, __cantfi_bits)
#define CAN1TID2         VOLATILE32(0xE0044044)
#define CAN1TID2_bit     VOLATILE_TYPE(0xE0044044, __cantid_bits)
#define CAN1TDA2         VOLATILE32(0xE0044048)
#define CAN1TDA2_bit     VOLATILE_TYPE(0xE0044048, __cantda_bits)
#define CAN1TDB2         VOLATILE32(0xE004404C)
#define CAN1TDB2_bit     VOLATILE_TYPE(0xE004404C, __cantdb_bits)
#define CAN1TFI3         VOLATILE32(0xE0044050)
#define CAN1TFI3_bit     VOLATILE_TYPE(0xE0044050, __cantfi_bits)
#define CAN1TID3         VOLATILE32(0xE0044054)
#define CAN1TID3_bit     VOLATILE_TYPE(0xE0044054, __cantid_bits)
#define CAN1TDA3         VOLATILE32(0xE0044058)
#define CAN1TDA3_bit     VOLATILE_TYPE(0xE0044058, __cantda_bits)
#define CAN1TDB3         VOLATILE32(0xE004405C)
#define CAN1TDB3_bit     VOLATILE_TYPE(0xE004405C, __cantdb_bits)
#define CAN2MOD         VOLATILE32(0xE0048000)
#define CAN2MOD_bit     VOLATILE_TYPE(0xE0048000, __canmod_bits)
#define CAN2CMR         VOLATILE32(0xE0048004)
#define CAN2CMR_bit     VOLATILE_TYPE(0xE0048004, __cancmr_bits)
#define CAN2GSR         VOLATILE32(0xE0048008)
#define CAN2GSR_bit     VOLATILE_TYPE(0xE0048008, __cangsr_bits)
#define CAN2ICR         VOLATILE32(0xE004800C)
#define CAN2ICR_bit     VOLATILE_TYPE(0xE004800C, __canicr_bits)
#define CAN2IER         VOLATILE32(0xE0048010)
#define CAN2IER_bit     VOLATILE_TYPE(0xE0048010, __canier_bits)
#define CAN2BTR         VOLATILE32(0xE0048014)
#define CAN2BTR_bit     VOLATILE_TYPE(0xE0048014, __canbtr_bits)
#define CAN2EWL         VOLATILE32(0xE0048018)
#define CAN2EWL_bit     VOLATILE_TYPE(0xE0048018, __canewl_bits)
#define CAN2SR         VOLATILE32(0xE004801C)
#define CAN2SR_bit     VOLATILE_TYPE(0xE004801C, __cansr_bits)
#define CAN2RFS         VOLATILE32(0xE0048020)
#define CAN2RFS_bit     VOLATILE_TYPE(0xE0048020, __canrfs_bits)
#define CAN2RID         VOLATILE32(0xE0048024)
#define CAN2RID_bit     VOLATILE_TYPE(0xE0048024, __canrid_bits)
#define CAN2RDA         VOLATILE32(0xE0048028)
#define CAN2RDA_bit     VOLATILE_TYPE(0xE0048028, __canrda_bits)
#define CAN2RDB         VOLATILE32(0xE004802C)
#define CAN2RDB_bit     VOLATILE_TYPE(0xE004802C, __canrdb_bits)
#define CAN2TFI1         VOLATILE32(0xE0048030)
#define CAN2TFI1_bit     VOLATILE_TYPE(0xE0048030, __cantfi_bits)
#define CAN2TID1         VOLATILE32(0xE0048034)
#define CAN2TID1_bit     VOLATILE_TYPE(0xE0048034, __cantid_bits)
#define CAN2TDA1         VOLATILE32(0xE0048038)
#define CAN2TDA1_bit     VOLATILE_TYPE(0xE0048038, __cantda_bits)
#define CAN2TDB1         VOLATILE32(0xE004803C)
#define CAN2TDB1_bit     VOLATILE_TYPE(0xE004803C, __cantdb_bits)
#define CAN2TFI2         VOLATILE32(0xE0048040)
#define CAN2TFI2_bit     VOLATILE_TYPE(0xE0048040, __cantfi_bits)
#define CAN2TID2         VOLATILE32(0xE0048044)
#define CAN2TID2_bit     VOLATILE_TYPE(0xE0048044, __cantid_bits)
#define CAN2TDA2         VOLATILE32(0xE0048048)
#define CAN2TDA2_bit     VOLATILE_TYPE(0xE0048048, __cantda_bits)
#define CAN2TDB2         VOLATILE32(0xE004804C)
#define CAN2TDB2_bit     VOLATILE_TYPE(0xE004804C, __cantdb_bits)
#define CAN2TFI3         VOLATILE32(0xE0048050)
#define CAN2TFI3_bit     VOLATILE_TYPE(0xE0048050, __cantfi_bits)
#define CAN2TID3         VOLATILE32(0xE0048054)
#define CAN2TID3_bit     VOLATILE_TYPE(0xE0048054, __cantid_bits)
#define CAN2TDA3         VOLATILE32(0xE0048058)
#define CAN2TDA3_bit     VOLATILE_TYPE(0xE0048058, __cantda_bits)
#define CAN2TDB3         VOLATILE32(0xE004805C)
#define CAN2TDB3_bit     VOLATILE_TYPE(0xE004805C, __cantdb_bits)

/***************************************************************************
 **
 **  UART0
 **
 ***************************************************************************/
/* U0DLL  U0RBR and U0THR share the same address */
#define U0RBRTHR               VOLATILE32(0xE000C000)   //
#define U0DLL                  VOLATILE32(0xE000C000)   //
#define U0RBR                  VOLATILE32(0xE000C000)   //
#define U0THR                  VOLATILE32(0xE000C000)   //

/* U0DLM and U0IER share the same address */
#define U0IER         VOLATILE32(0xE000C004)
#define U0IER_bit     VOLATILE_TYPE(0xE000C004, __uartier0_bits)
#define U0DLM         VOLATILE32(0xE000C004)
#define U0DLM_bit     VOLATILE_TYPE(0xE000C004, __uartier0_bits)

/* U0FCR and U0IIR share the same address */
#define U0FCR         VOLATILE32(0xE000C008)
#define U0FCR_bit     VOLATILE_TYPE(0xE000C008, __uartfcriir_bits)
#define U0IIR                  VOLATILE32(0xE000C008
#define U0IIR_bit  U0FCR_bit

#define U0LCR         VOLATILE32(0xE000C00C)
#define U0LCR_bit     VOLATILE_TYPE(0xE000C00C, __uartlcr_bits)
#define U0LSR         VOLATILE32(0xE000C014)
#define U0LSR_bit     VOLATILE_TYPE(0xE000C014, __uartlsr_bits)
#define U0SCR                  VOLATILE32(0xE000C01C)   //
#define U0ACR         VOLATILE32(0xE000C020)
#define U0ACR_bit     VOLATILE_TYPE(0xE000C020, __uartacr_bits)
#define U0FDR         VOLATILE32(0xE000C028)
#define U0FDR_bit     VOLATILE_TYPE(0xE000C028, __uartfdr_bits)
#define U0TER         VOLATILE32(0xE000C030)
#define U0TER_bit     VOLATILE_TYPE(0xE000C030, __uartter_bits)

/***************************************************************************
 **
 **  UART1
 **
 ***************************************************************************/
/* U1DLL  U1RBR and U1THR share the same address */
#define U1RBRTHR               VOLATILE32(0xE0010000)   //
#define U1DLL U1RBRTHR
#define U1RBR U1RBRTHR
#define U1THR U1RBRTHR

/* U1DLM and U1IER share the same address */
#define U1IER         VOLATILE32(0xE0010004)
#define U1IER_bit     VOLATILE_TYPE(0xE0010004, __uartier1_bits)
#define U1DLM      U1IER

/* U1FCR and U1IIR share the same address */
#define U1FCR         VOLATILE32(0xE0010008)
#define U1FCR_bit     VOLATILE_TYPE(0xE0010008, __uartfcriir_bits)
#define U1IIR      U1FCR
#define U1IIR_bit  U1FCR_bit

#define U1LCR         VOLATILE32(0xE001000C)
#define U1LCR_bit     VOLATILE_TYPE(0xE001000C, __uartlcr_bits)
#define U1MCR         VOLATILE32(0xE0010010)
#define U1MCR_bit     VOLATILE_TYPE(0xE0010010, __uartmcr_bits)
#define U1LSR         VOLATILE32(0xE0010014)
#define U1LSR_bit     VOLATILE_TYPE(0xE0010014, __uartlsr_bits)
#define U1MSR         VOLATILE32(0xE0010018)
#define U1MSR_bit     VOLATILE_TYPE(0xE0010018, __uartmsr_bits)
#define U1SCR                  VOLATILE32(0xE001001C)   //
#define U1ACR         VOLATILE32(0xE0010020)
#define U1ACR_bit     VOLATILE_TYPE(0xE0010020, __uartacr_bits)
#define U1FDR         VOLATILE32(0xE0010028)
#define U1FDR_bit     VOLATILE_TYPE(0xE0010028, __uartfdr_bits)
#define U1TER         VOLATILE32(0xE0010030)
#define U1TER_bit     VOLATILE_TYPE(0xE0010030, __uartter_bits)

/***************************************************************************
 **
 **  UART2
 **
 ***************************************************************************/
/* U2DLL, U2RBR and U2THR share the same address */
#define U2RBRTHR               VOLATILE32(0xE0078000)   //
#define U2DLL U2RBRTHR
#define U2RBR U2RBRTHR
#define U2THR U2RBRTHR

/* U2DLM and U2IER share the same address */
#define U2IER         VOLATILE32(0xE0078004)
#define U2IER_bit     VOLATILE_TYPE(0xE0078004, __uartier0_bits)
#define U2DLM      U2IER

/* U2FCR and U2IIR share the same address */
#define U2FCR         VOLATILE32(0xE0078008)
#define U2FCR_bit     VOLATILE_TYPE(0xE0078008, __uartfcriir_bits)
#define U2IIR      U2FCR
#define U2IIR_bit  U2FCR_bit

#define U2LCR         VOLATILE32(0xE007800C)
#define U2LCR_bit     VOLATILE_TYPE(0xE007800C, __uartlcr_bits)
#define U2LSR         VOLATILE32(0xE0078014)
#define U2LSR_bit     VOLATILE_TYPE(0xE0078014, __uartlsr_bits)
#define U2SCR                  VOLATILE32(0xE007801C)   //
#define U2ACR         VOLATILE32(0xE0078020)
#define U2ACR_bit     VOLATILE_TYPE(0xE0078020, __uartacr_bits)
#define U2FDR         VOLATILE32(0xE0078028)
#define U2FDR_bit     VOLATILE_TYPE(0xE0078028, __uartfdr_bits)
#define U2TER         VOLATILE32(0xE0078030)
#define U2TER_bit     VOLATILE_TYPE(0xE0078030, __uartter_bits)

/***************************************************************************
 **
 **  UART3
 **
 ***************************************************************************/
/* U3DLL, U3RBR and U3THR share the same address */
#define U3RBRTHR               VOLATILE32(0xE007C000)   //
#define U3DLL U3RBRTHR
#define U3RBR U3RBRTHR
#define U3THR U3RBRTHR

/* U3DLM and U3IER share the same address */
#define U3IER         VOLATILE32(0xE007C004)
#define U3IER_bit     VOLATILE_TYPE(0xE007C004, __uartier0_bits)
#define U3DLM      U3IER

/* U3FCR and U3IIR share the same address */
#define U3FCR         VOLATILE32(0xE007C008)
#define U3FCR_bit     VOLATILE_TYPE(0xE007C008, __uartfcriir_bits)
#define U3IIR      U3FCR
#define U3IIR_bit  U3FCR_bit

#define U3LCR         VOLATILE32(0xE007C00C)
#define U3LCR_bit     VOLATILE_TYPE(0xE007C00C, __uartlcr_bits)
#define U3LSR         VOLATILE32(0xE007C014)
#define U3LSR_bit     VOLATILE_TYPE(0xE007C014, __uartlsr_bits)
#define U3SCR                  VOLATILE32(0xE007C01C)   //
#define U3ACR         VOLATILE32(0xE007C020)
#define U3ACR_bit     VOLATILE_TYPE(0xE007C020, __uartacr_bits)
#define U3ICR         VOLATILE32(0xE007C024)
#define U3ICR_bit     VOLATILE_TYPE(0xE007C024, __uarticr_bits)
#define U3FDR         VOLATILE32(0xE007C028)
#define U3FDR_bit     VOLATILE_TYPE(0xE007C028, __uartfdr_bits)
#define U3TER         VOLATILE32(0xE007C030)
#define U3TER_bit     VOLATILE_TYPE(0xE007C030, __uartter_bits)

/***************************************************************************
 **
 ** SPI
 **
 ***************************************************************************/
#define S0SPCR         VOLATILE32(0xE0020000)
#define S0SPCR_bit     VOLATILE_TYPE(0xE0020000, __spcr_bits)
#define S0SPSR         VOLATILE32(0xE0020004)
#define S0SPSR_bit     VOLATILE_TYPE(0xE0020004, __spsr_bits)
#define S0SPDR                 VOLATILE32(0xE0020008)   //
#define S0SPCCR         VOLATILE32(0xE002000C)
#define S0SPCCR_bit     VOLATILE_TYPE(0xE002000C, __spccr_bits)
#define SPTCR         VOLATILE32(0xE0020010)
#define SPTCR_bit     VOLATILE_TYPE(0xE0020010, __sptcr_bits)
#define SPTSR         VOLATILE32(0xE0020014)
#define SPTSR_bit     VOLATILE_TYPE(0xE0020014, __sptsr_bits)
#define S0SPINT         VOLATILE32(0xE002001C)
#define S0SPINT_bit     VOLATILE_TYPE(0xE002001C, __spint_bits)

/***************************************************************************
 **
 ** SSP0
 **
 ***************************************************************************/
#define SSP0CR0         VOLATILE32(0xE0068000)
#define SSP0CR0_bit     VOLATILE_TYPE(0xE0068000, __sspcr0_bits)
#define SSP0CR1         VOLATILE32(0xE0068004)
#define SSP0CR1_bit     VOLATILE_TYPE(0xE0068004, __sspcr1_bits)
#define SSP0DR         VOLATILE32(0xE0068008)
#define SSP0DR_bit     VOLATILE_TYPE(0xE0068008, __sspdr_bits)
#define SSP0SR         VOLATILE32(0xE006800C)
#define SSP0SR_bit     VOLATILE_TYPE(0xE006800C, __sspsr_bits)
#define SSP0CPSR         VOLATILE32(0xE0068010)
#define SSP0CPSR_bit     VOLATILE_TYPE(0xE0068010, __sspcpsr_bits)
#define SSP0IMSC         VOLATILE32(0xE0068014)
#define SSP0IMSC_bit     VOLATILE_TYPE(0xE0068014, __sspimsc_bits)
#define SSP0RIS         VOLATILE32(0xE0068018)
#define SSP0RIS_bit     VOLATILE_TYPE(0xE0068018, __sspris_bits)
#define SSP0MIS         VOLATILE32(0xE006801C)
#define SSP0MIS_bit     VOLATILE_TYPE(0xE006801C, __sspmis_bits)
#define SSP0ICR         VOLATILE32(0xE0068020)
#define SSP0ICR_bit     VOLATILE_TYPE(0xE0068020, __sspicr_bits)
#define SSP0DMACR         VOLATILE32(0xE0068024)
#define SSP0DMACR_bit     VOLATILE_TYPE(0xE0068024, __sspdmacr_bits)

/***************************************************************************
 **
 ** SSP1
 **
 ***************************************************************************/
#define SSP1CR0         VOLATILE32(0xE0030000)
#define SSP1CR0_bit     VOLATILE_TYPE(0xE0030000, __sspcr0_bits)
#define SSP1CR1         VOLATILE32(0xE0030004)
#define SSP1CR1_bit     VOLATILE_TYPE(0xE0030004, __sspcr1_bits)
#define SSP1DR         VOLATILE32(0xE0030008)
#define SSP1DR_bit     VOLATILE_TYPE(0xE0030008, __sspdr_bits)
#define SSP1SR         VOLATILE32(0xE003000C)
#define SSP1SR_bit     VOLATILE_TYPE(0xE003000C, __sspsr_bits)
#define SSP1CPSR         VOLATILE32(0xE0030010)
#define SSP1CPSR_bit     VOLATILE_TYPE(0xE0030010, __sspcpsr_bits)
#define SSP1IMSC         VOLATILE32(0xE0030014)
#define SSP1IMSC_bit     VOLATILE_TYPE(0xE0030014, __sspimsc_bits)
#define SSP1RIS         VOLATILE32(0xE0030018)
#define SSP1RIS_bit     VOLATILE_TYPE(0xE0030018, __sspris_bits)
#define SSP1MIS         VOLATILE32(0xE003001C)
#define SSP1MIS_bit     VOLATILE_TYPE(0xE003001C, __sspmis_bits)
#define SSP1ICR         VOLATILE32(0xE0030020)
#define SSP1ICR_bit     VOLATILE_TYPE(0xE0030020, __sspicr_bits)
#define SSP1DMACR         VOLATILE32(0xE0030024)
#define SSP1DMACR_bit     VOLATILE_TYPE(0xE0030024, __sspdmacr_bits)

/***************************************************************************
 **
 ** SD/MMC
 **
 ***************************************************************************/
#define MCIPOWER         VOLATILE32(0xE008C000)
#define MCIPOWER_bit     VOLATILE_TYPE(0xE008C000, __mcipower_bits)
#define MCICLOCK         VOLATILE32(0xE008C004)
#define MCICLOCK_bit     VOLATILE_TYPE(0xE008C004, __mciclock_bits)
#define MCIARGUMENT            VOLATILE32(0xE008C008)   //
#define MCICOMMAND         VOLATILE32(0xE008C00C)
#define MCICOMMAND_bit     VOLATILE_TYPE(0xE008C00C, __mcicommand_bits)
#define MCIRESPCMD         VOLATILE32(0xE008C010)
#define MCIRESPCMD_bit     VOLATILE_TYPE(0xE008C010, __mcirespcmd_bits)
#define MCIRESPONSE0           VOLATILE32(0xE008C014)   //
#define MCIRESPONSE1           VOLATILE32(0xE008C018)   //
#define MCIRESPONSE2           VOLATILE32(0xE008C01C)   //
#define MCIRESPONSE3           VOLATILE32(0xE008C020)   //
#define MCIDATATIMER           VOLATILE32(0xE008C024)   //
#define MCIDATALENGTH          VOLATILE32(0xE008C028)   //
#define MCIDATACTRL         VOLATILE32(0xE008C02C)
#define MCIDATACTRL_bit     VOLATILE_TYPE(0xE008C02C, __mcidatactrl_bits)
#define MCIDATACNT             VOLATILE32(0xE008C030)   //
#define MCISTATUS         VOLATILE32(0xE008C034)
#define MCISTATUS_bit     VOLATILE_TYPE(0xE008C034, __mcistatus_bits)
#define MCICLEAR         VOLATILE32(0xE008C038)
#define MCICLEAR_bit     VOLATILE_TYPE(0xE008C038, __mciclear_bits)
#define MCIMASK0         VOLATILE32(0xE008C03C)
#define MCIMASK0_bit     VOLATILE_TYPE(0xE008C03C, __mcistatus_bits)
#define MCIMASK1         VOLATILE32(0xE008C040)
#define MCIMASK1_bit     VOLATILE_TYPE(0xE008C040, __mcistatus_bits)
#define MCIFIFOCNT         VOLATILE32(0xE008C048)
#define MCIFIFOCNT_bit     VOLATILE_TYPE(0xE008C048, __mcififocnt_bits)
#define MCIFIFO0               VOLATILE32(0xE008C080)   //
#define MCIFIFO1               VOLATILE32(0xE008C084)   //
#define MCIFIFO2               VOLATILE32(0xE008C088)   //
#define MCIFIFO3               VOLATILE32(0xE008C08C)   //
#define MCIFIFO4               VOLATILE32(0xE008C090)   //
#define MCIFIFO5               VOLATILE32(0xE008C094)   //
#define MCIFIFO6               VOLATILE32(0xE008C098)   //
#define MCIFIFO7               VOLATILE32(0xE008C09C)   //
#define MCIFIFO8               VOLATILE32(0xE008C0A0)   //
#define MCIFIFO9               VOLATILE32(0xE008C0A4)   //
#define MCIFIFO10              VOLATILE32(0xE008C0A8)   //
#define MCIFIFO11              VOLATILE32(0xE008C0AC)   //
#define MCIFIFO12              VOLATILE32(0xE008C0B0)   //
#define MCIFIFO13              VOLATILE32(0xE008C0B4)   //
#define MCIFIFO14              VOLATILE32(0xE008C0B8)   //
#define MCIFIFO15              VOLATILE32(0xE008C0BC)   //

/***************************************************************************
 **
 ** I2C0
 **
 ***************************************************************************/
#define I2C0CONSET         VOLATILE32(0xE001C000)
#define I2C0CONSET_bit     VOLATILE_TYPE(0xE001C000, __i2conset_bits)
#define I2C0STAT         VOLATILE32(0xE001C004)
#define I2C0STAT_bit     VOLATILE_TYPE(0xE001C004, __i2stat_bits)
#define I2C0DAT         VOLATILE32(0xE001C008)
#define I2C0DAT_bit     VOLATILE_TYPE(0xE001C008, __i2dat_bits)
#define I2C0ADR         VOLATILE32(0xE001C00C)
#define I2C0ADR_bit     VOLATILE_TYPE(0xE001C00C, __i2adr_bits)
#define I2C0SCLH         VOLATILE32(0xE001C010)
#define I2C0SCLH_bit     VOLATILE_TYPE(0xE001C010, __i2sch_bits)
#define I2C0SCLL         VOLATILE32(0xE001C014)
#define I2C0SCLL_bit     VOLATILE_TYPE(0xE001C014, __i2scl_bits)
#define I2C0CONCLR         VOLATILE32(0xE001C018)
#define I2C0CONCLR_bit     VOLATILE_TYPE(0xE001C018, __i2conclr_bits)

//The names of the registers above have been corrected according to the chip
//documentation. The defines below are aliases with the old names for backwards
//compatibility.
#define I20CONSET I2C0CONSET
#define I20STAT   I2C0STAT
#define I20DAT    I2C0DAT
#define I20ADR    I2C0ADR
#define I20SCLH   I2C0SCLH
#define I20SCLL   I2C0SCLL
#define I20CONCLR I2C0CONCLR

/***************************************************************************
 **
 ** I2C1
 **
 ***************************************************************************/
#define I2C1CONSET         VOLATILE32(0xE005C000)
#define I2C1CONSET_bit     VOLATILE_TYPE(0xE005C000, __i2conset_bits)
#define I2C1STAT         VOLATILE32(0xE005C004)
#define I2C1STAT_bit     VOLATILE_TYPE(0xE005C004, __i2stat_bits)
#define I2C1DAT         VOLATILE32(0xE005C008)
#define I2C1DAT_bit     VOLATILE_TYPE(0xE005C008, __i2dat_bits)
#define I2C1ADR         VOLATILE32(0xE005C00C)
#define I2C1ADR_bit     VOLATILE_TYPE(0xE005C00C, __i2adr_bits)
#define I2C1SCLH         VOLATILE32(0xE005C010)
#define I2C1SCLH_bit     VOLATILE_TYPE(0xE005C010, __i2sch_bits)
#define I2C1SCLL         VOLATILE32(0xE005C014)
#define I2C1SCLL_bit     VOLATILE_TYPE(0xE005C014, __i2scl_bits)
#define I2C1CONCLR         VOLATILE32(0xE005C018)
#define I2C1CONCLR_bit     VOLATILE_TYPE(0xE005C018, __i2conclr_bits)

//The names of the registers above have been corrected according to the chip
//documentation. The defines below are aliases with the old names for backwards
//compatibility.
#define I21CONSET I2C1CONSET
#define I21STAT   I2C1STAT
#define I21DAT    I2C1DAT
#define I21ADR    I2C1ADR
#define I21SCLH   I2C1SCLH
#define I21SCLL   I2C1SCLL
#define I21CONCLR I2C1CONCLR

/***************************************************************************
 **
 ** I2C2
 **
 ***************************************************************************/
#define I2C2CONSET         VOLATILE32(0xE0080000)
#define I2C2CONSET_bit     VOLATILE_TYPE(0xE0080000, __i2conset_bits)
#define I2C2STAT         VOLATILE32(0xE0080004)
#define I2C2STAT_bit     VOLATILE_TYPE(0xE0080004, __i2stat_bits)
#define I2C2DAT         VOLATILE32(0xE0080008)
#define I2C2DAT_bit     VOLATILE_TYPE(0xE0080008, __i2dat_bits)
#define I2C2ADR         VOLATILE32(0xE008000C)
#define I2C2ADR_bit     VOLATILE_TYPE(0xE008000C, __i2adr_bits)
#define I2C2SCLH         VOLATILE32(0xE0080010)
#define I2C2SCLH_bit     VOLATILE_TYPE(0xE0080010, __i2sch_bits)
#define I2C2SCLL         VOLATILE32(0xE0080014)
#define I2C2SCLL_bit     VOLATILE_TYPE(0xE0080014, __i2scl_bits)
#define I2C2CONCLR         VOLATILE32(0xE0080018)
#define I2C2CONCLR_bit     VOLATILE_TYPE(0xE0080018, __i2conclr_bits)

/***************************************************************************
 **
 ** I2S
 **
 ***************************************************************************/
#define I2SDAO         VOLATILE32(0xE0088000)
#define I2SDAO_bit     VOLATILE_TYPE(0xE0088000, __i2sdao_bits)
#define I2SDAI         VOLATILE32(0xE0088004)
#define I2SDAI_bit     VOLATILE_TYPE(0xE0088004, __i2sdai_bits)
#define I2STXFIFO              VOLATILE32(0xE0088008)   //
#define I2SRXFIFO              VOLATILE32(0xE008800C)   //
#define I2SSTATE         VOLATILE32(0xE0088010)
#define I2SSTATE_bit     VOLATILE_TYPE(0xE0088010, __i2sstate_bits)
#define I2SDMA1         VOLATILE32(0xE0088014)
#define I2SDMA1_bit     VOLATILE_TYPE(0xE0088014, __i2sdma_bits)
#define I2SDMA2         VOLATILE32(0xE0088018)
#define I2SDMA2_bit     VOLATILE_TYPE(0xE0088018, __i2sdma_bits)
#define I2SIRQ         VOLATILE32(0xE008801C)
#define I2SIRQ_bit     VOLATILE_TYPE(0xE008801C, __i2sirq_bits)
#define I2STXRATE         VOLATILE32(0xE0088020)
#define I2STXRATE_bit     VOLATILE_TYPE(0xE0088020, __i2stxrate_bits)
#define I2SRXRATE         VOLATILE32(0xE0088024)
#define I2SRXRATE_bit     VOLATILE_TYPE(0xE0088024, __i2srxrate_bits)

/***************************************************************************
 **
 ** TIMER0
 **
 ***************************************************************************/
#define T0IR         VOLATILE32(0xE0004000)
#define T0IR_bit     VOLATILE_TYPE(0xE0004000, __ir_bits)
#define T0TCR         VOLATILE32(0xE0004004)
#define T0TCR_bit     VOLATILE_TYPE(0xE0004004, __tcr_bits)
#define T0TC                   VOLATILE32(0xE0004008)   //
#define T0PR                   VOLATILE32(0xE000400C)   //
#define T0PC                   VOLATILE32(0xE0004010)   //
#define T0MCR         VOLATILE32(0xE0004014)
#define T0MCR_bit     VOLATILE_TYPE(0xE0004014, __mcr_bits)
#define T0MR0                  VOLATILE32(0xE0004018)   //
#define T0MR1                  VOLATILE32(0xE000401C)   //
#define T0MR2                  VOLATILE32(0xE0004020)   //
#define T0MR3                  VOLATILE32(0xE0004024)   //
#define T0CCR         VOLATILE32(0xE0004028)
#define T0CCR_bit     VOLATILE_TYPE(0xE0004028, __ccr_bits)
#define T0CR0                  VOLATILE32(0xE000402C)   //
#define T0CR1                  VOLATILE32(0xE0004030)   //
#define T0CR2                  VOLATILE32(0xE0004034)   //
#define T0CR3                  VOLATILE32(0xE0004038)   //
#define T0EMR         VOLATILE32(0xE000403C)
#define T0EMR_bit     VOLATILE_TYPE(0xE000403C, __emr_bits)
#define T0CTCR         VOLATILE32(0xE0004070)
#define T0CTCR_bit     VOLATILE_TYPE(0xE0004070, __ctcr_bits)

/***************************************************************************
 **
 ** TIMER1
 **
 ***************************************************************************/
#define T1IR         VOLATILE32(0xE0008000)
#define T1IR_bit     VOLATILE_TYPE(0xE0008000, __ir_bits)
#define T1TCR         VOLATILE32(0xE0008004)
#define T1TCR_bit     VOLATILE_TYPE(0xE0008004, __tcr_bits)
#define T1TC                   VOLATILE32(0xE0008008)   //
#define T1PR                   VOLATILE32(0xE000800C)   //
#define T1PC                   VOLATILE32(0xE0008010)   //
#define T1MCR         VOLATILE32(0xE0008014)
#define T1MCR_bit     VOLATILE_TYPE(0xE0008014, __mcr_bits)
#define T1MR0                  VOLATILE32(0xE0008018)   //
#define T1MR1                  VOLATILE32(0xE000801C)   //
#define T1MR2                  VOLATILE32(0xE0008020)   //
#define T1MR3                  VOLATILE32(0xE0008024)   //
#define T1CCR         VOLATILE32(0xE0008028)
#define T1CCR_bit     VOLATILE_TYPE(0xE0008028, __ccr_bits)
#define T1CR0                  VOLATILE32(0xE000802C)   //
#define T1CR1                  VOLATILE32(0xE0008030)   //
#define T1CR2                  VOLATILE32(0xE0008034)   //
#define T1CR3                  VOLATILE32(0xE0008038)   //
#define T1EMR         VOLATILE32(0xE000803C)
#define T1EMR_bit     VOLATILE_TYPE(0xE000803C, __emr_bits)
#define T1CTCR         VOLATILE32(0xE0008070)
#define T1CTCR_bit     VOLATILE_TYPE(0xE0008070, __ctcr_bits)

/***************************************************************************
 **
 ** TIMER2
 **
 ***************************************************************************/
#define T2IR         VOLATILE32(0xE0070000)
#define T2IR_bit     VOLATILE_TYPE(0xE0070000, __ir_bits)
#define T2TCR         VOLATILE32(0xE0070004)
#define T2TCR_bit     VOLATILE_TYPE(0xE0070004, __tcr_bits)
#define T2TC                   VOLATILE32(0xE0070008)   //
#define T2PR                   VOLATILE32(0xE007000C)   //
#define T2PC                   VOLATILE32(0xE0070010)   //
#define T2MCR         VOLATILE32(0xE0070014)
#define T2MCR_bit     VOLATILE_TYPE(0xE0070014, __mcr_bits)
#define T2MR0                  VOLATILE32(0xE0070018)   //
#define T2MR1                  VOLATILE32(0xE007001C)   //
#define T2MR2                  VOLATILE32(0xE0070020)   //
#define T2MR3                  VOLATILE32(0xE0070024)   //
#define T2CCR         VOLATILE32(0xE0070028)
#define T2CCR_bit     VOLATILE_TYPE(0xE0070028, __ccr_bits)
#define T2CR0                  VOLATILE32(0xE007002C)   //
#define T2CR1                  VOLATILE32(0xE0070030)   //
#define T2CR2                  VOLATILE32(0xE0070034)   //
#define T2CR3                  VOLATILE32(0xE0070038)   //
#define T2EMR         VOLATILE32(0xE007003C)
#define T2EMR_bit     VOLATILE_TYPE(0xE007003C, __emr_bits)
#define T2CTCR         VOLATILE32(0xE0070070)
#define T2CTCR_bit     VOLATILE_TYPE(0xE0070070, __ctcr_bits)

/***************************************************************************
 **
 ** TIMER3
 **
 ***************************************************************************/
#define T3IR         VOLATILE32(0xE0074000)
#define T3IR_bit     VOLATILE_TYPE(0xE0074000, __ir_bits)
#define T3TCR         VOLATILE32(0xE0074004)
#define T3TCR_bit     VOLATILE_TYPE(0xE0074004, __tcr_bits)
#define T3TC                   VOLATILE32(0xE0074008)   //
#define T3PR                   VOLATILE32(0xE007400C)   //
#define T3PC                   VOLATILE32(0xE0074010)   //
#define T3MCR         VOLATILE32(0xE0074014)
#define T3MCR_bit     VOLATILE_TYPE(0xE0074014, __mcr_bits)
#define T3MR0                  VOLATILE32(0xE0074018)   //
#define T3MR1                  VOLATILE32(0xE007401C)   //
#define T3MR2                  VOLATILE32(0xE0074020)   //
#define T3MR3                  VOLATILE32(0xE0074024)   //
#define T3CCR         VOLATILE32(0xE0074028)
#define T3CCR_bit     VOLATILE_TYPE(0xE0074028, __ccr_bits)
#define T3CR0                  VOLATILE32(0xE007402C)   //
#define T3CR1                  VOLATILE32(0xE0074030)   //
#define T3CR2                  VOLATILE32(0xE0074034)   //
#define T3CR3                  VOLATILE32(0xE0074038)   //
#define T3EMR         VOLATILE32(0xE007403C)
#define T3EMR_bit     VOLATILE_TYPE(0xE007403C, __emr_bits)
#define T3CTCR         VOLATILE32(0xE0074070)
#define T3CTCR_bit     VOLATILE_TYPE(0xE0074070, __ctcr_bits)

/***************************************************************************
 **
 ** Watchdog
 **
 ***************************************************************************/
#define WDMOD         VOLATILE32(0xE0000000)
#define WDMOD_bit     VOLATILE_TYPE(0xE0000000, __wdmod_bits)
#define WDTC                   VOLATILE32(0xE0000004)   //
#define WDFEED         VOLATILE32(0xE0000008)
#define WDFEED_bit     VOLATILE_TYPE(0xE0000008, __wdfeed_bits)
#define WDTV                   VOLATILE32(0xE000000C)   //
#define WDCLKSEL         VOLATILE32(0xE0000010)
#define WDCLKSEL_bit     VOLATILE_TYPE(0xE0000010, __wdclksel_bits)

/***************************************************************************
 **
 ** A/D Converters
 **
 ***************************************************************************/
#define AD0CR         VOLATILE32(0xE0034000)
#define AD0CR_bit     VOLATILE_TYPE(0xE0034000, __adcr_bits)
#define AD0GDR         VOLATILE32(0xE0034004)
#define AD0GDR_bit     VOLATILE_TYPE(0xE0034004, __adgdr_bits)
#define ADINTEN         VOLATILE32(0xE003400C)
#define ADINTEN_bit     VOLATILE_TYPE(0xE003400C, __adinten_bits)
#define ADDR0         VOLATILE32(0xE0034010)
#define ADDR0_bit     VOLATILE_TYPE(0xE0034010, __addr_bits)
#define ADDR1         VOLATILE32(0xE0034014)
#define ADDR1_bit     VOLATILE_TYPE(0xE0034014, __addr_bits)
#define ADDR2         VOLATILE32(0xE0034018)
#define ADDR2_bit     VOLATILE_TYPE(0xE0034018, __addr_bits)
#define ADDR3         VOLATILE32(0xE003401C)
#define ADDR3_bit     VOLATILE_TYPE(0xE003401C, __addr_bits)
#define ADDR4         VOLATILE32(0xE0034020)
#define ADDR4_bit     VOLATILE_TYPE(0xE0034020, __addr_bits)
#define ADDR5         VOLATILE32(0xE0034024)
#define ADDR5_bit     VOLATILE_TYPE(0xE0034024, __addr_bits)
#define ADDR6         VOLATILE32(0xE0034028)
#define ADDR6_bit     VOLATILE_TYPE(0xE0034028, __addr_bits)
#define ADDR7         VOLATILE32(0xE003402C)
#define ADDR7_bit     VOLATILE_TYPE(0xE003402C, __addr_bits)
#define ADSTAT         VOLATILE32(0xE0034030)
#define ADSTAT_bit     VOLATILE_TYPE(0xE0034030, __adstat_bits)

/***************************************************************************
 **
 ** D/A Converter
 **
 ***************************************************************************/
#define DACR         VOLATILE32(0xE006C000)
#define DACR_bit     VOLATILE_TYPE(0xE006C000, __dacr_bits)

/***************************************************************************
 **
 ** PWM1
 **
 ***************************************************************************/
#define PWM1IR         VOLATILE32(0xE0018000)
#define PWM1IR_bit     VOLATILE_TYPE(0xE0018000, __pwmir_bits)
#define PWM1TCR         VOLATILE32(0xE0018004)
#define PWM1TCR_bit     VOLATILE_TYPE(0xE0018004, __pwmtcr1_bits)
#define PWM1TC                 VOLATILE32(0xE0018008)   //
#define PWM1PR                 VOLATILE32(0xE001800C)   //
#define PWM1PC                 VOLATILE32(0xE0018010)   //
#define PWM1MCR         VOLATILE32(0xE0018014)
#define PWM1MCR_bit     VOLATILE_TYPE(0xE0018014, __pwmmcr_bits)
#define PWM1MR0                VOLATILE32(0xE0018018)   //
#define PWM1MR1                VOLATILE32(0xE001801C)   //
#define PWM1MR2                VOLATILE32(0xE0018020)   //
#define PWM1MR3                VOLATILE32(0xE0018024)   //
#define PWM1CCR         VOLATILE32(0xE0018028)
#define PWM1CCR_bit     VOLATILE_TYPE(0xE0018028, __pwmccr_bits)
#define PWM1CR0                VOLATILE32(0xE001802C)   //
#define PWM1CR1                VOLATILE32(0xE0018030)   //
#define PWM1CR2                VOLATILE32(0xE0018034)   //
#define PWM1CR3                VOLATILE32(0xE0018038)   //
#define PWM1EMR                VOLATILE32(0xE001803C)   //
#define PWM1MR4                VOLATILE32(0xE0018040)   //
#define PWM1MR5                VOLATILE32(0xE0018044)   //
#define PWM1MR6                VOLATILE32(0xE0018048)   //
#define PWM1PCR         VOLATILE32(0xE001804C)
#define PWM1PCR_bit     VOLATILE_TYPE(0xE001804C, __pwmpcr_bits)
#define PWM1LER         VOLATILE32(0xE0018050)
#define PWM1LER_bit     VOLATILE_TYPE(0xE0018050, __pwmler_bits)
#define PWM1CTCR         VOLATILE32(0xE0018070)
#define PWM1CTCR_bit     VOLATILE_TYPE(0xE0018070, __pwmctcr_bits)

/***************************************************************************
 **
 ** RTC
 **
 ***************************************************************************/
#define ILR         VOLATILE32(0xE0024000)
#define ILR_bit     VOLATILE_TYPE(0xE0024000, __ilr_bits)
#define CTC         VOLATILE32(0xE0024004)
#define CTC_bit     VOLATILE_TYPE(0xE0024004, __ctc_bits)
#define CCR         VOLATILE32(0xE0024008)
#define CCR_bit     VOLATILE_TYPE(0xE0024008, __rtcccr_bits)
#define CIIR         VOLATILE32(0xE002400C)
#define CIIR_bit     VOLATILE_TYPE(0xE002400C, __ciir_bits)
#define AMR         VOLATILE32(0xE0024010)
#define AMR_bit     VOLATILE_TYPE(0xE0024010, __amr_bits)
#define CTIME0         VOLATILE32(0xE0024014)
#define CTIME0_bit     VOLATILE_TYPE(0xE0024014, __ctime0_bits)
#define CTIME1         VOLATILE32(0xE0024018)
#define CTIME1_bit     VOLATILE_TYPE(0xE0024018, __ctime1_bits)
#define CTIME2         VOLATILE32(0xE002401C)
#define CTIME2_bit     VOLATILE_TYPE(0xE002401C, __ctime2_bits)
#define SEC         VOLATILE32(0xE0024020)
#define SEC_bit     VOLATILE_TYPE(0xE0024020, __sec_bits)
#define MIN         VOLATILE32(0xE0024024)
#define MIN_bit     VOLATILE_TYPE(0xE0024024, __min_bits)
#define HOUR         VOLATILE32(0xE0024028)
#define HOUR_bit     VOLATILE_TYPE(0xE0024028, __hour_bits)
#define DOM         VOLATILE32(0xE002402C)
#define DOM_bit     VOLATILE_TYPE(0xE002402C, __dom_bits)
#define DOW         VOLATILE32(0xE0024030)
#define DOW_bit     VOLATILE_TYPE(0xE0024030, __dow_bits)
#define DOY         VOLATILE32(0xE0024034)
#define DOY_bit     VOLATILE_TYPE(0xE0024034, __doy_bits)
#define MONTH         VOLATILE32(0xE0024038)
#define MONTH_bit     VOLATILE_TYPE(0xE0024038, __month_bits)
#define YEAR         VOLATILE32(0xE002403C)
#define YEAR_bit     VOLATILE_TYPE(0xE002403C, __year_bits)
#define CISS         VOLATILE32(0xE0024040)
#define CISS_bit     VOLATILE_TYPE(0xE0024040, __ciss_bits)
#define ALSEC         VOLATILE32(0xE0024060)
#define ALSEC_bit     VOLATILE_TYPE(0xE0024060, __sec_bits)
#define ALMIN         VOLATILE32(0xE0024064)
#define ALMIN_bit     VOLATILE_TYPE(0xE0024064, __min_bits)
#define ALHOUR         VOLATILE32(0xE0024068)
#define ALHOUR_bit     VOLATILE_TYPE(0xE0024068, __hour_bits)
#define ALDOM         VOLATILE32(0xE002406C)
#define ALDOM_bit     VOLATILE_TYPE(0xE002406C, __dom_bits)
#define ALDOW         VOLATILE32(0xE0024070)
#define ALDOW_bit     VOLATILE_TYPE(0xE0024070, __dow_bits)
#define ALDOY         VOLATILE32(0xE0024074)
#define ALDOY_bit     VOLATILE_TYPE(0xE0024074, __doy_bits)
#define ALMON         VOLATILE32(0xE0024078)
#define ALMON_bit     VOLATILE_TYPE(0xE0024078, __month_bits)
#define ALYEAR         VOLATILE32(0xE002407C)
#define ALYEAR_bit     VOLATILE_TYPE(0xE002407C, __year_bits)
#define PREINT         VOLATILE32(0xE0024080)
#define PREINT_bit     VOLATILE_TYPE(0xE0024080, __preint_bits)
#define PREFRAC         VOLATILE32(0xE0024084)
#define PREFRAC_bit     VOLATILE_TYPE(0xE0024084, __prefrac_bits)

/***************************************************************************
 **
 ** DMA
 **
 ***************************************************************************/
#define DMACINTSTATUS         VOLATILE32(0xFFE04000)
#define DMACINTSTATUS_bit     VOLATILE_TYPE(0xFFE04000, __dmacintstatus_bits)
#define DMACINTTCSTATUS         VOLATILE32(0xFFE04004)
#define DMACINTTCSTATUS_bit     VOLATILE_TYPE(0xFFE04004, __dmacinttcstatus_bits)
#define DMACINTTCCLEAR         VOLATILE32(0xFFE04008)
#define DMACINTTCCLEAR_bit     VOLATILE_TYPE(0xFFE04008, __dmacinttcclear_bits)
#define DMACINTERRSTAT         VOLATILE32(0xFFE0400C)
#define DMACINTERRSTAT_bit     VOLATILE_TYPE(0xFFE0400C, __dmacinterrstat_bits)
#define DMACINTERRCLR         VOLATILE32(0xFFE04010)
#define DMACINTERRCLR_bit     VOLATILE_TYPE(0xFFE04010, __dmacinterrclr_bits)
#define DMACRAWINTTCSTATUS         VOLATILE32(0xFFE04014)
#define DMACRAWINTTCSTATUS_bit     VOLATILE_TYPE(0xFFE04014, __dmacrawinttcstatus_bits)
#define DMACRAWINTERRORSTATUS         VOLATILE32(0xFFE04018)
#define DMACRAWINTERRORSTATUS_bit     VOLATILE_TYPE(0xFFE04018, __dmacrawinterrorstatus_bits)
#define DMACENBLDCHNS         VOLATILE32(0xFFE0401C)
#define DMACENBLDCHNS_bit     VOLATILE_TYPE(0xFFE0401C, __dmacenbldchns_bits)
#define DMACSOFTBREQ         VOLATILE32(0xFFE04020)
#define DMACSOFTBREQ_bit     VOLATILE_TYPE(0xFFE04020, __dmacsoftbreq_bits)
#define DMACSOFTSREQ         VOLATILE32(0xFFE04024)
#define DMACSOFTSREQ_bit     VOLATILE_TYPE(0xFFE04024, __dmacsoftsreq_bits)
#define DMACSOFTLBREQ         VOLATILE32(0xFFE04028)
#define DMACSOFTLBREQ_bit     VOLATILE_TYPE(0xFFE04028, __dmacsoftlbreq_bits)
#define DMACSOFTLSREQ         VOLATILE32(0xFFE0402C)
#define DMACSOFTLSREQ_bit     VOLATILE_TYPE(0xFFE0402C, __dmacsoftlsreq_bits)
#define DMACCONFIGURATION         VOLATILE32(0xFFE04030)
#define DMACCONFIGURATION_bit     VOLATILE_TYPE(0xFFE04030, __dmacconfig_bits)
#define DMACSYNC         VOLATILE32(0xFFE04034)
#define DMACSYNC_bit     VOLATILE_TYPE(0xFFE04034, __dmacsync_bits)
#define DMACC0SRCADDR          VOLATILE32(0xFFE04100)   //
#define DMACC0DESTADDR         VOLATILE32(0xFFE04104)   //
#define DMACC0LLI         VOLATILE32(0xFFE04108)
#define DMACC0LLI_bit     VOLATILE_TYPE(0xFFE04108, __dma_lli_bits)
#define DMACC0CONTROL         VOLATILE32(0xFFE0410C)
#define DMACC0CONTROL_bit     VOLATILE_TYPE(0xFFE0410C, __dma_ctrl_bits)
#define DMACC0CONFIGURATION         VOLATILE32(0xFFE04110)
#define DMACC0CONFIGURATION_bit     VOLATILE_TYPE(0xFFE04110, __dma_cfg_bits)
#define DMACC1SRCADDR          VOLATILE32(0xFFE04120)   //
#define DMACC1DESTADDR         VOLATILE32(0xFFE04124)   //
#define DMACC1LLI         VOLATILE32(0xFFE04128)
#define DMACC1LLI_bit     VOLATILE_TYPE(0xFFE04128, __dma_lli_bits)
#define DMACC1CONTROL         VOLATILE32(0xFFE0412C)
#define DMACC1CONTROL_bit     VOLATILE_TYPE(0xFFE0412C, __dma_ctrl_bits)
#define DMACC1CONFIGURATION         VOLATILE32(0x31000130)
#define DMACC1CONFIGURATION_bit     VOLATILE_TYPE(0x31000130, __dma_cfg_bits)

/***************************************************************************
 **  Assembler-specific declarations
 ***************************************************************************/

#ifdef __IAR_SYSTEMS_ASM__
#endif    /* __IAR_SYSTEMS_ASM__ */

/***************************************************************************
 **
 **  Interrupt vector table
 **
 ***************************************************************************/
#define RESETV        0x00  /* Reset                              */
#define UNDEFV        0x04  /* Undefined instruction              */
#define SWIV          0x08  /* Software interrupt                 */
#define PABORTV       0x0C  /* Prefetch abort                     */
#define DABORTV       0x10  /* Data abort                         */
#define IRQV          0x18  /* Normal interrupt                   */
#define FIQV          0x1C  /* Fast interrupt                     */

/***************************************************************************
 **
 **  DMA Controller peripheral devices lines
 **
 ***************************************************************************/
#define DMA_SSP0TX       0  /* SPI0 Tx                            */
#define DMA_SSP0RX       1  /* SPI0 Rx                            */
#define DMA_SSP1TX       2  /* SPI1 Tx                            */
#define DMA_SSP1RX       3  /* SPI1 Rx                            */
#define DMA_MMCSD        4  /* MMC/SD                             */
#define DMA_I2S0         5  /* I2S Channel 0                      */
#define DMA_I2S1         6  /* I2S Channel 1                      */

/***************************************************************************
 **
 **  VIC Interrupt channels
 **
 ***************************************************************************/
#define VIC_WDT          0  /* Watchdog                           */
#define VIC_SW           1  /* Software interrupts                */
#define VIC_DEBUGRX      2  /* Embedded ICE, DbgCommRx            */
#define VIC_DEBUGTX      3  /* Embedded ICE, DbgCommTx            */
#define VIC_TIMER0       4  /* Timer 0 (Match 0-3 Capture 0-3)    */
#define VIC_TIMER1       5  /* Timer 1 (Match 0-3 Capture 0-3)    */
#define VIC_UART0        6  /* UART 0  (RLS, THRE, RDA, CTI)      */
#define VIC_UART1        7  /* UART 1  (RLS, THRE, RDA, CTI, MSI) */
#define VIC_PWM01        8  /* PWM 01  (Match 0-6 Capture 0-3)    */
#define VIC_I2C0         9  /* I2C 0   (SI)                       */
#define VIC_SPI         10  /* SPI 0, SSP 0                       */
#define VIC_SSP1         11 /* SSP 1                              */
#define VIC_PLL         12  /* PLL lock (PLOCK)                   */
#define VIC_RTC         13  /* RTC      (RTCCIF, RTCALF)          */
#define VIC_EINT0       14  /* External interrupt 0 (EINT0)       */
#define VIC_EINT1       15  /* External interrupt 1 (EINT1)       */
#define VIC_EINT2       16  /* External interrupt 2 (EINT2)       */
#define VIC_EINT3       17  /* External interrupt 3 (EINT3)       */
#define VIC_AD0         18  /* A/D converter 0                    */
#define VIC_I2C1        19  /* I2C 1                              */
#define VIC_BOD         20  /* Brown out detect                   */
#define VIC_ETHERNET    21  /* Ethernet                           */
#define VIC_USB         22  /* USB Low and High priority          */
#define VIC_CAN12       23  /* CAN1,2 Tx, Rx                      */
#define VIC_MMC         24  /* SD/MMC                             */
#define VIC_GP_DMA      25  /* DMA channel 0, DMA channel 1       */
#define VIC_TIMER2      26  /* Timer 2 (Match 0-3 Capture 0-3)    */
#define VIC_TIMER3      27  /* Timer 3 (Match 0-3 Capture 0-3)    */
#define VIC_UART2       28  /* UART 2  (RLS, THRE, RDA, CTI)      */
#define VIC_UART3       29  /* UART 3  (RLS, THRE, RDA, CTI, MSI) */
#define VIC_I2C2        30  /* I2C 0   (SI)                       */
#define VIC_I2S         31  /* I2S Rx, Tx                         */

#endif    /* __IOLPC2378_H */
